@@ -122,6 +122,10 @@ namespace {
         }
     } initOperatorMapping_;
 
+    inline std::string full_scope(const std::string& tpname) {
+        return tpname[0] == ':' ? tpname : "::"+tpname;
+    }
+
 } // unnamed namespace
 
 
@@ -484,7 +488,7 @@ static bool AddTypeName(std::string& tmpl_name, PyObject* tn, PyObject* arg,
     }
 
     if (CPPScope_Check(tn)) {
-        tmpl_name.append(Cppyy::GetScopedFinalName(((CPPClass*)tn)->fCppType));
+        tmpl_name.append(full_scope(Cppyy::GetScopedFinalName(((CPPClass*)tn)->fCppType)));
         if (arg) {
         // try to specialize the type match for the given object
             CPPInstance* pyobj = (CPPInstance*)arg;
@@ -505,7 +509,7 @@ static bool AddTypeName(std::string& tmpl_name, PyObject* tn, PyObject* arg,
     }
 
     if (tn == (PyObject*)&CPPOverload_Type) {
-        PyObject* tpName =  arg ? \
+        PyObject* tpName = arg ? \
             PyObject_GetAttr(arg, PyStrings::gCppName) : \
             CPyCppyy_PyText_FromString("void* (*)(...)");
         tmpl_name.append(CPyCppyy_PyText_AsString(tpName));
@@ -529,7 +533,7 @@ static bool AddTypeName(std::string& tmpl_name, PyObject* tn, PyObject* arg,
                     for (Py_ssize_t i = 0; i < (PyList_GET_SIZE(values)-1); ++i) {
                         if (i) tpn << ", ";
                         PyObject* item = PyList_GET_ITEM(values, i);
-                        tpn << (CPPScope_Check(item) ?  ClassName(item) : AnnotationAsText(item));
+                        tpn << (CPPScope_Check(item) ? full_scope(ClassName(item)) : AnnotationAsText(item));
                     }
                     Py_DECREF(values);
 
@@ -547,7 +551,8 @@ static bool AddTypeName(std::string& tmpl_name, PyObject* tn, PyObject* arg,
 
         PyObject* tpName = PyObject_GetAttr(arg, PyStrings::gCppName);
         if (tpName) {
-            tmpl_name.append(CPyCppyy_PyText_AsString(tpName));
+            const char* cname = CPyCppyy_PyText_AsString(tpName);
+            tmpl_name.append(CPPScope_Check(arg) ? full_scope(cname) : cname);
             Py_DECREF(tpName);
             return true;
         }
@@ -623,7 +628,7 @@ std::string CPyCppyy::Utility::ConstructTemplateArgs(
 //----------------------------------------------------------------------------
 static inline bool check_scope(const std::string& name)
 {
-    return (bool)Cppyy::GetScope(CPyCppyy::TypeManip::clean_type(name));
+    return (bool)Cppyy::GetScope(CPyCppyy::TypeManip::clean_type(name, false));
 }
 
 void CPyCppyy::Utility::ConstructCallbackPreamble(const std::string& retType,
@@ -640,7 +645,7 @@ void CPyCppyy::Utility::ConstructCallbackPreamble(const std::string& retType,
              << retType << "\"), CPyCppyy::DestroyConverter};\n";
     std::vector<bool> arg_is_ptr;
     if (nArgs) {
-        arg_is_ptr.reserve(nArgs);
+        arg_is_ptr.resize(nArgs);
         code << "    CPYCPPYY_STATIC std::vector<std::unique_ptr<CPyCppyy::Converter, std::function<void(CPyCppyy::Converter*)>>> argcvs;\n"
              << "    if (argcvs.empty()) {\n"
              << "      argcvs.reserve(" << nArgs << ");\n";
@@ -821,6 +826,9 @@ Py_ssize_t CPyCppyy::Utility::GetBuffer(PyObject* pyobject, char tc, int size, v
 
 // new-style buffer interface
     if (PyObject_CheckBuffer(pyobject)) {
+        if (PySequence_Check(pyobject) && !PySequence_Size(pyobject))
+            return 0;   // PyObject_GetBuffer() crashes on some platforms for some zero-sized seqeunces
+
         Py_buffer bufinfo;
         memset(&bufinfo, 0, sizeof(Py_buffer));
         if (PyObject_GetBuffer(pyobject, &bufinfo, PyBUF_FORMAT) == 0) {
@@ -906,15 +914,14 @@ Py_ssize_t CPyCppyy::Utility::GetBuffer(PyObject* pyobject, char tc, int size, v
                 buf = 0;                      // not compatible
 
             // clarify error message
-                PyObject* pytype = 0, *pyvalue = 0, *pytrace = 0;
-                PyErr_Fetch(&pytype, &pyvalue, &pytrace);
+                auto error = FetchPyError();
                 PyObject* pyvalue2 = CPyCppyy_PyText_FromFormat(
                     (char*)"%s and given element size (%ld) do not match needed (%d)",
-                    CPyCppyy_PyText_AsString(pyvalue),
+                    CPyCppyy_PyText_AsString(error.fValue.get()),
                     seqmeths->sq_length ? (long)(buflen/(*(seqmeths->sq_length))(pyobject)) : (long)buflen,
                     size);
-                Py_DECREF(pyvalue);
-                PyErr_Restore(pytype, pyvalue2, pytrace);
+                error.fValue.reset(pyvalue2);
+                RestorePyError(error);
             }
         }
 
@@ -1014,7 +1021,11 @@ std::string CPyCppyy::Utility::ClassName(PyObject* pyobj)
 static std::set<std::string> sIteratorTypes;
 bool CPyCppyy::Utility::IsSTLIterator(const std::string& classname)
 {
-// attempt to recognize STL iterators (TODO: probably belongs in the backend)
+// attempt to recognize STL iterators (TODO: probably belongs in the backend), using
+// a couple of common container classes with different iterator protocols (note that
+// mapping iterators are handled separately in the pythonizations) as exemplars (the
+// actual, resolved, names will be compiler-specific) that are picked b/c they are
+// baked into the CoreLegacy dictionary
     if (sIteratorTypes.empty()) {
         std::string tt = "<int>::";
         for (auto c : {"std::vector", "std::list", "std::deque"}) {
@@ -1067,20 +1078,50 @@ PyObject* CPyCppyy::Utility::PyErr_Occurred_WithGIL()
 }
 
 
+//----------------------------------------------------------------------------
+CPyCppyy::Utility::PyError_t CPyCppyy::Utility::FetchPyError()
+{
+   // create a PyError_t RAII object that will capture and store the exception data
+   CPyCppyy::Utility::PyError_t error{};
+#if PY_VERSION_HEX >= 0x030c0000
+   error.fValue.reset(PyErr_GetRaisedException());
+#else
+   PyObject *pytype = nullptr;
+   PyObject *pyvalue = nullptr;
+   PyObject *pytrace = nullptr;
+   PyErr_Fetch(&pytype, &pyvalue, &pytrace);
+   error.fType.reset(pytype);
+   error.fValue.reset(pyvalue);
+   error.fTrace.reset(pytrace);
+#endif
+   return error;
+}
+
+
+//----------------------------------------------------------------------------
+void CPyCppyy::Utility::RestorePyError(CPyCppyy::Utility::PyError_t &error)
+{
+#if PY_VERSION_HEX >= 0x030c0000
+   PyErr_SetRaisedException(error.fValue.release());
+#else
+   PyErr_Restore(error.fType.release(), error.fValue.release(), error.fTrace.release());
+#endif
+}
+
+
 //----------------------------------------------------------------------------
 size_t CPyCppyy::Utility::FetchError(std::vector<PyError_t>& errors, bool is_cpp)
 {
 // Fetch the current python error, if any, and store it for future use.
     if (PyErr_Occurred()) {
-        PyError_t e{is_cpp};
-        PyErr_Fetch(&e.fType, &e.fValue, &e.fTrace);
-        errors.push_back(e);
+        errors.emplace_back(FetchPyError());
+        errors.back().fIsCpp = is_cpp;
     }
     return errors.size();
 }
 
 //----------------------------------------------------------------------------
-void CPyCppyy::Utility::SetDetailedException(std::vector<PyError_t>& errors, PyObject* topmsg, PyObject* defexc)
+void CPyCppyy::Utility::SetDetailedException(std::vector<PyError_t>&& errors, PyObject* topmsg, PyObject* defexc)
 {
 // Use the collected exceptions to build up a detailed error log.
     if (errors.empty()) {
@@ -1111,14 +1152,18 @@ void CPyCppyy::Utility::SetDetailedException(std::vector<PyError_t>& errors, PyO
 
     // bind the original C++ object, rather than constructing from topmsg, as it
     // is expected to have informative state
-        Py_INCREF(unique_from_cpp->fType); Py_INCREF(unique_from_cpp->fValue); Py_XINCREF(unique_from_cpp->fTrace);
-        PyErr_Restore(unique_from_cpp->fType, unique_from_cpp->fValue, unique_from_cpp->fTrace);
+        RestorePyError(*unique_from_cpp);
     } else {
     // try to consolidate Python exceptions, otherwise select default
         PyObject* exc_type = nullptr;
         for (auto& e : errors) {
-            if (!exc_type) exc_type = e.fType;
-            else if (exc_type != e.fType) {
+#if PY_VERSION_HEX >= 0x030c0000
+            PyObject* pytype = (PyObject*)Py_TYPE(e.fValue.get());
+#else
+            PyObject* pytype = e.fType.get();
+#endif
+            if (!exc_type) exc_type = pytype;
+            else if (exc_type != pytype) {
                 exc_type = defexc;
                 break;
             }
@@ -1127,14 +1172,15 @@ void CPyCppyy::Utility::SetDetailedException(std::vector<PyError_t>& errors, PyO
     // add the details to the topmsg
         PyObject* separator = CPyCppyy_PyText_FromString("\n  ");
         for (auto& e : errors) {
+            PyObject *pyvalue = e.fValue.get();
             CPyCppyy_PyText_Append(&topmsg, separator);
-            if (CPyCppyy_PyText_Check(e.fValue)) {
-                CPyCppyy_PyText_Append(&topmsg, e.fValue);
-            } else if (e.fValue) {
-                PyObject* excstr = PyObject_Str(e.fValue);
+            if (CPyCppyy_PyText_Check(pyvalue)) {
+                CPyCppyy_PyText_Append(&topmsg, pyvalue);
+            } else if (pyvalue) {
+                PyObject* excstr = PyObject_Str(pyvalue);
                 if (!excstr) {
                     PyErr_Clear();
-                    excstr = PyObject_Str((PyObject*)Py_TYPE(e.fValue));
+                    excstr = PyObject_Str((PyObject*)Py_TYPE(pyvalue));
                 }
                 CPyCppyy_PyText_AppendAndDel(&topmsg, excstr);
             } else {
@@ -1149,8 +1195,6 @@ void CPyCppyy::Utility::SetDetailedException(std::vector<PyError_t>& errors, PyO
         PyErr_SetString(exc_type, CPyCppyy_PyText_AsString(topmsg));
     }
 
-// cleanup stored errors and done with topmsg (whether used or not)
-    std::for_each(errors.begin(), errors.end(), PyError_t::Clear);
     Py_DECREF(topmsg);
 }
 
