@@ -511,6 +511,10 @@ class TestPYTHONIFY:
 
         void foobar(const MyClass& m1 = MyClass(), const MyClass& m2 = MyClass()) {
             /* empty */
+        }
+
+        bool barfoo(bool opt1=false, bool opt2=true) {
+            return opt1 && opt2;
         } }""")
 
         def pyfoo(a=10, b=20, c=5, d=4):
@@ -533,6 +537,12 @@ class TestPYTHONIFY:
 
         ns.foobar(m2 = ns.MyClass())
 
+        assert not ns.barfoo()
+        assert not ns.barfoo(opt2=True)
+        assert not ns.barfoo(opt2=False)
+        assert     ns.barfoo(opt1=True, opt2=True)
+        assert not ns.barfoo(opt1=True, opt2=False)
+
 
 class TestPYTHONIFY_UI:
     def setup_class(cls):
