@@ -60,7 +60,7 @@ void TMemberInspector::TParentBuf::Remove(Ssiz_t startingAt)
 ClassImp(TMemberInspector);
 
 TMemberInspector::TMemberInspector():
-   fObjectPointerState(kUnset)
+   fObjectPointerState(kUnset), fNestedTransient(0)
 {
    // Construct a member inspector
 
