@@ -234,7 +234,12 @@ TString::TString(const char *a1, Ssiz_t n1, const char *a2, Ssiz_t n2)
    }
    if (!a1) n1 = 0;
    if (!a2) n2 = 0;
-   Ssiz_t tot = n1+n2;
+   Long64_t tot = static_cast<Long64_t>(n1)+n2; // Final string length, use 64-bit long instead of 32-bit int to check for overflows
+   if (tot > MaxSize()) {
+      Error("TString::TString", "Too large number of characters!");
+      Zero();
+      return;
+   }
    char *data = Init(tot, tot);
    if (a1) memcpy(data,    a1, n1);
    if (a2) memcpy(data+n1, a2, n2);
@@ -251,6 +256,7 @@ TString::~TString()
 ////////////////////////////////////////////////////////////////////////////////
 /// Private member function returning an empty string representation of
 /// size capacity and containing nchar characters.
+/// \warning If nchar > MaxSize(), then Fatal() is raised and only MaxSize() elements are allocated
 
 char *TString::Init(Ssiz_t capacity, Ssiz_t nchar)
 {
@@ -267,7 +273,7 @@ char *TString::Init(Ssiz_t capacity, Ssiz_t nchar)
       nchar = capacity;
    }
    if (capacity > MaxSize()) {
-      Error("TString::Init", "capacity too large (%d, max = %d)", capacity, MaxSize());
+      Fatal("TString::Init", "capacity too large (%d, max = %d)", capacity, MaxSize());
       capacity = MaxSize();
       if (nchar > capacity)
          nchar = capacity;
@@ -386,6 +392,7 @@ TString& TString::operator=(const TSubString &substr)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Append character c rep times to string.
+/// \warning If length+rep exceeds MaxSize(), then Fatal() is raised and only MaxSize()-length elements are added
 
 TString& TString::Append(char c, Ssiz_t rep)
 {
@@ -396,10 +403,10 @@ TString& TString::Append(char c, Ssiz_t rep)
       return *this;
    }
    Ssiz_t len = Length();
-   Ssiz_t tot = len + rep;  // Final string length
+   Long64_t tot = static_cast<Long64_t>(len) + rep;  // Final string length, use 64-bit long instead of 32-bit int to check for overflows
 
    if (tot > MaxSize()) {
-      Error("TString::Append", "rep too large (%d, max = %d)", rep, MaxSize()-len);
+      Fatal("TString::Append", "rep too large (%d, max = %d)", rep, MaxSize()-len);
       tot = MaxSize();
       rep = tot - len;
    }
@@ -965,6 +972,7 @@ Bool_t TString::MaybeWildcard() const
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Prepend character c rep times to string.
+/// \warning If length+rep exceeds MaxSize(), then Fatal() is raised and only MaxSize()-length elements are added
 
 TString& TString::Prepend(char c, Ssiz_t rep)
 {
@@ -972,10 +980,10 @@ TString& TString::Prepend(char c, Ssiz_t rep)
       return *this;
 
    Ssiz_t len = Length();
-   Ssiz_t tot = len + rep;  // Final string length
+   Long64_t tot = static_cast<Long64_t>(len) + rep;  // Final string length, use 64-bit long instead of 32-bit int to check for overflows
 
    if (tot > MaxSize()) {
-      Error("TString::Prepend", "rep too large (%d, max = %d)", rep, MaxSize()-len);
+      Fatal("TString::Prepend", "rep too large (%d, max = %d)", rep, MaxSize()-len);
       tot = MaxSize();
       rep = tot - len;
    }
@@ -1028,7 +1036,11 @@ TString &TString::Replace(Ssiz_t pos, Ssiz_t n1, const char *cs, Ssiz_t n2)
    n1 = TMath::Min(n1, len - pos);
    if (!cs) n2 = 0;
 
-   Ssiz_t tot = len - n1 + n2;  // Final string length
+   Long64_t tot = static_cast<Long64_t>(len) - n1 + n2;  // Final string length, use 64-bit long instead of 32-bit int to check for overflows
+   if (tot > MaxSize()) {
+      Error("TString::Replace", "Too large number of characters!");
+      return *this;
+   }
    Ssiz_t rem = len - n1 - pos; // Length of remnant at end of string
 
    Ssiz_t capac = Capacity();
@@ -1101,7 +1113,7 @@ TString& TString::ReplaceAll(const char *s1, Ssiz_t ls1, const char *s2,
 
 TString &TString::ReplaceSpecialCppChars()
 {
-   return ReplaceAll("\\","\\\\").ReplaceAll("\"","\\\"");
+   return ReplaceAll("\\","\\\\").ReplaceAll("\"","\\\"").ReplaceAll("\n","\\n").ReplaceAll("\t","\\t");
 }
 
 
@@ -1202,12 +1214,14 @@ void TString::AssertElement(Ssiz_t i) const
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Calculate a nice capacity greater than or equal to newCap.
+/// \warning Fatal() is raised if newCap > MaxSize()
+/// \return Resulting recommended capacity (after clamping, if needed)
 
 Ssiz_t TString::AdjustCapacity(Ssiz_t oldCap, Ssiz_t newCap)
 {
    Ssiz_t ms = MaxSize();
    if (newCap > ms - 1) {
-      Error("TString::AdjustCapacity", "capacity too large (%d, max = %d)",
+      Fatal("TString::AdjustCapacity", "capacity too large (%d, max = %d)",
             newCap, ms);
    }
    Ssiz_t cap = oldCap < ms / 2 - kAlignment ?
@@ -1225,12 +1239,18 @@ void TString::Clear()
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Clear string and make sure it has a capacity of nc.
+/// \warning If nc > MaxSize(), then Fatal() is raised, and only MaxSize()
+/// elements are allocated if Fatal does not abort
+/// \return Resulting allocated capacity (after clamping, if needed)
 
-void TString::Clobber(Ssiz_t nc)
+Ssiz_t TString::Clobber(Ssiz_t nc)
 {
    if (nc > MaxSize()) {
-      Error("TString::Clobber", "capacity too large (%d, max = %d)", nc, MaxSize());
-      nc = MaxSize();
+      Fatal("TString::Clobber", "capacity too large (%d, max = %d)", nc, MaxSize());
+      // In the rare case where Fatal does not abort, we erase, clamp and continue
+      UnLink();
+      Zero();
+      nc = MaxSize(); // Clamping after deleting to avoid corruption
    }
 
    if (nc < kMinCap) {
@@ -1248,11 +1268,13 @@ void TString::Clobber(Ssiz_t nc)
       SetLongSize(0);
       data[0] = 0;
    }
+   return nc;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Make self a distinct copy with capacity of at least tot, where tot cannot
 /// be smaller than the current length. Preserve previous contents.
+/// \warning If tot > MaxSize(), then Fatal() is raised and only MaxSize() elements are allocated
 
 void TString::Clone(Ssiz_t tot)
 {
@@ -1260,7 +1282,7 @@ void TString::Clone(Ssiz_t tot)
    if (len >= tot) return;
 
    if (tot > MaxSize()) {
-      Error("TString::Clone", "tot too large (%d, max = %d)", tot, MaxSize());
+      Fatal("TString::Clone", "tot too large (%d, max = %d)", tot, MaxSize());
       tot = MaxSize();
    }
 
@@ -2288,7 +2310,7 @@ TObjArray *TString::Tokenize(const TString &delim) const
 void TString::FormImp(const char *fmt, va_list ap)
 {
    Ssiz_t buflen = 20 + 20 * strlen(fmt);    // pick a number, any strictly positive number
-   Clobber(buflen);
+   buflen = Clobber(buflen); // Update buflen, as Clobber clamps length to MaxSize (if Fatal does not abort)
 
    va_list sap;
    R__VA_COPY(sap, ap);
@@ -2303,7 +2325,7 @@ again:
          buflen *= 2;
       else
          buflen = n+1;
-      Clobber(buflen);
+      buflen = Clobber(buflen);
       va_end(ap);
       R__VA_COPY(ap, sap);
       vc = 1;
@@ -2324,7 +2346,7 @@ again:
 ///   TString formatted;
 ///   formatted.Form("%s in <%s>: %s", type, location, msg);
 ///
-///   lines.emplace_back(TString::Format("Welcome to ROOT %s%%shttp://root.cern.ch",
+///   lines.emplace_back(TString::Format("Welcome to ROOT %s%%shttp://root.cern",
 ///                      gROOT->GetVersion()));
 /// ~~~
 ///
@@ -2344,7 +2366,7 @@ void TString::Form(const char *va_(fmt), ...)
 /// descriptor and return a TString. Similar to TString::Form() but it is
 /// not needed to first create a TString.
 /// ~~~ {.cpp}
-///   lines.emplace_back(TString::Format("Welcome to ROOT %s%%shttp://root.cern.ch",
+///   lines.emplace_back(TString::Format("Welcome to ROOT %s%%shttp://root.cern",
 ///                      gROOT->GetVersion()));
 ///   TString formatted;
 ///   formatted.Form("%s in <%s>: %s", type, location, msg);
