@@ -56,7 +56,11 @@ private:
    TList  *fGarbage;
 public:
    TSingleShotCleaner() : TTimer(10, kTRUE) { fGarbage = new TList(); }
-   virtual ~TSingleShotCleaner() { fGarbage->Delete(); delete fGarbage; }
+   ~TSingleShotCleaner() override
+   {
+      fGarbage->Delete();
+      delete fGarbage;
+   }
    void TurnOn() override
    {
       TObject *obj = (TObject *)gTQSender;
