@@ -160,25 +160,26 @@ public:
 class TClingLookupHelper : public TClassEdit::TInterpreterLookupHelper {
 public:
    typedef bool (*ExistingTypeCheck_t)(const std::string &tname, std::string &result);
+   typedef bool (*CheckInClassTable_t)(const std::string &tname, std::string &result);
    typedef bool (*AutoParse_t)(const char *name);
 
 private:
    cling::Interpreter *fInterpreter;
    TNormalizedCtxt    *fNormalizedCtxt;
    ExistingTypeCheck_t fExistingTypeCheck;
+   CheckInClassTable_t fCheckInClassTable;
    AutoParse_t         fAutoParse;
    bool               *fInterpreterIsShuttingDownPtr;
    const int          *fPDebug; // debug flag, might change at runtime thus *
    bool WantDiags() const { return fPDebug && *fPDebug > 5; }
 
 public:
-   TClingLookupHelper(cling::Interpreter &interpreter, TNormalizedCtxt &normCtxt,
-                      ExistingTypeCheck_t existingTypeCheck,
-                      AutoParse_t autoParse,
-                      bool *shuttingDownPtr,
+   TClingLookupHelper(cling::Interpreter &interpreter, TNormalizedCtxt &normCtxt, ExistingTypeCheck_t existingTypeCheck,
+                      CheckInClassTable_t CheckInClassTable, AutoParse_t autoParse, bool *shuttingDownPtr,
                       const int *pgDebug = nullptr);
    virtual ~TClingLookupHelper() { /* we're not owner */ }
 
+   bool CheckInClassTable(const std::string &tname, std::string &result) override;
    bool ExistingTypeCheck(const std::string &tname, std::string &result) override;
    void GetPartiallyDesugaredName(std::string &nameLong) override;
    bool IsAlreadyPartiallyDesugaredName(const std::string &nondef, const std::string &nameLong) override;
@@ -197,21 +198,30 @@ private:
    std::string fRequestedName;
    std::string fNormalizedName;
    std::string fDemangledTypeInfo;
+   // clang-format off
    bool fRequestStreamerInfo;
    bool fRequestNoStreamer;
    bool fRequestNoInputOperator;
    bool fRequestOnlyTClass;
    int  fRequestedVersionNumber;
+   int  fRequestedRNTupleSerializationMode;
+   // clang-format on
 
 public:
+   // clang-format off
    enum ERootFlag {
-      kNoStreamer      = 0x01,
+      kNoStreamer = 0x01,
       kNoInputOperator = 0x02,
-      kUseByteCount    = 0x04,
-      kStreamerInfo    = 0x04,
-      kHasVersion      = 0x08
+      kUseByteCount = 0x04,
+      kStreamerInfo = 0x04,
+      kHasVersion = 0x08,
+      // kHasCustomStreamerMember = 0x10 (see TClingUtils.cxx and TClassTable.h)
+      kNtplForceNativeMode = 0x20,
+      kNtplForceStreamerMode = 0x40
    };
+   // clang-format on
 
+   // clang-format off
    AnnotatedRecordDecl(long index,
                        const clang::RecordDecl *decl,
                        bool rStreamerInfo,
@@ -219,6 +229,7 @@ public:
                        bool rRequestNoInputOperator,
                        bool rRequestOnlyTClass,
                        int rRequestedVersionNumber,
+                       int rRequestedRNTupleSerializationMode,
                        const cling::Interpreter &interpret,
                        const TNormalizedCtxt &normCtxt);
 
@@ -230,6 +241,7 @@ public:
                        bool rRequestNoInputOperator,
                        bool rRequestOnlyTClass,
                        int rRequestedVersionNumber,
+                       int rRequestedRNTupleSerializationMode,
                        const cling::Interpreter &interpret,
                        const TNormalizedCtxt &normCtxt);
 
@@ -242,6 +254,7 @@ public:
                        bool rRequestNoInputOperator,
                        bool rRequestOnlyTClass,
                        int rRequestedVersionNumber,
+                       int rRequestedRNTupleSerializationMode,
                        const cling::Interpreter &interpret,
                        const TNormalizedCtxt &normCtxt);
 
@@ -255,8 +268,10 @@ public:
                        bool rRequestNoInputOperator,
                        bool rRequestOnlyTClass,
                        int rRequestedVersionNumber,
+                       int rRequestedRNTupleSerializationMode,
                        const cling::Interpreter &interpret,
                        const TNormalizedCtxt &normCtxt);
+   // clang-format on
 
    ~AnnotatedRecordDecl() {
       // Nothing to do we do not own the pointer;
@@ -273,10 +288,13 @@ public:
       // Equivalent to CINT's cl.RootFlag() & G__USEBYTECOUNT
       return fRequestStreamerInfo;
    }
+   // clang-format off
    bool RequestNoInputOperator() const { return fRequestNoInputOperator; }
    bool RequestNoStreamer() const { return fRequestNoStreamer; }
    bool RequestOnlyTClass() const { return fRequestOnlyTClass; }
    int  RequestedVersionNumber() const { return fRequestedVersionNumber; }
+   int  RequestedRNTupleSerializationMode() const { return fRequestedRNTupleSerializationMode; }
+   // clang-format on
    int  RootFlag() const {
       // Return the request (streamerInfo, has_version, etc.) combined in a single
       // int.  See RScanner::AnnotatedRecordDecl::ERootFlag.
@@ -285,6 +303,12 @@ public:
       if (fRequestNoInputOperator) result |= kNoInputOperator;
       if (fRequestStreamerInfo) result |= kStreamerInfo;
       if (fRequestedVersionNumber > -1) result |= kHasVersion;
+      switch (fRequestedRNTupleSerializationMode) {
+      case 0: break;
+      case 1: result |= kNtplForceNativeMode; break;
+      case -1: result |= kNtplForceStreamerMode; break;
+      default: assert(false && "invalid setting of fRequestedRNTupleSerializationMode");
+      }
       return result;
    }
    const clang::RecordDecl* GetRecordDecl() const { return fDecl; }
@@ -544,6 +568,14 @@ void WriteClassInit(std::ostream& finalString,
                     const RConstructorTypes& ctorTypes,
                     bool& needCollectionProxy);
 
+//______________________________________________________________________________
+void WriteStandaloneReadRules(std::ostream &finalString, bool rawrules, std::vector<std::string> &standaloneTargets,
+                              const cling::Interpreter &interp);
+
+//______________________________________________________________________________
+void WriteRulesRegistration(std::ostream &finalString, const std::string &dictName,
+                            const std::vector<std::string> &standaloneTargets);
+
 //______________________________________________________________________________
 bool HasCustomStreamerMemberFunction(const AnnotatedRecordDecl &cl,
                                      const clang::CXXRecordDecl* clxx,
