@@ -26,6 +26,7 @@
 #include "TBaseClass.h"
 #include "TDataMember.h"
 #include "TDataType.h"
+#include "TEnum.h"
 #include "TRealData.h"
 #include "ThreadLocalStorage.h"
 #include "TList.h"
@@ -480,8 +481,10 @@ void TStreamerElement::ls(Option_t *) const
 void TStreamerElement::SetArrayDim(Int_t dim)
 {
    fArrayDim = dim;
-   if (dim) fType += TVirtualStreamerInfo::kOffsetL;
-   fNewType = fType;
+   if (dim) {
+      fType += TVirtualStreamerInfo::kOffsetL;
+      fNewType += TVirtualStreamerInfo::kOffsetL;
+   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -673,8 +676,11 @@ TClass *TStreamerBase::GetClassPointer() const
 
 Int_t TStreamerBase::GetSize() const
 {
-   TClass *cl = GetClassPointer();
-   if (cl) return cl->Size();
+   TClass *cl = GetNewClass();
+   if (!cl)
+      cl = GetClassPointer();
+   if (cl)
+      return cl->Size();
    return 0;
 }
 
@@ -1278,10 +1284,14 @@ const char *TStreamerObject::GetInclude() const
 
 Int_t TStreamerObject::GetSize() const
 {
-   TClass *cl = GetClassPointer();
+   TClass *cl = GetNewClass();
+   if (!cl)
+      cl = GetClassPointer();
    Int_t classSize = 8;
-   if (cl) classSize = cl->Size();
-   if (fArrayLength) return fArrayLength*classSize;
+   if (cl)
+      classSize = cl->Size();
+   if (fArrayLength)
+      return fArrayLength * classSize;
    return classSize;
 }
 
@@ -1371,10 +1381,14 @@ const char *TStreamerObjectAny::GetInclude() const
 
 Int_t TStreamerObjectAny::GetSize() const
 {
-   TClass *cl = GetClassPointer();
+   TClass *cl = GetNewClass();
+   if (!cl)
+      cl = GetClassPointer();
    Int_t classSize = 8;
-   if (cl) classSize = cl->Size();
-   if (fArrayLength) return fArrayLength*classSize;
+   if (cl)
+      classSize = cl->Size();
+   if (fArrayLength)
+      return fArrayLength * classSize;
    return classSize;
 }
 
@@ -1683,7 +1697,7 @@ ClassImp(TStreamerSTL);
 ////////////////////////////////////////////////////////////////////////////////
 /// Default ctor.
 
-TStreamerSTL::TStreamerSTL() : fSTLtype(0),fCtype(0)
+TStreamerSTL::TStreamerSTL() : fSTLtype(0), fCtype(0)
 {
 }
 
@@ -1694,7 +1708,10 @@ TStreamerSTL::TStreamerSTL(const char *name, const char *title, Int_t offset,
                            const char *typeName, const TVirtualCollectionProxy &proxy, Bool_t dmPointer)
         : TStreamerElement(name,title,offset,ROOT::kSTLany,typeName)
 {
-   fTypeName = TClassEdit::ShortType(fTypeName,TClassEdit::kDropStlDefault).c_str();
+   std::string answer;
+   TClassEdit::TSplitType arglist(fTypeName, TClassEdit::kDropStlDefault);
+   arglist.ShortType(answer, TClassEdit::kDropStlDefault);
+   fTypeName = answer;
 
   if (name==typeName /* intentional pointer comparison */
       || strcmp(name,typeName)==0) {
@@ -1714,8 +1731,15 @@ TStreamerSTL::TStreamerSTL(const char *name, const char *title, Int_t offset,
    } else {
       fCtype = proxy.GetType();
       if (proxy.HasPointers()) fCtype += TVirtualStreamerInfo::kOffsetP;
+      auto enumdesc = TEnum::GetEnum(arglist.fElements[1].c_str());
+      if (enumdesc || gCling->ClassInfo_IsEnum(arglist.fElements[1].c_str())) {
+         fCtype = enumdesc ? enumdesc->GetUnderlyingType() : 3;
+      }
+   }
+   if (TStreamerSTL::IsaPointer()) {
+      fType = TVirtualStreamerInfo::kSTLp;
+      fNewType = fType;
    }
-   if (TStreamerSTL::IsaPointer()) fType = TVirtualStreamerInfo::kSTLp;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1776,8 +1800,11 @@ TStreamerSTL::TStreamerSTL(const char *name, const char *title, Int_t offset,
          if (isPointer) fCtype = TVirtualStreamerInfo::kObjectp;
          else           fCtype = TVirtualStreamerInfo::kObject;
       } else {
-         if (gCling->ClassInfo_IsEnum(intype.c_str())) {
-            if (isPointer) fCtype += TVirtualStreamerInfo::kOffsetP;
+         auto enumdesc = TEnum::GetEnum(intype.c_str());
+         if (enumdesc || gCling->ClassInfo_IsEnum(intype.c_str())) {
+            fCtype = enumdesc ? enumdesc->GetUnderlyingType() : 3;
+            if (isPointer)
+               fCtype += TVirtualStreamerInfo::kOffsetP;
          } else {
             if (intype != "string") {
                // This case can happens when 'this' is a TStreamerElement for
@@ -1794,7 +1821,10 @@ TStreamerSTL::TStreamerSTL(const char *name, const char *title, Int_t offset,
       }
    }
 
-   if (TStreamerSTL::IsaPointer()) fType = TVirtualStreamerInfo::kSTLp;
+   if (TStreamerSTL::IsaPointer()) {
+      fType = TVirtualStreamerInfo::kSTLp;
+      fNewType = fType;
+   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1844,6 +1874,39 @@ Bool_t TStreamerSTL::IsBase() const
    if (strcmp(ts.Data(),GetTypeNameBasic())==0) return kTRUE;
    return kFALSE;
 }
+
+////////////////////////////////////////////////////////////////////////////////
+/// Returns a pointer to the TClass of this element.
+
+TClass *TStreamerSTL::GetClassPointer() const
+{
+   if (fClassObject!=(TClass*)(-1))
+      return fClassObject;
+
+   bool quiet = (fType == TVirtualStreamerInfo::kArtificial);
+
+   TString className(ExtractClassName(fTypeName));
+   TClass *cl = TClass::GetClass(className, kTRUE, quiet);
+
+   auto proxy = cl->GetCollectionProxy();
+   if (!fNewClass && proxy && proxy->GetValueClass() == nullptr) {
+      // Collection of numerical type, let check if it is an enum.
+      TClassEdit::TSplitType arglist(fTypeName, TClassEdit::kDropStlDefault);
+      if ( arglist.fElements[1].size() >= 2 ) {
+         auto enumdesc = TEnum::GetEnum(arglist.fElements[1].c_str());
+         if (enumdesc || gCling->ClassInfo_IsEnum(arglist.fElements[1].c_str())) {
+            ((TStreamerElement *)this)->fNewClass = cl;
+            if (proxy->HasPointers())
+               cl = TClass::GetClass("vector<Int_t*>");
+            else
+               cl = TClass::GetClass("vector<Int_t>");
+         }
+      }
+   }
+   ((TStreamerElement*)this)->fClassObject = cl;
+   return fClassObject;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 /// Returns size of STL container in bytes.
 
@@ -1852,7 +1915,9 @@ Int_t TStreamerSTL::GetSize() const
    // Since the STL collection might or might not be emulated and that the
    // sizeof the object depends on this, let's just always retrieve the
    // current size!
-   TClass *cl = GetClassPointer();
+   TClass *cl = GetNewClass();
+   if (!cl)
+      cl = GetClassPointer();
    UInt_t size = 0;
    if (cl==nullptr) {
       if (!TestBit(kWarned)) {
