@@ -201,7 +201,7 @@ public: // Public Interface
    Int_t   AutoLoad(const std::type_info& typeinfo, Bool_t knowDictNotLoaded = kFALSE) final;
    Int_t   AutoParse(const char* cls) final;
    void*   LazyFunctionCreatorAutoload(const std::string& mangled_name);
-   bool   LibraryLoadingFailed(const std::string&, const std::string&, bool, bool);
+   bool    LibraryLoadingFailed(const std::string&, const std::string&, bool, bool);
    Bool_t  IsAutoLoadNamespaceCandidate(const clang::NamespaceDecl* nsDecl);
    void    ClearFileBusy() final;
    void    ClearStack() final; // Delete existing temporary values
@@ -216,7 +216,7 @@ public: // Public Interface
    Int_t   GenerateDictionary(const char* classes, const char* includes = "", const char* options = nullptr) final;
    char*   GetPrompt() final { return fPrompt; }
    const char* GetSharedLibs() final;
-   const char* GetClassSharedLibs(const char* cls) final;
+   const char* GetClassSharedLibs(const char* cls, bool skipCore = true) final;
    const char* GetSharedLibDeps(const char* lib, bool tryDyld = false) final;
    const char* GetIncludePath() final;
    virtual const char* GetSTLIncludePath() const final;
@@ -227,6 +227,7 @@ public: // Public Interface
    void    InspectMembers(TMemberInspector&, const void* obj, const TClass* cl, Bool_t isTransient) final;
    Bool_t  IsLoaded(const char* filename) const final;
    Bool_t  IsLibraryLoaded(const char* libname) const final;
+   bool    IsValid() const final;
    Bool_t  HasPCMForLibrary(const char *libname) const final;
    Int_t   Load(const char* filenam, Bool_t system = kFALSE) final;
    void    LoadMacro(const char* filename, EErrorCode* error = nullptr) final;
@@ -573,8 +574,6 @@ public: // Public Interface
    bool IsPointerType(const void * QualTypePtr) const;
    bool IsVoidPointerType(const void * QualTypePtr) const;
 
-   // FunctionDecl interface 
-   bool FunctionDeclId_IsMethod(DeclId_t fdeclid) const;
 
    std::set<TClass*>& GetModTClasses() { return fModTClasses; }
 
