@@ -79,10 +79,6 @@ using std::string, std::map, std::ostringstream, std::make_pair;
 static unsigned long long gWrapperSerial = 0LL;
 static const string kIndentString("   ");
 
-static map<const Decl *, void *> gWrapperStore;
-static map<const Decl *, void *> gCtorWrapperStore;
-static map<const Decl *, void *> gDtorWrapperStore;
-
 static
 inline
 void
@@ -155,6 +151,25 @@ static void GetTypeAsString(QualType QT, string& type_name, ASTContext &C,
    QT.getAsStringInternal(type_name, Policy);
 }
 
+static void GetDeclName(const clang::Decl *D, ASTContext &Context, std::string &name)
+{
+   // Helper to extract a fully qualified name from a Decl
+
+   PrintingPolicy Policy(Context.getPrintingPolicy());
+   Policy.SuppressTagKeyword = true;
+   Policy.SuppressUnwrittenScope = true;
+   if (const TypeDecl *TD = dyn_cast<TypeDecl>(D)) {
+      // This is a class, struct, or union member.
+      QualType QT(TD->getTypeForDecl(), 0);
+      GetTypeAsString(QT, name, Context, Policy);
+   } else if (const NamedDecl *ND = dyn_cast<NamedDecl>(D)) {
+      // This is a namespace member.
+      raw_string_ostream stream(name);
+      ND->getNameForDiagnostic(stream, Policy, /*Qualified=*/true);
+      stream.flush();
+   }
+}
+
 void TClingCallFunc::collect_type_info(QualType &QT, ostringstream &typedefbuf, std::ostringstream &callbuf,
                                        string &type_name, EReferenceType &refType, bool &isPointer, int indent_level,
                                        bool forArgument)
@@ -181,9 +196,7 @@ void TClingCallFunc::collect_type_info(QualType &QT, ostringstream &typedefbuf,
          QT.print(OS, Policy, type_name);
          OS.flush();
       }
-      for (int i = 0; i < indent_level; ++i) {
-         typedefbuf << kIndentString;
-      }
+      indent(typedefbuf, indent_level);
       typedefbuf << "typedef " << fp_typedef_name << ";\n";
       return;
    } else if (QT->isMemberPointerType()) {
@@ -196,9 +209,7 @@ void TClingCallFunc::collect_type_info(QualType &QT, ostringstream &typedefbuf,
          QT.print(OS, Policy, type_name);
          OS.flush();
       }
-      for (int i = 0; i < indent_level; ++i) {
-         typedefbuf << kIndentString;
-      }
+      indent(typedefbuf, indent_level);
       typedefbuf << "typedef " << mp_typedef_name << ";\n";
       return;
    } else if (QT->isPointerType()) {
@@ -220,15 +231,40 @@ void TClingCallFunc::collect_type_info(QualType &QT, ostringstream &typedefbuf,
          QT.print(OS, Policy, type_name);
          OS.flush();
       }
-      for (int i = 0; i < indent_level; ++i) {
-         typedefbuf << kIndentString;
-      }
+      indent(typedefbuf, indent_level);
       typedefbuf << "typedef " << ar_typedef_name << ";\n";
       return;
    }
    GetTypeAsString(QT, type_name, C, Policy);
 }
 
+static bool IsCopyConstructorDeleted(QualType QT)
+{
+   CXXRecordDecl *RD = QT->getAsCXXRecordDecl();
+   if (!RD) {
+      // For types that are not C++ records (such as PODs), we assume that they are copyable, ie their copy constructor
+      // is not deleted.
+      return false;
+   }
+
+   RD = RD->getDefinition();
+   assert(RD && "expecting a definition");
+
+   if (RD->hasSimpleCopyConstructor())
+      return false;
+
+   for (auto *Ctor : RD->ctors()) {
+      if (Ctor->isCopyConstructor()) {
+         return Ctor->isDeleted();
+      }
+   }
+
+   assert(0 && "did not find a copy constructor?");
+   // Should never happen and the return value is somewhat arbitrary, but we did not see a deleted copy ctor. The user
+   // will be told if the generated code doesn't compile.
+   return false;
+}
+
 void TClingCallFunc::make_narg_ctor(const unsigned N, ostringstream &typedefbuf,
                                     ostringstream &callbuf, const string &class_name,
                                     int indent_level)
@@ -240,6 +276,10 @@ void TClingCallFunc::make_narg_ctor(const unsigned N, ostringstream &typedefbuf,
    const FunctionDecl *FD = GetDecl();
 
    callbuf << "new " << class_name << "(";
+
+   // IsCopyConstructorDeleted could trigger deserialization of decls.
+   cling::Interpreter::PushTransactionRAII RAII(fInterp);
+
    for (unsigned i = 0U; i < N; ++i) {
       const ParmVarDecl *PVD = FD->getParamDecl(i);
       QualType Ty = PVD->getType();
@@ -255,9 +295,7 @@ void TClingCallFunc::make_narg_ctor(const unsigned N, ostringstream &typedefbuf,
             callbuf << ' ';
          } else {
             callbuf << "\n";
-            for (int j = 0; j <= indent_level; ++j) {
-               callbuf << kIndentString;
-            }
+            indent(callbuf, indent_level + 1);
          }
       }
       if (refType != kNotReference) {
@@ -268,7 +306,17 @@ void TClingCallFunc::make_narg_ctor(const unsigned N, ostringstream &typedefbuf,
          callbuf << "*(" << type_name.c_str() << "**)args["
                  << i << "]";
       } else {
+         // By-value construction: Figure out if the type can be copy-constructed. This is tricky and cannot be done in
+         // a fully reliable way, also because std::vector<T> always defines a copy constructor, even if the type T is
+         // only moveable. As a heuristic, we only check if the copy constructor is deleted, or would be if implicit.
+         bool Move = IsCopyConstructorDeleted(QT);
+         if (Move) {
+            callbuf << "static_cast<" << type_name << "&&>(";
+         }
          callbuf << "*(" << type_name.c_str() << "*)args[" << i << "]";
+         if (Move) {
+            callbuf << ")";
+         }
       }
    }
    callbuf << ")";
@@ -309,9 +357,7 @@ void TClingCallFunc::make_narg_call(const std::string &return_type, const unsign
                   callbuf << ' ';
                } else {
                   callbuf << "\n";
-                  for (int j = 0; j <= indent_level; ++j) {
-                     callbuf << kIndentString;
-                  }
+                  indent(callbuf, indent_level + 1);
                }
             }
             const ParmVarDecl *PVD = FD->getParamDecl(i);
@@ -354,6 +400,10 @@ void TClingCallFunc::make_narg_call(const std::string &return_type, const unsign
    if (ShouldCastFunction) callbuf << ")";
 
    callbuf << "(";
+
+   // IsCopyConstructorDeleted could trigger deserialization of decls.
+   cling::Interpreter::PushTransactionRAII RAII(fInterp);
+
    for (unsigned i = 0U; i < N; ++i) {
       const ParmVarDecl *PVD = FD->getParamDecl(i);
       QualType Ty = PVD->getType();
@@ -369,9 +419,7 @@ void TClingCallFunc::make_narg_call(const std::string &return_type, const unsign
             callbuf << ' ';
          } else {
             callbuf << "\n";
-            for (int j = 0; j <= indent_level; ++j) {
-               callbuf << kIndentString;
-            }
+            indent(callbuf, indent_level + 1);
          }
       }
 
@@ -383,9 +431,17 @@ void TClingCallFunc::make_narg_call(const std::string &return_type, const unsign
          callbuf << "*(" << type_name.c_str() << "**)args["
                  << i << "]";
       } else {
-         // pointer falls back to non-pointer case; the argument preserves
-         // the "pointerness" (i.e. doesn't reference the value).
+         // By-value construction: Figure out if the type can be copy-constructed. This is tricky and cannot be done in
+         // a fully reliable way, also because std::vector<T> always defines a copy constructor, even if the type T is
+         // only moveable. As a heuristic, we only check if the copy constructor is deleted, or would be if implicit.
+         bool Move = IsCopyConstructorDeleted(QT);
+         if (Move) {
+            callbuf << "static_cast<" << type_name << "&&>(";
+         }
          callbuf << "*(" << type_name.c_str() << "*)args[" << i << "]";
+         if (Move) {
+            callbuf << ")";
+         }
       }
    }
    callbuf << ")";
@@ -403,9 +459,7 @@ void TClingCallFunc::make_narg_ctor_with_return(const unsigned N, const string &
    //    new ClassName(args...);
    // }
    //
-   for (int i = 0; i < indent_level; ++i) {
-      buf << kIndentString;
-   }
+   indent(buf, indent_level);
    buf << "if (ret) {\n";
    ++indent_level;
    {
@@ -414,9 +468,7 @@ void TClingCallFunc::make_narg_ctor_with_return(const unsigned N, const string &
       //
       //  Write the return value assignment part.
       //
-      for (int i = 0; i < indent_level; ++i) {
-         callbuf << kIndentString;
-      }
+      indent(callbuf, indent_level);
       callbuf << "(*(" << class_name << "**)ret) = ";
       //
       //  Write the actual new expression.
@@ -426,9 +478,7 @@ void TClingCallFunc::make_narg_ctor_with_return(const unsigned N, const string &
       //  End the new expression statement.
       //
       callbuf << ";\n";
-      for (int i = 0; i < indent_level; ++i) {
-         callbuf << kIndentString;
-      }
+      indent(callbuf, indent_level);
       callbuf << "return;\n";
       //
       //  Output the whole new expression and return statement.
@@ -481,23 +531,13 @@ int TClingCallFunc::get_wrapper_code(std::string &wrapper_name, std::string &wra
 {
    const FunctionDecl *FD = GetDecl();
    assert(FD && "generate_wrapper called without a function decl!");
-   ASTContext &Context = FD->getASTContext();
-   PrintingPolicy Policy(Context.getPrintingPolicy());
    //
    //  Get the class or namespace name.
    //
    string class_name;
+   ASTContext &Context = FD->getASTContext();
    const clang::DeclContext *DC = GetDeclContext();
-   if (const TypeDecl *TD = dyn_cast<TypeDecl>(DC)) {
-      // This is a class, struct, or union member.
-      QualType QT(TD->getTypeForDecl(), 0);
-      GetTypeAsString(QT, class_name, Context, Policy);
-   } else if (const NamedDecl *ND = dyn_cast<NamedDecl>(DC)) {
-      // This is a namespace member.
-      raw_string_ostream stream(class_name);
-      ND->getNameForDiagnostic(stream, Policy, /*Qualified=*/true);
-      stream.flush();
-   }
+   GetDeclName(cast<Decl>(DC), Context, class_name);
    //
    //  Check to make sure that we can
    //  instantiate and codegen this function.
@@ -842,16 +882,12 @@ int TClingCallFunc::get_wrapper_code(std::string &wrapper_name, std::string &wra
       // We need one function call clause compiled for every
       // possible number of arguments per call.
       for (unsigned N = min_args; N <= num_params; ++N) {
-         for (int i = 0; i < indent_level; ++i) {
-            buf << kIndentString;
-         }
+         indent(buf, indent_level);
          buf << "if (nargs == " << N << ") {\n";
          ++indent_level;
          make_narg_call_with_return(N, class_name, buf, indent_level);
          --indent_level;
-         for (int i = 0; i < indent_level; ++i) {
-            buf << kIndentString;
-         }
+         indent(buf, indent_level);
          buf << "}\n";
       }
    }
@@ -895,20 +931,14 @@ void TClingCallFunc::make_narg_call_with_return(const unsigned N, const string &
    if (QT->isVoidType()) {
       ostringstream typedefbuf;
       ostringstream callbuf;
-      for (int i = 0; i < indent_level; ++i) {
-         callbuf << kIndentString;
-      }
+      indent(callbuf, indent_level);
       make_narg_call("void", N, typedefbuf, callbuf, class_name, indent_level);
       callbuf << ";\n";
-      for (int i = 0; i < indent_level; ++i) {
-         callbuf << kIndentString;
-      }
+      indent(callbuf, indent_level);
       callbuf << "return;\n";
       buf << typedefbuf.str() << callbuf.str();
    } else {
-      for (int i = 0; i < indent_level; ++i) {
-         buf << kIndentString;
-      }
+      indent(buf, indent_level);
 
       string type_name;
       EReferenceType refType = kNotReference;
@@ -922,9 +952,7 @@ void TClingCallFunc::make_narg_call_with_return(const unsigned N, const string &
          //
          //  Write the placement part of the placement new.
          //
-         for (int i = 0; i < indent_level; ++i) {
-            callbuf << kIndentString;
-         }
+         indent(callbuf, indent_level);
          callbuf << "new (ret) ";
          collect_type_info(QT, typedefbuf, callbuf, type_name,
                            refType, isPointer, indent_level, false);
@@ -949,9 +977,7 @@ void TClingCallFunc::make_narg_call_with_return(const unsigned N, const string &
          //  End the placement new.
          //
          callbuf << ");\n";
-         for (int i = 0; i < indent_level; ++i) {
-            callbuf << kIndentString;
-         }
+         indent(callbuf, indent_level);
          callbuf << "return;\n";
          //
          //  Output the whole placement new expression and return statement.
@@ -959,43 +985,40 @@ void TClingCallFunc::make_narg_call_with_return(const unsigned N, const string &
          buf << typedefbuf.str() << callbuf.str();
       }
       --indent_level;
-      for (int i = 0; i < indent_level; ++i) {
-         buf << kIndentString;
-      }
+      indent(buf, indent_level);
       buf << "}\n";
-      for (int i = 0; i < indent_level; ++i) {
-         buf << kIndentString;
-      }
+      indent(buf, indent_level);
       buf << "else {\n";
       ++indent_level;
       {
          ostringstream typedefbuf;
          ostringstream callbuf;
-         for (int i = 0; i < indent_level; ++i) {
-            callbuf << kIndentString;
-         }
+         indent(callbuf, indent_level);
          callbuf << "(void)(";
          make_narg_call(type_name, N, typedefbuf, callbuf, class_name, indent_level);
          callbuf << ");\n";
-         for (int i = 0; i < indent_level; ++i) {
-            callbuf << kIndentString;
-         }
+         indent(callbuf, indent_level);
          callbuf << "return;\n";
          buf << typedefbuf.str() << callbuf.str();
       }
       --indent_level;
-      for (int i = 0; i < indent_level; ++i) {
-         buf << kIndentString;
-      }
+      indent(buf, indent_level);
       buf << "}\n";
    }
 }
 
 tcling_callfunc_Wrapper_t TClingCallFunc::make_wrapper()
 {
+   static map<const Decl *, void *> gWrapperStore;
+
    R__LOCKGUARD_CLING(gInterpreterMutex);
 
    const Decl *D = GetFunctionOrShadowDecl();
+
+   auto I = gWrapperStore.find(D);
+   if (I != gWrapperStore.end())
+      return (tcling_callfunc_Wrapper_t)I->second;
+
    string wrapper_name;
    string wrapper;
 
@@ -1016,6 +1039,32 @@ tcling_callfunc_Wrapper_t TClingCallFunc::make_wrapper()
    return (tcling_callfunc_Wrapper_t)F;
 }
 
+static std::string PrepareStructorWrapper(const Decl *D, const char *wrapper_prefix, std::string &class_name)
+{
+   //
+   //  Get the class or namespace name.
+   //
+   ASTContext &Context = D->getASTContext();
+   GetDeclName(D, Context, class_name);
+
+   //
+   //  Make the wrapper name.
+   //
+   string wrapper_name;
+   {
+      ostringstream buf;
+      buf << wrapper_prefix;
+      // const NamedDecl* ND = dyn_cast<NamedDecl>(FD);
+      // string mn;
+      // fInterp->maybeMangleDeclName(ND, mn);
+      // buf << '_dtor_' << mn;
+      buf << '_' << gWrapperSerial++;
+      wrapper_name = buf.str();
+   }
+
+   return wrapper_name;
+}
+
 tcling_callfunc_ctor_Wrapper_t TClingCallFunc::make_ctor_wrapper(const TClingClassInfo *info,
       ROOT::TMetaUtils::EIOCtorCategory kind, const std::string &type_name)
 {
@@ -1087,40 +1136,21 @@ tcling_callfunc_ctor_Wrapper_t TClingCallFunc::make_ctor_wrapper(const TClingCla
    // CINT did.
    //
    //--
-   ASTContext &Context = info->GetDecl()->getASTContext();
-   PrintingPolicy Policy(Context.getPrintingPolicy());
-   Policy.SuppressTagKeyword = true;
-   Policy.SuppressUnwrittenScope = true;
-   //
-   //  Get the class or namespace name.
-   //
-   string class_name;
-   if (const TypeDecl *TD = dyn_cast<TypeDecl>(info->GetDecl())) {
-      // This is a class, struct, or union member.
-      QualType QT(TD->getTypeForDecl(), 0);
-      GetTypeAsString(QT, class_name, Context, Policy);
-   } else if (const NamedDecl *ND = dyn_cast<NamedDecl>(info->GetDecl())) {
-      // This is a namespace member.
-      raw_string_ostream stream(class_name);
-      ND->getNameForDiagnostic(stream, Policy, /*Qualified=*/true);
-      stream.flush();
-   }
 
+   static map<const Decl *, void *> gCtorWrapperStore;
+
+   R__LOCKGUARD_CLING(gInterpreterMutex);
+
+   auto D = info->GetDecl();
+   auto I = gCtorWrapperStore.find(D);
+   if (I != gCtorWrapperStore.end())
+      return (tcling_callfunc_ctor_Wrapper_t)I->second;
 
    //
    //  Make the wrapper name.
    //
-   string wrapper_name;
-   {
-      ostringstream buf;
-      buf << "__ctor";
-      //const NamedDecl* ND = dyn_cast<NamedDecl>(FD);
-      //string mn;
-      //fInterp->maybeMangleDeclName(ND, mn);
-      //buf << '_dtor_' << mn;
-      buf << '_' << gWrapperSerial++;
-      wrapper_name = buf.str();
-   }
+   string class_name;
+   string wrapper_name = PrepareStructorWrapper(D, "__ctor", class_name);
 
    string constr_arg;
    if (kind == ROOT::TMetaUtils::EIOCtorCategory::kIOPtrType)
@@ -1217,7 +1247,7 @@ tcling_callfunc_ctor_Wrapper_t TClingCallFunc::make_ctor_wrapper(const TClingCla
    void *F = compile_wrapper(wrapper_name, wrapper,
                              /*withAccessControl=*/false);
    if (F) {
-      gCtorWrapperStore.insert(make_pair(info->GetDecl(), F));
+      gCtorWrapperStore.insert(make_pair(D, F));
    } else {
       ::Error("TClingCallFunc::make_ctor_wrapper",
             "Failed to compile\n  ==== SOURCE BEGIN ====\n%s\n  ==== SOURCE END ====",
@@ -1256,38 +1286,21 @@ TClingCallFunc::make_dtor_wrapper(const TClingClassInfo *info)
    // }
    //
    //--
-   ASTContext &Context = info->GetDecl()->getASTContext();
-   PrintingPolicy Policy(Context.getPrintingPolicy());
-   Policy.SuppressTagKeyword = true;
-   Policy.SuppressUnwrittenScope = true;
-   //
-   //  Get the class or namespace name.
-   //
-   string class_name;
-   if (const TypeDecl *TD = dyn_cast<TypeDecl>(info->GetDecl())) {
-      // This is a class, struct, or union member.
-      QualType QT(TD->getTypeForDecl(), 0);
-      GetTypeAsString(QT, class_name, Context, Policy);
-   } else if (const NamedDecl *ND = dyn_cast<NamedDecl>(info->GetDecl())) {
-      // This is a namespace member.
-      raw_string_ostream stream(class_name);
-      ND->getNameForDiagnostic(stream, Policy, /*Qualified=*/true);
-      stream.flush();
-   }
+
+   static map<const Decl *, void *> gDtorWrapperStore;
+
+   R__LOCKGUARD_CLING(gInterpreterMutex);
+
+   const Decl *D = info->GetDecl();
+   auto I = gDtorWrapperStore.find(D);
+   if (I != gDtorWrapperStore.end())
+      return (tcling_callfunc_dtor_Wrapper_t)I->second;
+
    //
    //  Make the wrapper name.
    //
-   string wrapper_name;
-   {
-      ostringstream buf;
-      buf << "__dtor";
-      //const NamedDecl* ND = dyn_cast<NamedDecl>(FD);
-      //string mn;
-      //fInterp->maybeMangleDeclName(ND, mn);
-      //buf << '_dtor_' << mn;
-      buf << '_' << gWrapperSerial++;
-      wrapper_name = buf.str();
-   }
+   std::string class_name;
+   string wrapper_name = PrepareStructorWrapper(D, "__dtor", class_name);
    //
    //  Write the wrapper code.
    //
@@ -1381,7 +1394,7 @@ TClingCallFunc::make_dtor_wrapper(const TClingClassInfo *info)
    void *F = compile_wrapper(wrapper_name, wrapper,
                              /*withAccessControl=*/false);
    if (F) {
-      gDtorWrapperStore.insert(make_pair(info->GetDecl(), F));
+      gDtorWrapperStore.insert(make_pair(D, F));
    } else {
       ::Error("TClingCallFunc::make_dtor_wrapper",
             "Failed to compile\n  ==== SOURCE BEGIN ====\n%s\n  ==== SOURCE END ====",
@@ -1596,10 +1609,7 @@ void *TClingCallFunc::ExecDefaultConstructor(const TClingClassInfo *info,
       ::Error("TClingCallFunc::ExecDefaultConstructor", "Invalid class info!");
       return nullptr;
    }
-   tcling_callfunc_ctor_Wrapper_t wrapper = nullptr;
-   {
-      R__LOCKGUARD_CLING(gInterpreterMutex);
-      auto D = info->GetDecl();
+   if (tcling_callfunc_ctor_Wrapper_t wrapper = make_ctor_wrapper(info, kind, type_name)) {
       //if (!info->HasDefaultConstructor()) {
       //   // FIXME: We might have a ROOT ioctor, we might
       //   //        have to check for that here.
@@ -1608,21 +1618,12 @@ void *TClingCallFunc::ExecDefaultConstructor(const TClingClassInfo *info,
       //         info->Name());
       //   return 0;
       //}
-      auto I = gCtorWrapperStore.find(D);
-      if (I != gCtorWrapperStore.end()) {
-         wrapper = (tcling_callfunc_ctor_Wrapper_t) I->second;
-      } else {
-         wrapper = make_ctor_wrapper(info, kind, type_name);
-      }
+      void *obj = nullptr;
+      (*wrapper)(&obj, address, nary);
+      return obj;
    }
-   if (!wrapper) {
-      ::Error("TClingCallFunc::ExecDefaultConstructor",
-            "Called with no wrapper, not implemented!");
-      return nullptr;
-   }
-   void *obj = nullptr;
-   (*wrapper)(&obj, address, nary);
-   return obj;
+   ::Error("TClingCallFunc::ExecDefaultConstructor", "Called with no wrapper, not implemented!");
+   return nullptr;
 }
 
 void TClingCallFunc::ExecDestructor(const TClingClassInfo *info, void *address /*=0*/,
@@ -1633,23 +1634,12 @@ void TClingCallFunc::ExecDestructor(const TClingClassInfo *info, void *address /
       return;
    }
 
-   tcling_callfunc_dtor_Wrapper_t wrapper = nullptr;
-   {
-      R__LOCKGUARD_CLING(gInterpreterMutex);
-      const Decl *D = info->GetDecl();
-      map<const Decl *, void *>::iterator I = gDtorWrapperStore.find(D);
-      if (I != gDtorWrapperStore.end()) {
-         wrapper = (tcling_callfunc_dtor_Wrapper_t) I->second;
-      } else {
-         wrapper = make_dtor_wrapper(info);
-      }
-   }
-   if (!wrapper) {
-      ::Error("TClingCallFunc::ExecDestructor",
-            "Called with no wrapper, not implemented!");
+   if (tcling_callfunc_dtor_Wrapper_t wrapper = make_dtor_wrapper(info)) {
+      (*wrapper)(address, nary, withFree);
       return;
    }
-   (*wrapper)(address, nary, withFree);
+
+   ::Error("TClingCallFunc::ExecDestructor", "Called with no wrapper, not implemented!");
 }
 
 TClingMethodInfo *
@@ -1684,20 +1674,10 @@ void *TClingCallFunc::InterfaceMethod()
    if (!IsValid()) {
       return nullptr;
    }
-   if (!fWrapper) {
-      const Decl *decl = GetFunctionOrShadowDecl();
 
-      R__LOCKGUARD_CLING(gInterpreterMutex);
-      // check if another thread already did it
-      if (!fWrapper) {
-         map<const Decl *, void *>::iterator I = gWrapperStore.find(decl);
-         if (I != gWrapperStore.end()) {
-            fWrapper = (tcling_callfunc_Wrapper_t)I->second;
-         } else {
-            fWrapper = make_wrapper();
-         }
-      }
-   }
+   if (!fWrapper)
+      fWrapper = make_wrapper();
+
    return (void *)fWrapper.load();
 }
 
@@ -1716,20 +1696,10 @@ TInterpreter::CallFuncIFacePtr_t TClingCallFunc::IFacePtr()
             "Attempt to get interface while invalid.");
       return TInterpreter::CallFuncIFacePtr_t();
    }
-   if (!fWrapper) {
-      const Decl *decl = GetFunctionOrShadowDecl();
 
-      R__LOCKGUARD_CLING(gInterpreterMutex);
-      // check if another thread already did it
-      if (!fWrapper) {
-         map<const Decl *, void *>::iterator I = gWrapperStore.find(decl);
-         if (I != gWrapperStore.end()) {
-            fWrapper = (tcling_callfunc_Wrapper_t)I->second;
-         } else {
-            fWrapper = make_wrapper();
-         }
-      }
-   }
+   if (!fWrapper)
+      fWrapper = make_wrapper();
+
    return TInterpreter::CallFuncIFacePtr_t(fWrapper);
 }
 
