@@ -30,17 +30,17 @@
 /// \file
 /// \ingroup tutorial_hist
 /// \notebook
-/// Getting Contours From TH2D.
+/// \preview Getting Contours From TH2D.
 ///
-/// #### Image produced by `.x ContourList.C`
+/// #### Image produced by `.x hist102_TH2_contour_list.C`
 /// The contours values are drawn next to each contour.
 /// \macro_image
 ///
-/// #### Output produced by `.x ContourList.C`
+/// #### Output produced by `.x hist102_TH2_contour_list.C`
 /// It shows that 6 contours and 12 graphs were found.
 /// \macro_output
 ///
-/// #### `ContourList.C`
+/// #### `hist102_TH2_contour_list.C`
 /// \macro_code
 ///
 /// \authors  Josh de Bever, Olivier Couet
@@ -68,8 +68,16 @@
 ///    To generate the corresponding jupyter notebook. In case the tutorial does
 ///    not generate any graphics output, the option `-nodraw` should be added.
 ///
+///  5. `\preview`
+///    To display the first image generated by the tutorial as an icon in the list of tutorials.
+///
 /// Note that the doxygen directive `\authors` or `\author` must be the last one
 /// of the macro header.
+///
+/// ## In the Python doc files
+///
+/// The two tags `\pythondoc` and `\endpythondoc` should be used to start and finish
+/// python documentation.
 
 #include <unistd.h>
 #include <stdio.h>
@@ -81,12 +89,16 @@
 #include <stdarg.h>
 #include <memory>
 
-using std::string, std::ios_base, std::unique_ptr;
+using std::string;
+using std::ios_base;
+using std::unique_ptr;
 
 // Auxiliary functions
 void   FilterClass();
 void   FilterTutorial();
+void   FilterPythonBox();
 void   GetClassName();
+void   CreateTutorialImage(bool);
 int    NumberOfImages();
 string ImagesList(string&);
 void   ExecuteMacro();
@@ -114,6 +126,7 @@ string gOutputName;    // File containing a macro std::out
 bool   gHeader;        // True if the input file is a header
 bool   gSource;        // True if the input file is a source file
 bool   gPython;        // True if the input file is a Python script.
+bool   gImageGenerated;// True if the PNG image has been generated.
 bool   gImageSource;   // True the source of the current macro should be shown
 int    gInMacro;       // >0 if parsing a macro in a class documentation.
 int    gImageID;       // Image Identifier.
@@ -131,6 +144,7 @@ int main(int argc, char *argv[])
    gSource        = false;
    gPython        = false;
    gImageSource   = false;
+   gImageGenerated= false;
    gInMacro       = 0;
    gImageID       = 0;
    gMacroID       = 0;
@@ -162,8 +176,38 @@ int main(int argc, char *argv[])
    f = fopen(gFileName.c_str(),"r");
    if (!f) return 1;
 
-   if (gFileName.find("tutorials") != string::npos) FilterTutorial();
-   else                                             FilterClass();
+   if      (gFileName.find("tutorials") != string::npos) FilterTutorial();
+   else if (gFileName.find("pyzdoc")    != string::npos) FilterPythonBox();
+   else                                                  FilterClass();
+}
+
+////////////////////////////////////////////////////////////////////////////////
+/// Filter ROOT python box for Doxygen.
+
+void FilterPythonBox()
+{
+   while (fgets(gLine,255,f)) {
+      gLineString = gLine;
+      if (gLineString.find("\\pythondoc") != string::npos) {
+         string class_name = gLineString;
+         ReplaceAll(class_name, " ", "");
+         ReplaceAll(class_name, "\\pythondoc", "");
+         ReplaceAll(class_name, "\n", "");
+         gLineString = StringFormat("/**\n\\class %s\n"
+                                    "\\brief \\parblock \\endparblock\n"
+                                    "\\htmlonly\n"
+                                    "<details open>\n"
+                                    "<summary style=\"font-size:20px; color: #425788;\">\n"
+                                    "<b>Python interface</b></summary>\n"
+                                    "<div class=\"pyrootbox\">\n"
+                                    "\\endhtmlonly\n"
+                                    "\\ingroup Pythonizations", class_name.c_str());
+      }
+      if (gLineString.find("\\endpythondoc") != string::npos)
+         ReplaceAll(gLineString, "\\endpythondoc", "\\htmlonly </div> </details> \\endhtmlonly\n*/");
+      printf("%s",gLineString.c_str());
+   }
+   fclose(f);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -299,6 +343,34 @@ void FilterClass()
    fclose(f);
 }
 
+////////////////////////////////////////////////////////////////////////////////
+/// Create PNG tutorial image
+
+void CreateTutorialImage(bool nobatch) {
+   if (gPython) {
+      if (nobatch) {
+         ExecuteCommand(StringFormat("%s makeimage.py %s %s %s 0 1 0",
+                                    gPythonExec.c_str(),
+                                    gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
+      } else {
+         ExecuteCommand(StringFormat("%s makeimage.py %s %s %s 0 1 1",
+                                    gPythonExec.c_str(),
+                                    gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
+      }
+   } else {
+      if (nobatch) {
+         ExecuteCommand(
+            StringFormat("root -l -q \"makeimage.C+O(\\\"%s\\\",\\\"%s\\\",\\\"%s\\\",false,false)\"",
+                         gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
+      } else {
+         ExecuteCommand(
+            StringFormat("root -l -b -q \"makeimage.C+O(\\\"%s\\\",\\\"%s\\\",\\\"%s\\\",false,false)\"",
+                         gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
+      }
+   }
+   gImageGenerated = true;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 /// Filter ROOT tutorials for Doxygen.
 
@@ -324,6 +396,7 @@ void FilterTutorial()
    } else {
       i2 = gFileName.rfind('C');
    }
+   gImageGenerated = false;
    gMacroName  = gFileName.substr(i1,i2-i1+1);
    gImageName  = StringFormat("%s.%s", gMacroName.c_str(), gImageType.c_str()); // Image name
    gOutputName = StringFormat("%s.out", gMacroName.c_str()); // output name
@@ -399,27 +472,7 @@ void FilterTutorial()
                gFileName.c_str(), IN.c_str(), gOutDir.c_str(), gPython));
             ReplaceAll(gLineString, "macro_image", StringFormat("htmlinclude %s.html",IN.c_str()));
          } else {
-            if (gPython) {
-               if (nobatch) {
-                  ExecuteCommand(StringFormat("%s makeimage.py %s %s %s 0 1 0",
-                                             gPythonExec.c_str(),
-                                             gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
-               } else {
-                  ExecuteCommand(StringFormat("%s makeimage.py %s %s %s 0 1 1",
-                                             gPythonExec.c_str(),
-                                             gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
-               }
-            } else {
-               if (nobatch) {
-                  ExecuteCommand(
-                     StringFormat("root -l -q \"makeimage.C+O(\\\"%s\\\",\\\"%s\\\",\\\"%s\\\",false,false)\"",
-                                  gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
-               } else {
-                  ExecuteCommand(
-                     StringFormat("root -l -b -q \"makeimage.C+O(\\\"%s\\\",\\\"%s\\\",\\\"%s\\\",false,false)\"",
-                                  gFileName.c_str(), gImageName.c_str(), gOutDir.c_str()));
-               }
-            }
+            if (!gImageGenerated) CreateTutorialImage(nobatch);
             ReplaceAll(gLineString, "\\macro_image", ImagesList(gImageName));
             remove(gOutputName.c_str());
          }
@@ -432,7 +485,7 @@ void FilterTutorial()
          ReplaceAll(gLineString, "\\macro_code", StringFormat("\\include %s",gMacroName.c_str()));
       }
 
-      // notebook found
+      // \notebook found
       if (gLineString.find("\\notebook") != string::npos) {
          // Notebooks are generated in dedicated step:
          worklist_py << "converttonotebook.py " << gFileName << " " << gOutDir << "/notebooks/" << std::endl;
@@ -446,6 +499,16 @@ void FilterTutorial()
          gLineString += StringFormat( "\\htmlonly <a href=\"https://nbviewer.jupyter.org/url/root.cern/doc/master/notebooks/%s.nbconvert.ipynb\" target=\"_blank\"><img src= notebook.gif alt=\"View in nbviewer\" style=\"height:1.5em\" ></a> <a href=\"https://cern.ch/swanserver/cgi-bin/go?projurl=https://root.cern/doc/master/notebooks/%s.nbconvert.ipynb\" target=\"_blank\"><img src=\"https://swanserver.web.cern.ch/swanserver/images/badge_swan_white_150.png\"  alt=\"Open in SWAN\" style=\"height:1.5em\" ></a> <br/>\\endhtmlonly \n", gMacroName.c_str() , gMacroName.c_str());
       }
 
+      // \preview found
+      if (gLineString.find("\\preview") != string::npos) {
+         if (!gImageGenerated) CreateTutorialImage(false);
+         string name = gMacroName;
+         int width = 150;
+         ReplaceAll(name,"_","__");
+         ReplaceAll(name,".C","_8C.html");
+         ReplaceAll(gLineString, "\\preview", StringFormat("\\htmlonly <a href=\"%s\"><img src=\"pict1_%s.png\" style=\"float: left; margin-right: 10px;\" width=\"%d\"/></a>\\endhtmlonly",name.c_str(),gMacroName.c_str(),width));
+      }
+
       // \macro_output found
       if (gLineString.find("\\macro_output") != string::npos) {
          remove(gOutputName.c_str());
