@@ -20,7 +20,6 @@ Editor for a TGeoCone.
 
 */
 
-
 #include "TGeoConeEditor.h"
 #include "TGeoTabManager.h"
 #include "TGeoCone.h"
@@ -36,19 +35,15 @@ Editor for a TGeoCone.
 
 ClassImp(TGeoConeEditor);
 
-enum ETGeoConeWid {
-   kCONE_NAME, kCONE_RMIN1, kCONE_RMIN2, kCONE_RMAX1, kCONE_RMAX2, kCONE_Z,
-   kCONE_APPLY, kCONE_UNDO
-};
+enum ETGeoConeWid { kCONE_NAME, kCONE_RMIN1, kCONE_RMIN2, kCONE_RMAX1, kCONE_RMAX2, kCONE_Z, kCONE_APPLY, kCONE_UNDO };
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Constructor for volume editor
 
-TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
-                                   Int_t height, UInt_t options, Pixel_t back)
+TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width, Int_t height, UInt_t options, Pixel_t back)
    : TGeoGedFrame(p, width, height, options | kVerticalFrame, back)
 {
-   fShape   = 0;
+   fShape = nullptr;
    fRmini1 = fRmaxi1 = fRmini2 = fRmaxi2 = fDzi = 0.0;
    fNamei = "";
    fIsModified = kFALSE;
@@ -71,19 +66,19 @@ TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
    f1->AddFrame(new TGLabel(f1, "Rmin1"), new TGLayoutHints(kLHintsLeft, 1, 1, 6, 0));
    fERmin1 = new TGNumberEntry(f1, 0., 5, kCONE_RMIN1);
    fERmin1->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fERmin1->GetNumberEntry();
+   nef = (TGTextEntry *)fERmin1->GetNumberEntry();
    nef->SetToolTipText("Enter the inner radius");
    fERmin1->Associate(this);
    fERmin1->Resize(100, fERmin1->GetDefaultHeight());
    f1->AddFrame(fERmin1, new TGLayoutHints(kLHintsRight, 2, 2, 2, 2));
    compxyz->AddFrame(f1, new TGLayoutHints(kLHintsLeft, 2, 2, 0, 0));
 
-  // Number entry for Rmax1
+   // Number entry for Rmax1
    f1 = new TGCompositeFrame(compxyz, 155, 30, kHorizontalFrame | kFixedWidth);
    f1->AddFrame(new TGLabel(f1, "Rmax1"), new TGLayoutHints(kLHintsLeft, 1, 1, 6, 0));
    fERmax1 = new TGNumberEntry(f1, 0., 5, kCONE_RMAX1);
    fERmax1->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fERmax1->GetNumberEntry();
+   nef = (TGTextEntry *)fERmax1->GetNumberEntry();
    nef->SetToolTipText("Enter the outer radius");
    fERmax1->Associate(this);
    fERmax1->Resize(100, fERmax1->GetDefaultHeight());
@@ -95,7 +90,7 @@ TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
    f1->AddFrame(new TGLabel(f1, "Rmin2"), new TGLayoutHints(kLHintsLeft, 1, 1, 6, 0));
    fERmin2 = new TGNumberEntry(f1, 0., 5, kCONE_RMIN2);
    fERmin2->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fERmin2->GetNumberEntry();
+   nef = (TGTextEntry *)fERmin2->GetNumberEntry();
    nef->SetToolTipText("Enter the inner radius");
    fERmin2->Associate(this);
    fERmin2->Resize(100, fERmin2->GetDefaultHeight());
@@ -107,7 +102,7 @@ TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
    f1->AddFrame(new TGLabel(f1, "Rmax2"), new TGLayoutHints(kLHintsLeft, 1, 1, 6, 0));
    fERmax2 = new TGNumberEntry(f1, 0., 5, kCONE_RMAX2);
    fERmax2->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fERmax1->GetNumberEntry();
+   nef = (TGTextEntry *)fERmax1->GetNumberEntry();
    nef->SetToolTipText("Enter the outer radius");
    fERmax2->Associate(this);
    fERmax2->Resize(100, fERmax2->GetDefaultHeight());
@@ -119,21 +114,21 @@ TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
    f1->AddFrame(new TGLabel(f1, "DZ"), new TGLayoutHints(kLHintsLeft, 1, 1, 6, 0));
    fEDz = new TGNumberEntry(f1, 0., 5, kCONE_Z);
    fEDz->SetNumAttr(TGNumberFormat::kNEAPositive);
-   nef = (TGTextEntry*)fEDz->GetNumberEntry();
+   nef = (TGTextEntry *)fEDz->GetNumberEntry();
    nef->SetToolTipText("Enter the cone half-lenth in Z");
    fEDz->Associate(this);
    fEDz->Resize(100, fEDz->GetDefaultHeight());
    f1->AddFrame(fEDz, new TGLayoutHints(kLHintsRight, 2, 2, 2, 2));
    compxyz->AddFrame(f1, new TGLayoutHints(kLHintsLeft, 2, 2, 0, 0));
 
-   compxyz->Resize(150,30);
+   compxyz->Resize(150, 30);
    AddFrame(compxyz, new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
 
    // Delayed draw
    fDFrame = new TGCompositeFrame(this, 155, 10, kHorizontalFrame | kFixedWidth | kSunkenFrame);
    fDelayed = new TGCheckButton(fDFrame, "Delayed draw");
-   fDFrame->AddFrame(fDelayed, new TGLayoutHints(kLHintsLeft , 2, 2, 2, 2));
-   AddFrame(fDFrame,  new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
+   fDFrame->AddFrame(fDelayed, new TGLayoutHints(kLHintsLeft, 2, 2, 2, 2));
+   AddFrame(fDFrame, new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
 
    // Buttons
    fBFrame = new TGCompositeFrame(this, 155, 10, kHorizontalFrame | kFixedWidth);
@@ -141,9 +136,9 @@ TGeoConeEditor::TGeoConeEditor(const TGWindow *p, Int_t width,
    fBFrame->AddFrame(fApply, new TGLayoutHints(kLHintsLeft, 2, 2, 4, 4));
    fApply->Associate(this);
    fUndo = new TGTextButton(fBFrame, "Undo");
-   fBFrame->AddFrame(fUndo, new TGLayoutHints(kLHintsRight , 2, 2, 4, 4));
+   fBFrame->AddFrame(fUndo, new TGLayoutHints(kLHintsRight, 2, 2, 4, 4));
    fUndo->Associate(this);
-   AddFrame(fBFrame,  new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
+   AddFrame(fBFrame, new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
    fUndo->SetSize(fApply->GetSize());
 }
 
@@ -156,7 +151,7 @@ TGeoConeEditor::~TGeoConeEditor()
    TIter next(GetList());
    while ((el = (TGFrameElement *)next())) {
       if (el->fFrame->IsComposite())
-         TGeoTabManager::Cleanup((TGCompositeFrame*)el->fFrame);
+         TGeoTabManager::Cleanup((TGCompositeFrame *)el->fFrame);
    }
    Cleanup();
 }
@@ -182,17 +177,16 @@ void TGeoConeEditor::ConnectSignals2Slots()
    fInit = kFALSE;
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
 /// Connect to the selected object.
 
-void TGeoConeEditor::SetModel(TObject* obj)
+void TGeoConeEditor::SetModel(TObject *obj)
 {
-   if (obj == 0 || (obj->IsA()!=TGeoCone::Class())) {
+   if (obj == nullptr || (obj->IsA() != TGeoCone::Class())) {
       SetActive(kFALSE);
       return;
    }
-   fShape = (TGeoCone*)obj;
+   fShape = (TGeoCone *)obj;
    fRmini1 = fShape->GetRmin1();
    fRmini2 = fShape->GetRmin2();
    fRmaxi1 = fShape->GetRmax1();
@@ -208,7 +202,8 @@ void TGeoConeEditor::SetModel(TObject* obj)
    fApply->SetEnabled(kFALSE);
    fUndo->SetEnabled(kFALSE);
 
-   if (fInit) ConnectSignals2Slots();
+   if (fInit)
+      ConnectSignals2Slots();
    SetActive();
 }
 
@@ -229,22 +224,27 @@ void TGeoConeEditor::DoName()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///Slot for applying current parameters.
+/// Slot for applying current parameters.
 
 void TGeoConeEditor::DoApply()
 {
    fApply->SetEnabled(kFALSE);
    const char *name = fShapeName->GetText();
-   if (strcmp(name,fShape->GetName())) fShape->SetName(name);
+   if (strcmp(name, fShape->GetName()))
+      fShape->SetName(name);
    Double_t rmin1 = fERmin1->GetNumber();
    Double_t rmin2 = fERmin2->GetNumber();
    Double_t rmax1 = fERmax1->GetNumber();
    Double_t rmax2 = fERmax2->GetNumber();
    Double_t dz = fEDz->GetNumber();
-   if (rmin1<0 || rmin1>rmax1) return;
-   if (rmin2<0 || rmin2>rmax2) return;
-   if (dz<=0) return;
-   if (rmin1==rmax1 && rmin2==rmax2) return;
+   if (rmin1 < 0 || rmin1 > rmax1)
+      return;
+   if (rmin2 < 0 || rmin2 > rmax2)
+      return;
+   if (dz <= 0)
+      return;
+   if (rmin1 == rmax1 && rmin2 == rmax2)
+      return;
    fShape->SetConeDimensions(dz, rmin1, rmax1, rmin2, rmax2);
    fShape->ComputeBBox();
    fUndo->SetEnabled();
@@ -252,12 +252,13 @@ void TGeoConeEditor::DoApply()
       if (gGeoManager && gGeoManager->GetPainter() && gGeoManager->GetPainter()->IsPaintingShape()) {
          fShape->Draw();
          fPad->GetView()->ShowAxis();
-      } else Update();
+      } else
+         Update();
    }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///Slot for modifying current parameters.
+/// Slot for modifying current parameters.
 
 void TGeoConeEditor::DoModified()
 {
@@ -286,16 +287,17 @@ void TGeoConeEditor::DoRmin1()
 {
    Double_t rmin1 = fERmin1->GetNumber();
    Double_t rmax1 = fERmax1->GetNumber();
-   if (rmin1<0) {
+   if (rmin1 < 0) {
       rmin1 = 0;
       fERmin1->SetNumber(rmin1);
    }
-   if (rmin1>rmax1) {
+   if (rmin1 > rmax1) {
       rmin1 = rmax1;
       fERmin1->SetNumber(rmin1);
    }
    DoModified();
-   if (!IsDelayed()) DoApply();
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -305,12 +307,13 @@ void TGeoConeEditor::DoRmax1()
 {
    Double_t rmin1 = fERmin1->GetNumber();
    Double_t rmax1 = fERmax1->GetNumber();
-   if (rmax1<rmin1) {
+   if (rmax1 < rmin1) {
       rmax1 = rmin1;
       fERmax1->SetNumber(rmax1);
    }
    DoModified();
-   if (!IsDelayed()) DoApply();
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -320,16 +323,17 @@ void TGeoConeEditor::DoRmin2()
 {
    Double_t rmin2 = fERmin2->GetNumber();
    Double_t rmax2 = fERmax2->GetNumber();
-   if (rmin2<0) {
+   if (rmin2 < 0) {
       rmin2 = 0;
       fERmin2->SetNumber(rmin2);
    }
-   if (rmin2>rmax2) {
+   if (rmin2 > rmax2) {
       rmin2 = rmax2;
       fERmin2->SetNumber(rmin2);
    }
    DoModified();
-   if (!IsDelayed()) DoApply();
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -339,12 +343,13 @@ void TGeoConeEditor::DoRmax2()
 {
    Double_t rmin2 = fERmin2->GetNumber();
    Double_t rmax2 = fERmax2->GetNumber();
-   if (rmax2<rmin2) {
+   if (rmax2 < rmin2) {
       rmax2 = rmin2;
       fERmax2->SetNumber(rmax2);
    }
    DoModified();
-   if (!IsDelayed()) DoApply();
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -353,12 +358,13 @@ void TGeoConeEditor::DoRmax2()
 void TGeoConeEditor::DoDz()
 {
    Double_t dz = fEDz->GetNumber();
-   if (dz<=0) {
+   if (dz <= 0) {
       dz = 0.1;
       fEDz->SetNumber(dz);
    }
    DoModified();
-   if (!IsDelayed()) DoApply();
+   if (!IsDelayed())
+      DoApply();
 }
 
 /** \class TGeoConeSegEditor
@@ -374,24 +380,22 @@ Editor for a cone segment.
 
 ClassImp(TGeoConeSegEditor);
 
-enum ETGeoConeSegWid {
-   kCONESEG_PHI1, kCONESEG_PHI2, kCONESEG_PHI
-};
+enum ETGeoConeSegWid { kCONESEG_PHI1, kCONESEG_PHI2, kCONESEG_PHI };
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Constructor for cone segment editor
 
-TGeoConeSegEditor::TGeoConeSegEditor(const TGWindow *p, Int_t width,
-                                   Int_t height, UInt_t options, Pixel_t back)
-                 : TGeoConeEditor(p, width, height, options | kVerticalFrame, back)
+TGeoConeSegEditor::TGeoConeSegEditor(const TGWindow *p, Int_t width, Int_t height, UInt_t options, Pixel_t back)
+   : TGeoConeEditor(p, width, height, options | kVerticalFrame, back)
 {
    fLock = kFALSE;
    MakeTitle("Phi range");
    TGTextEntry *nef;
-   TGCompositeFrame *compxyz = new TGCompositeFrame(this, 155, 110, kHorizontalFrame | kFixedWidth | kFixedHeight | kRaisedFrame);
+   TGCompositeFrame *compxyz =
+      new TGCompositeFrame(this, 155, 110, kHorizontalFrame | kFixedWidth | kFixedHeight | kRaisedFrame);
    // Vertical slider
-   fSPhi = new TGDoubleVSlider(compxyz,100);
-   fSPhi->SetRange(0.,720.);
+   fSPhi = new TGDoubleVSlider(compxyz, 100);
+   fSPhi->SetRange(0., 720.);
    fSPhi->Resize(fSPhi->GetDefaultWidth(), 100);
    compxyz->AddFrame(fSPhi, new TGLayoutHints(kLHintsLeft, 2, 2, 4, 4));
    TGCompositeFrame *f1 = new TGCompositeFrame(compxyz, 135, 100, kVerticalFrame | kFixedHeight);
@@ -399,7 +403,7 @@ TGeoConeSegEditor::TGeoConeSegEditor(const TGWindow *p, Int_t width,
    fEPhi1 = new TGNumberEntry(f1, 0., 5, kCONESEG_PHI1);
    fEPhi1->Resize(100, fEPhi1->GetDefaultHeight());
    fEPhi1->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fEPhi1->GetNumberEntry();
+   nef = (TGTextEntry *)fEPhi1->GetNumberEntry();
    nef->SetToolTipText("Enter the phi1 value");
    fEPhi1->Associate(this);
    f1->AddFrame(fEPhi1, new TGLayoutHints(kLHintsTop | kLHintsRight, 2, 2, 2, 2));
@@ -407,14 +411,14 @@ TGeoConeSegEditor::TGeoConeSegEditor(const TGWindow *p, Int_t width,
    fEPhi2 = new TGNumberEntry(f1, 0., 5, kCONESEG_PHI2);
    fEPhi2->Resize(100, fEPhi2->GetDefaultHeight());
    fEPhi2->SetNumAttr(TGNumberFormat::kNEANonNegative);
-   nef = (TGTextEntry*)fEPhi2->GetNumberEntry();
+   nef = (TGTextEntry *)fEPhi2->GetNumberEntry();
    nef->SetToolTipText("Enter the phi2 value");
    fEPhi2->Associate(this);
    f1->AddFrame(fEPhi2, new TGLayoutHints(kLHintsBottom | kLHintsRight, 2, 2, 2, 2));
    f1->AddFrame(new TGLabel(f1, "Phi max."), new TGLayoutHints(kLHintsBottom, 0, 0, 6, 2));
    compxyz->AddFrame(f1, new TGLayoutHints(kLHintsLeft, 2, 2, 4, 4));
 
-//   compxyz->Resize(150,150);
+   //   compxyz->Resize(150,150);
    AddFrame(compxyz, new TGLayoutHints(kLHintsLeft, 6, 6, 4, 4));
    TGeoTabManager::MoveFrame(fDFrame, this);
    TGeoTabManager::MoveFrame(fBFrame, this);
@@ -429,7 +433,7 @@ TGeoConeSegEditor::~TGeoConeSegEditor()
    TIter next(GetList());
    while ((el = (TGFrameElement *)next())) {
       if (el->fFrame->IsComposite())
-         TGeoTabManager::Cleanup((TGCompositeFrame*)el->fFrame);
+         TGeoTabManager::Cleanup((TGCompositeFrame *)el->fFrame);
    }
    Cleanup();
 }
@@ -440,39 +444,39 @@ TGeoConeSegEditor::~TGeoConeSegEditor()
 void TGeoConeSegEditor::ConnectSignals2Slots()
 {
    TGeoConeEditor::ConnectSignals2Slots();
-   Disconnect(fApply, "Clicked()",(TGeoConeEditor*)this, "DoApply()");
-   Disconnect(fUndo, "Clicked()",(TGeoConeEditor*)this, "DoUndo()");
+   Disconnect(fApply, "Clicked()", (TGeoConeEditor *)this, "DoApply()");
+   Disconnect(fUndo, "Clicked()", (TGeoConeEditor *)this, "DoUndo()");
    fApply->Connect("Clicked()", "TGeoConeSegEditor", this, "DoApply()");
    fUndo->Connect("Clicked()", "TGeoConeSegEditor", this, "DoUndo()");
    fEPhi1->Connect("ValueSet(Long_t)", "TGeoConeSegEditor", this, "DoPhi1()");
    fEPhi2->Connect("ValueSet(Long_t)", "TGeoConeSegEditor", this, "DoPhi2()");
-//   fEPhi1->GetNumberEntry()->Connect("TextChanged(const char *)","TGeoConeSegEditor", this, "DoPhi1()");
-//   fEPhi2->GetNumberEntry()->Connect("TextChanged(const char *)","TGeoConeSegEditor", this, "DoPhi2()");
-   fSPhi->Connect("PositionChanged()","TGeoConeSegEditor", this, "DoPhi()");
+   //   fEPhi1->GetNumberEntry()->Connect("TextChanged(const char *)","TGeoConeSegEditor", this, "DoPhi1()");
+   //   fEPhi2->GetNumberEntry()->Connect("TextChanged(const char *)","TGeoConeSegEditor", this, "DoPhi2()");
+   fSPhi->Connect("PositionChanged()", "TGeoConeSegEditor", this, "DoPhi()");
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Connect to the selected object.
 
-void TGeoConeSegEditor::SetModel(TObject* obj)
+void TGeoConeSegEditor::SetModel(TObject *obj)
 {
-   if (obj == 0 || (obj->IsA()!=TGeoConeSeg::Class())) {
+   if (obj == nullptr || (obj->IsA() != TGeoConeSeg::Class())) {
       SetActive(kFALSE);
       return;
    }
-   fShape = (TGeoCone*)obj;
+   fShape = (TGeoCone *)obj;
    fRmini1 = fShape->GetRmin1();
    fRmaxi1 = fShape->GetRmax1();
    fRmini2 = fShape->GetRmin2();
    fRmaxi2 = fShape->GetRmax2();
    fDzi = fShape->GetDz();
    fNamei = fShape->GetName();
-   fPmini = ((TGeoConeSeg*)fShape)->GetPhi1();
-   fPmaxi = ((TGeoConeSeg*)fShape)->GetPhi2();
+   fPmini = ((TGeoConeSeg *)fShape)->GetPhi1();
+   fPmaxi = ((TGeoConeSeg *)fShape)->GetPhi2();
    fShapeName->SetText(fShape->GetName());
    fEPhi1->SetNumber(fPmini);
    fEPhi2->SetNumber(fPmaxi);
-   fSPhi->SetPosition(fPmini,fPmaxi);
+   fSPhi->SetPosition(fPmini, fPmaxi);
    fERmin1->SetNumber(fRmini1);
    fERmax1->SetNumber(fRmaxi1);
    fERmin2->SetNumber(fRmini2);
@@ -481,31 +485,34 @@ void TGeoConeSegEditor::SetModel(TObject* obj)
    fApply->SetEnabled(kFALSE);
    fUndo->SetEnabled(kFALSE);
 
-   if (fInit) ConnectSignals2Slots();
+   if (fInit)
+      ConnectSignals2Slots();
    SetActive();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-///Slot for Phi1
+/// Slot for Phi1
 
 void TGeoConeSegEditor::DoPhi1()
 {
    Double_t phi1 = fEPhi1->GetNumber();
    Double_t phi2 = fEPhi2->GetNumber();
-   if (phi1 > 360-1.e-10) {
+   if (phi1 > 360 - 1.e-10) {
       phi1 = 0.;
       fEPhi1->SetNumber(phi1);
    }
-   if (phi2<phi1+1.e-10) {
+   if (phi2 < phi1 + 1.e-10) {
       phi1 = phi2 - 0.1;
       fEPhi1->SetNumber(phi1);
    }
    if (!fLock) {
       DoModified();
       fLock = kTRUE;
-      fSPhi->SetPosition(phi1,phi2);
-   } else fLock = kFALSE;
-   if (!IsDelayed()) DoApply();
+      fSPhi->SetPosition(phi1, phi2);
+   } else
+      fLock = kFALSE;
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -515,20 +522,22 @@ void TGeoConeSegEditor::DoPhi2()
 {
    Double_t phi1 = fEPhi1->GetNumber();
    Double_t phi2 = fEPhi2->GetNumber();
-   if (phi2-phi1 > 360.) {
+   if (phi2 - phi1 > 360.) {
       phi2 -= 360.;
       fEPhi2->SetNumber(phi2);
    }
-   if (phi2<phi1+1.e-10) {
+   if (phi2 < phi1 + 1.e-10) {
       phi2 = phi1 + 0.1;
       fEPhi2->SetNumber(phi2);
    }
    if (!fLock) {
       DoModified();
       fLock = kTRUE;
-      fSPhi->SetPosition(phi1,phi2);
-   } else fLock = kFALSE;
-   if (!IsDelayed()) DoApply();
+      fSPhi->SetPosition(phi1, phi2);
+   } else
+      fLock = kFALSE;
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -542,8 +551,10 @@ void TGeoConeSegEditor::DoPhi()
       fEPhi1->SetNumber(fSPhi->GetMinPosition());
       fLock = kTRUE;
       fEPhi2->SetNumber(fSPhi->GetMaxPosition());
-   } else fLock = kFALSE;
-   if (!IsDelayed()) DoApply();
+   } else
+      fLock = kFALSE;
+   if (!IsDelayed())
+      DoApply();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -553,33 +564,37 @@ void TGeoConeSegEditor::DoApply()
 {
    fApply->SetEnabled(kFALSE);
    const char *name = fShapeName->GetText();
-   if (strcmp(name,fShape->GetName())) fShape->SetName(name);
+   if (strcmp(name, fShape->GetName()))
+      fShape->SetName(name);
    Double_t rmin1 = fERmin1->GetNumber();
    Double_t rmax1 = fERmax1->GetNumber();
-   if (rmin1<0 || rmax1<rmin1) return;
+   if (rmin1 < 0 || rmax1 < rmin1)
+      return;
    Double_t rmin2 = fERmin2->GetNumber();
    Double_t rmax2 = fERmax2->GetNumber();
-   if (rmin2<0 || rmax2<rmin2) return;
+   if (rmin2 < 0 || rmax2 < rmin2)
+      return;
    Double_t dz = fEDz->GetNumber();
    Double_t phi1 = fEPhi1->GetNumber();
    Double_t phi2 = fEPhi2->GetNumber();
-   if ((phi2-phi1) > 360.001) {
+   if ((phi2 - phi1) > 360.001) {
       phi1 = 0.;
       phi2 = 360.;
       fEPhi1->SetNumber(phi1);
       fEPhi2->SetNumber(phi2);
       fLock = kTRUE;
-      fSPhi->SetPosition(phi1,phi2);
+      fSPhi->SetPosition(phi1, phi2);
       fLock = kFALSE;
    }
-   ((TGeoConeSeg*)fShape)->SetConsDimensions(dz, rmin1, rmax1, rmin2,rmax2, phi1, phi2);
+   ((TGeoConeSeg *)fShape)->SetConsDimensions(dz, rmin1, rmax1, rmin2, rmax2, phi1, phi2);
    fShape->ComputeBBox();
    fUndo->SetEnabled();
    if (fPad) {
       if (gGeoManager && gGeoManager->GetPainter() && gGeoManager->GetPainter()->IsPaintingShape()) {
          fShape->Draw();
          fPad->GetView()->ShowAxis();
-      } else Update();
+      } else
+         Update();
    }
 }
 
@@ -595,12 +610,8 @@ void TGeoConeSegEditor::DoUndo()
    fEDz->SetNumber(fDzi);
    fEPhi1->SetNumber(fPmini);
    fEPhi2->SetNumber(fPmaxi);
-   fSPhi->SetPosition(fPmini,fPmaxi);
+   fSPhi->SetPosition(fPmini, fPmaxi);
    DoApply();
    fUndo->SetEnabled(kFALSE);
    fApply->SetEnabled(kFALSE);
 }
-
-
-
-
