@@ -75,7 +75,7 @@ Begin_Macro(source)
    TView *view = TView::CreateView(1);
    view->SetRange(0,0,0,2,2,2);
    const Int_t n = 500;
-   r = new TRandom();
+   auto r = new TRandom();
    Double_t x, y, z;
    TPolyLine3D *l = new TPolyLine3D(n);
    for (Int_t i=0;i<n;i++) {
@@ -99,9 +99,6 @@ option `L`.
 
 TPolyLine3D::TPolyLine3D()
 {
-   fN = 0;
-   fP = 0;
-   fLastPoint = -1;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -112,12 +109,8 @@ TPolyLine3D::TPolyLine3D(Int_t n, Option_t *option)
 {
    fOption = option;
    SetBit(kCanDelete);
-   fLastPoint = -1;
-   if (n <= 0) {
-      fN = 0;
-      fP = 0;
+   if (n <= 0)
       return;
-   }
 
    fN = n;
    fP = new Float_t[3*fN];
@@ -132,12 +125,8 @@ TPolyLine3D::TPolyLine3D(Int_t n, Float_t const* p, Option_t *option)
 {
    fOption = option;
    SetBit(kCanDelete);
-   fLastPoint = -1;
-   if (n <= 0) {
-      fN = 0;
-      fP = 0;
+   if (n <= 0)
       return;
-   }
 
    fN = n;
    fP = new Float_t[3*fN];
@@ -155,12 +144,8 @@ TPolyLine3D::TPolyLine3D(Int_t n, Double_t const* p, Option_t *option)
 {
    fOption = option;
    SetBit(kCanDelete);
-   fLastPoint = -1;
-   if (n <= 0) {
-      fN = 0;
-      fP = 0;
+   if (n <= 0)
       return;
-   }
 
    fN = n;
    fP = new Float_t[3*fN];
@@ -178,12 +163,8 @@ TPolyLine3D::TPolyLine3D(Int_t n, Float_t const* x, Float_t const* y, Float_t co
 {
    fOption = option;
    SetBit(kCanDelete);
-   fLastPoint = -1;
-   if (n <= 0) {
-      fN = 0;
-      fP = 0;
+   if (n <= 0)
       return;
-   }
 
    fN = n;
    fP = new Float_t[3*fN];
@@ -206,12 +187,8 @@ TPolyLine3D::TPolyLine3D(Int_t n, Double_t const* x, Double_t const* y, Double_t
 {
    fOption = option;
    SetBit(kCanDelete);
-   fLastPoint = -1;
-   if (n <= 0) {
-      fN = 0;
-      fP = 0;
+   if (n <= 0)
       return;
-   }
 
    fN = n;
    fP = new Float_t[3*fN];
@@ -248,9 +225,6 @@ TPolyLine3D::~TPolyLine3D()
 
 TPolyLine3D::TPolyLine3D(const TPolyLine3D &polyline) : TObject(polyline), TAttLine(polyline), TAtt3D(polyline)
 {
-   fP         = 0;
-   fLastPoint = 0;
-   fN         = 0;
    polyline.TPolyLine3D::Copy(*this);
 }
 
@@ -581,25 +555,24 @@ void TPolyLine3D::Print(Option_t *option) const
 ////////////////////////////////////////////////////////////////////////////////
 /// Save primitive as a C++ statement(s) on output stream.
 
-void TPolyLine3D::SavePrimitive(std::ostream &out, Option_t * /*= ""*/)
+void TPolyLine3D::SavePrimitive(std::ostream &out, Option_t *option)
 {
-   char quote = '"';
-   out<<"   "<<std::endl;
-   if (gROOT->ClassSaved(TPolyLine3D::Class())) {
-      out<<"   ";
-   } else {
-      out<<"   TPolyLine3D *";
+   TString arrarg;
+   if (Size() > 0) {
+      std::vector<Double_t> arr(Size() * 3);
+      for (Int_t i = 0; i < Size() * 3; i++)
+         arr[i] = fP[i];
+      arrarg = SavePrimitiveVector(out, "pline3D", Size() * 3, arr.data(), kTRUE);
+      arrarg.Append(".data(), ");
    }
-   Int_t size=Size();
-   out<<"pline3D = new TPolyLine3D("<<fN<<","<<quote<<fOption<<quote<<");"<<std::endl;
 
-   SaveLineAttributes(out,"pline3D",1,1,1);
+   SavePrimitiveConstructor(
+      out, Class(), "pline3D",
+      TString::Format("%d, %s\"%s\"", Size(), arrarg.Data(), TString(fOption).ReplaceSpecialCppChars().Data()),
+      arrarg.IsNull());
 
-   if (size > 0) {
-      for (Int_t i=0;i<size;i++)
-         out<<"   pline3D->SetPoint("<<i<<","<<fP[3*i]<<","<<fP[3*i+1]<<","<<fP[3*i+2]<<");"<<std::endl;
-   }
-   out<<"   pline3D->Draw();"<<std::endl;
+   SaveLineAttributes(out, "pline3D", 1, 1, 1);
+   SavePrimitiveDraw(out, "pline3D", option);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -650,7 +623,7 @@ void TPolyLine3D::SetPolyLine(Int_t n, Option_t *option)
       fN = 0;
       fLastPoint = -1;
       delete [] fP;
-      fP = 0;
+      fP = nullptr;
       return;
    }
    fN = n;
@@ -671,7 +644,7 @@ void TPolyLine3D::SetPolyLine(Int_t n, Float_t *p, Option_t *option)
       fN = 0;
       fLastPoint = -1;
       delete [] fP;
-      fP = 0;
+      fP = nullptr;
       return;
    }
    fN = n;
@@ -700,7 +673,7 @@ void TPolyLine3D::SetPolyLine(Int_t n, Double_t *p, Option_t *option)
       fN = 0;
       fLastPoint = -1;
       delete [] fP;
-      fP = 0;
+      fP = nullptr;
       return;
    }
    fN = n;
