@@ -58,11 +58,11 @@ ClassImp(TGLEventHandler);
 TGLEventHandler::TGLEventHandler(TGWindow *w, TObject *obj) :
    TGEventHandler      ("TGLEventHandler", w, obj),
    fGLViewer           ((TGLViewer *)obj),
-   fMouseTimer         (0),
+   fMouseTimer         (nullptr),
    fLastPos            (-1, -1),
    fLastMouseOverPos   (-1, -1),
-   fLastMouseOverShape (0),
-   fTooltip            (0),
+   fLastMouseOverShape (nullptr),
+   fTooltip            (nullptr),
    fActiveButtonID     (0),
    fLastEventState     (0),
    fIgnoreButtonUp     (kFALSE),
@@ -375,7 +375,7 @@ Bool_t TGLEventHandler::HandleEvent(Event_t *event)
 
 Bool_t TGLEventHandler::HandleFocusChange(Event_t *event)
 {
-   fGLViewer->MouseIdle(0, 0, 0);
+   fGLViewer->MouseIdle(nullptr, 0, 0);
    if (event->fType == kFocusIn) {
       if (fGLViewer->fDragAction != TGLViewer::kDragNone) {
          Error("TGLEventHandler::HandleFocusChange", "active drag-action at focus-in.");
@@ -407,7 +407,7 @@ Bool_t TGLEventHandler::HandleCrossing(Event_t *event)
       return kTRUE;
    }
 
-   fGLViewer->MouseIdle(0, 0, 0);
+   fGLViewer->MouseIdle(nullptr, 0, 0);
    if (event->fType == kEnterNotify) {
       if (fGLViewer->fDragAction != TGLViewer::kDragNone) {
          Error("TGLEventHandler::HandleCrossing", "active drag-action at enter-notify.");
@@ -499,7 +499,7 @@ Bool_t TGLEventHandler::HandleButton(Event_t * event)
    {
       GrabMouse();
 
-      fGLViewer->MouseIdle(0, 0, 0);
+      fGLViewer->MouseIdle(nullptr, 0, 0);
 
       fButtonPushPos.fX = event->fX;
       fButtonPushPos.fY = event->fY;
@@ -688,11 +688,11 @@ Bool_t TGLEventHandler::HandleDoubleClick(Event_t *event)
    fActiveButtonID = event->fCode;
    GrabMouse();
 
-   fGLViewer->MouseIdle(0, 0, 0);
+   fGLViewer->MouseIdle(nullptr, 0, 0);
    if (event->fCode == kButton1)
    {
       fGLViewer->DoubleClicked();
-      if (fGLViewer->GetSelected() == 0)
+      if (fGLViewer->GetSelected() == nullptr)
          fGLViewer->SelectionChanged();
    }
    return kTRUE;
@@ -754,7 +754,7 @@ Bool_t TGLEventHandler::HandleKey(Event_t *event)
 
    fLastEventState = event->fState;
 
-   fGLViewer->MouseIdle(0, 0, 0);
+   fGLViewer->MouseIdle(nullptr, 0, 0);
    if (fGLViewer->IsLocked()) {
       if (gDebug>3) {
          Info("TGLEventHandler::HandleKey", "ignored - viewer is %s",
@@ -889,7 +889,7 @@ Bool_t TGLEventHandler::HandleKey(Event_t *event)
 
 Bool_t TGLEventHandler::HandleMotion(Event_t * event)
 {
-   fGLViewer->MouseIdle(0, 0, 0);
+   fGLViewer->MouseIdle(nullptr, 0, 0);
    if (fGLViewer->IsLocked()) {
       if (gDebug>3) {
          Info("TGLEventHandler::HandleMotion", "ignored - viewer is %s",
@@ -1034,10 +1034,10 @@ void TGLEventHandler::StopMouseTimer()
 void TGLEventHandler::ClearMouseOver()
 {
    fLastMouseOverPos.fX = fLastMouseOverPos.fY = -1;
-   fLastMouseOverShape = 0;
+   fLastMouseOverShape = nullptr;
    fGLViewer->MouseOver(fLastMouseOverShape);
    fGLViewer->MouseOver(fLastMouseOverShape, fLastEventState);
-   fGLViewer->MouseOver((TObject*)0, fLastEventState);
+   fGLViewer->MouseOver((TObject*)nullptr, fLastEventState);
 
    fGLViewer->ClearCurrentOvlElm();
 }
