@@ -11,23 +11,15 @@
 #include <ROOT/RCanvas.hxx>
 #include <ROOT/TObjectDrawable.hxx>
 
-using namespace ROOT::Experimental;
-
-/** Provider for drawing of ROOT7 classes */
+/** Provider for drawing TLeaf/TBranch in ROOT7 canvas */
 
 class TLeafDraw7Provider : public TLeafProvider {
 public:
-   bool AddHist(std::shared_ptr<RPadBase> &subpad, TH1 *hist, const std::string &opt)
+   bool AddHist(std::shared_ptr<ROOT::Experimental::RPadBase> &subpad, TH1 *hist, const std::string &opt)
    {
       if (!hist)
          return false;
 
-      if (subpad->NumPrimitives() > 0) {
-         subpad->Wipe();
-         subpad->GetCanvas()->Modified();
-         subpad->GetCanvas()->Update(true);
-      }
-
       std::shared_ptr<TH1> shared;
       shared.reset(hist);
 
@@ -38,19 +30,19 @@ public:
 
    TLeafDraw7Provider()
    {
-      RegisterDraw7(TLeaf::Class(), [this](std::shared_ptr<RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
+      RegisterDraw7(TLeaf::Class(), [this](std::shared_ptr<ROOT::Experimental::RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
          return AddHist(subpad, DrawLeaf(obj), opt);
       });
 
-      RegisterDraw7(TBranchElement::Class(), [this](std::shared_ptr<RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
+      RegisterDraw7(TBranchElement::Class(), [this](std::shared_ptr<ROOT::Experimental::RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
          return AddHist(subpad, DrawBranchElement(obj), opt);
       });
 
-      RegisterDraw7(TBranch::Class(), [this](std::shared_ptr<RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
+      RegisterDraw7(TBranch::Class(), [this](std::shared_ptr<ROOT::Experimental::RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
          return AddHist(subpad, DrawBranch(obj), opt);
       });
 
-      RegisterDraw7(TVirtualBranchBrowsable::Class(), [this](std::shared_ptr<RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
+      RegisterDraw7(TVirtualBranchBrowsable::Class(), [this](std::shared_ptr<ROOT::Experimental::RPadBase> &subpad, std::unique_ptr<RHolder> &obj, const std::string &opt) -> bool {
          return AddHist(subpad, DrawBranchBrowsable(obj), opt);
       });
 
