@@ -22,6 +22,7 @@
 
 #include "RBrowserWidget.hxx"
 
+#include "TVirtualPad.h"
 #include "TString.h"
 #include "TSystem.h"
 #include "TError.h"
@@ -68,15 +69,12 @@ public:
    std::string fItemPath;   ///<! item path in the browser
 
    RBrowserEditorWidget(const std::string &name, bool is_editor = true) : RBrowserWidget(name), fIsEditor(is_editor) {}
-   virtual ~RBrowserEditorWidget() = default;
+   ~RBrowserEditorWidget() override = default;
 
    void ResetConn() override { fFirstSend = false; }
 
    std::string GetKind() const override { return fIsEditor ? "editor"s : "image"s; }
    std::string GetTitle() override { return fTitle; }
-   std::string GetUrl() override { return ""s; }
-
-   void Show(const std::string &) override {}
 
    bool DrawElement(std::shared_ptr<Browsable::RElement> &elem, const std::string & = "") override
    {
@@ -148,15 +146,12 @@ public:
       Refresh();
    }
 
-   virtual ~RBrowserInfoWidget() = default;
+   ~RBrowserInfoWidget() override = default;
 
    void ResetConn() override { fFirstSend = false; }
 
    std::string GetKind() const override { return "info"s; }
    std::string GetTitle() override { return fTitle; }
-   std::string GetUrl() override { return ""s; }
-
-   void Show(const std::string &) override {}
 
    bool DrawElement(std::shared_ptr<Browsable::RElement> &, const std::string & = "") override { return false; }
 
@@ -238,11 +233,9 @@ public:
    RWebWindow  *fWindow{nullptr};   // catched widget, TODO: to be changed to shared_ptr
    std::string fCatchedKind;  // kind of catched widget
 
-   void Show(const std::string &) override {}
-
    std::string GetKind() const override { return "catched"s; }
 
-   std::string GetUrl() override { return fWindow ? fWindow->GetUrl(false) : ""s; }
+   std::string GetUrl() override { return fWindow ? ".."s + fWindow->GetUrl(false) : ""s; }
 
    std::string GetTitle() override { return fCatchedKind; }
 
@@ -317,9 +310,17 @@ RBrowser::RBrowser(bool use_rcanvas)
       if (!fWebWindow || !fCatchWindowShow || kind.empty())
          return false;
 
+      // before create new widget check if other disappear
       CheckWidgtesModified(0);
 
-      auto widget = AddCatchedWidget(&win, kind);
+      auto widget = RBrowserWidgetProvider::DetectCatchedWindow(kind, win);
+      if (widget) {
+         widget->fBrowser = this;
+         fWidgets.emplace_back(widget);
+         fActiveWidgetName = widget->GetName();
+      } else {
+         widget = AddCatchedWidget(&win, kind);
+      }
 
       if (widget && fWebWindow && (fWebWindow->NumConnections() > 0))
          fWebWindow->Send(0, NewWidgetMsg(widget));
@@ -339,17 +340,6 @@ RBrowser::RBrowser(bool use_rcanvas)
    });
 
    Show();
-
-   // add first canvas by default
-
-   //if (GetUseRCanvas())
-   //   AddWidget("rcanvas");
-   //else
-   //   AddWidget("tcanvas");
-
-   // AddWidget("geom");  // add geometry viewer at the beginning
-
-   // AddWidget("editor"); // one can add empty editor if necessary
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
@@ -360,6 +350,7 @@ RBrowser::~RBrowser()
    if (fWebWindow) {
       fWebWindow->GetManager()->SetShowCallback(nullptr);
       fWebWindow->GetManager()->SetDeleteCallback(nullptr);
+      fWebWindow->Reset();
    }
 }
 
@@ -450,8 +441,6 @@ std::string RBrowser::ProcessDblClick(unsigned connid, std::vector<std::string>
 
       // assign back pointer
       new_widget->fBrowser = this;
-
-      new_widget->Show("embed");
       fWidgets.emplace_back(new_widget);
       fActiveWidgetName = new_widget->GetName();
 
@@ -518,6 +507,34 @@ std::string RBrowser::ProcessDblClick(unsigned connid, std::vector<std::string>
    return ""s;
 }
 
+/////////////////////////////////////////////////////////////////////////////////
+/// Process drop of item in the current tab
+
+std::string RBrowser::ProcessDrop(unsigned connid, std::vector<std::string> &args)
+{
+   auto path = fBrowsable.GetWorkingPath();
+   path.insert(path.end(), args.begin(), args.end());
+
+   R__LOG_DEBUG(0, BrowserLog()) << "DoubleClick " << Browsable::RElement::GetPathAsString(path);
+
+   auto elem = fBrowsable.GetSubElement(path);
+   if (!elem) return ""s;
+
+   fLastProgressSend = 0;
+   Browsable::RProvider::ProgressHandle handle(elem.get(), [this, connid](float progress, void *) {
+      SendProgress(connid, progress);
+   });
+
+   auto widget = GetActiveWidget();
+   if (widget && widget->DrawElement(elem, "<append>")) {
+      widget->SetPath(path);
+      return widget->SendWidgetContent();
+   }
+
+   return ""s;
+}
+
+
 /////////////////////////////////////////////////////////////////////////////////
 /// Show or update RBrowser in web window
 /// If web window already started - just refresh it like "reload" button does
@@ -528,8 +545,6 @@ void RBrowser::Show(const RWebDisplayArgs &args, bool always_start_new_browser)
 {
    if (!fWebWindow->NumConnections() || always_start_new_browser) {
       fWebWindow->Show(args);
-   } else {
-      SendInitMsg(0);
    }
 }
 
@@ -579,9 +594,7 @@ std::shared_ptr<RBrowserWidget> RBrowser::AddWidget(const std::string &kind)
    }
 
    widget->fBrowser = this;
-   widget->Show("embed");
    fWidgets.emplace_back(widget);
-
    fActiveWidgetName = name;
 
    return widget;
@@ -592,7 +605,8 @@ std::shared_ptr<RBrowserWidget> RBrowser::AddWidget(const std::string &kind)
 
 std::shared_ptr<RBrowserWidget> RBrowser::AddCatchedWidget(RWebWindow *win, const std::string &kind)
 {
-   if (!win || kind.empty()) return nullptr;
+   if (!win || kind.empty())
+      return nullptr;
 
    std::string name = "catched"s + std::to_string(++fWidgetCnt);
 
@@ -697,7 +711,7 @@ void RBrowser::SendInitMsg(unsigned connid)
 
    for (auto &widget : fWidgets) {
       widget->ResetConn();
-      reply.emplace_back(std::vector<std::string>({ widget->GetKind(), ".."s + widget->GetUrl(), widget->GetName(), widget->GetTitle() }));
+      reply.emplace_back(std::vector<std::string>({ widget->GetKind(), widget->GetUrl(), widget->GetName(), widget->GetTitle() }));
    }
 
    if (!fActiveWidgetName.empty())
@@ -761,7 +775,7 @@ std::string RBrowser::GetCurrentWorkingDirectory()
 
 std::string RBrowser::NewWidgetMsg(std::shared_ptr<RBrowserWidget> &widget)
 {
-   std::vector<std::string> arr = { widget->GetKind(), ".."s + widget->GetUrl(), widget->GetName(), widget->GetTitle(),
+   std::vector<std::string> arr = { widget->GetKind(), widget->GetUrl(), widget->GetName(), widget->GetTitle(),
                                     Browsable::RElement::GetPathAsString(widget->GetPath()) };
    return "NEWWIDGET:"s + TBufferJSON::ToJSON(&arr, TBufferJSON::kNoSpaces).Data();
 }
@@ -808,6 +822,9 @@ void RBrowser::ProcessPostponedRequests()
    if (kind == "DBLCLK") {
       reply = ProcessDblClick(connid, arr);
       if (reply.empty()) reply = "NOPE";
+   } else if (kind == "DROP") {
+      reply = ProcessDrop(connid, arr);
+      if (reply.empty()) reply = "NOPE";
    }
 
    if (!reply.empty())
@@ -853,6 +870,19 @@ void RBrowser::ProcessMsg(unsigned connid, const std::string &arg0)
          fWebWindow->Send(connid, "NOPE");
       }
 
+   } else if (kind == "DROP") {
+
+      auto arr = TBufferJSON::FromJSON<std::vector<std::string>>(msg);
+      if (arr && arr->size()) {
+         arr->push_back(kind);
+         arr->push_back(std::to_string(connid));
+         fPostponed.push_back(*arr);
+         if (fPostponed.size() == 1)
+            fTimer->TurnOn();
+      } else {
+         fWebWindow->Send(connid, "NOPE");
+      }
+
    } else if (kind == "WIDGET_SELECTED") {
       fActiveWidgetName = msg;
       auto widget = GetActiveWidget();
@@ -942,6 +972,13 @@ void RBrowser::ProcessMsg(unsigned connid, const std::string &arg0)
       auto widget = AddWidget(msg);
       if (widget)
          fWebWindow->Send(connid, NewWidgetMsg(widget));
+   } else if (kind == "NEWCHANNEL") {
+      auto arr = TBufferJSON::FromJSON<std::vector<std::string>>(msg);
+      if (arr && (arr->size() == 2)) {
+         auto widget = FindWidget((*arr)[0]);
+         if (widget)
+            RWebWindow::ShowWindow(widget->GetWindow(), { fWebWindow, connid, std::stoi((*arr)[1]) });
+      }
    } else if (kind == "CDWORKDIR") {
       auto wrkdir = Browsable::RSysFile::GetWorkingPath();
       if (fBrowsable.GetWorkingPath() != wrkdir) {
