@@ -7,7 +7,7 @@
 // can be found in the LICENSE file.
 
 /*************************************************************************
- * Copyright (C) 1995-2019, Rene Brun and Fons Rademakers.               *
+ * Copyright (C) 1995-2023, Rene Brun and Fons Rademakers.               *
  * All rights reserved.                                                  *
  *                                                                       *
  * For the licensing terms see $ROOTSYS/LICENSE.                         *
@@ -53,45 +53,36 @@ public:
    void SetNextHandle(RCefWebDisplayHandle *handle);
 
    // CefApp methods:
-   virtual CefRefPtr<CefBrowserProcessHandler> GetBrowserProcessHandler() override { return this; }
+   CefRefPtr<CefBrowserProcessHandler> GetBrowserProcessHandler() override { return this; }
 
-#if defined(OS_LINUX)
-#if CEF_VERSION_MAJOR < 95
    // only on Linux special print handler is required to return PDF size
-   virtual CefRefPtr<CefPrintHandler> GetPrintHandler() override { return this; }
-#endif
-#endif
+   // CefRefPtr<CefPrintHandler> GetPrintHandler() override { return this; }
    // virtual CefRefPtr<CefRenderProcessHandler> GetRenderProcessHandler() override { return this; }
 
-   virtual void OnRegisterCustomSchemes(CefRawPtr<CefSchemeRegistrar> registrar) override;
+   void OnRegisterCustomSchemes(CefRawPtr<CefSchemeRegistrar> registrar) override;
 
    // CefBrowserProcessHandler methods:
-   virtual void OnContextInitialized() override;
+   void OnContextInitialized() override;
 
-   virtual void
-   OnBeforeCommandLineProcessing(const CefString &process_type, CefRefPtr<CefCommandLine> command_line) override;
+   void OnBeforeCommandLineProcessing(const CefString &process_type, CefRefPtr<CefCommandLine> command_line) override;
 
-   virtual void OnBeforeChildProcessLaunch(CefRefPtr<CefCommandLine> command_line) override;
+   void OnBeforeChildProcessLaunch(CefRefPtr<CefCommandLine> command_line) override;
 
 #if defined(OS_LINUX)
    // CefPrintHandler methods
-#if CEF_VERSION_MAJOR < 95
-   virtual CefSize GetPdfPaperSize(int device_units_per_inch) override { return CefSize(device_units_per_inch*8.25, device_units_per_inch*11.75); }
-#else
-   virtual CefSize GetPdfPaperSize(CefRefPtr<CefBrowser>, int device_units_per_inch) override { return CefSize(device_units_per_inch*8.25, device_units_per_inch*11.75); }
-#endif
-   virtual bool OnPrintDialog( CefRefPtr< CefBrowser > browser, bool has_selection, CefRefPtr< CefPrintDialogCallback > callback ) override { return false; }
-   virtual bool OnPrintJob( CefRefPtr< CefBrowser > browser, const CefString& document_name, const CefString& pdf_file_path, CefRefPtr< CefPrintJobCallback > callback ) override { return false; }
-   virtual void OnPrintReset( CefRefPtr< CefBrowser > browser ) override {}
-   virtual void OnPrintSettings( CefRefPtr< CefBrowser > browser, CefRefPtr< CefPrintSettings > settings, bool get_defaults ) override {}
-   virtual void OnPrintStart( CefRefPtr< CefBrowser > browser ) override {}
+   CefSize GetPdfPaperSize(CefRefPtr<CefBrowser>, int device_units_per_inch) override { return CefSize(device_units_per_inch*8.25, device_units_per_inch*11.75); }
+   bool OnPrintDialog( CefRefPtr< CefBrowser > browser, bool has_selection, CefRefPtr< CefPrintDialogCallback > callback ) override { return false; }
+   bool OnPrintJob( CefRefPtr< CefBrowser > browser, const CefString& document_name, const CefString& pdf_file_path, CefRefPtr< CefPrintJobCallback > callback ) override { return false; }
+   void OnPrintReset( CefRefPtr< CefBrowser > browser ) override {}
+   void OnPrintSettings( CefRefPtr< CefBrowser > browser, CefRefPtr< CefPrintSettings > settings, bool get_defaults ) override {}
+   void OnPrintStart( CefRefPtr< CefBrowser > browser ) override {}
 #endif
 
 
    void StartWindow(THttpServer *serv, const std::string &url, const std::string &cont, CefRect &rect);
 
    // CefRenderProcessHandler methods
-   // virtual void OnContextCreated(CefRefPtr<CefBrowser> browser, CefRefPtr<CefFrame> frame,
+   // void OnContextCreated(CefRefPtr<CefBrowser> browser, CefRefPtr<CefFrame> frame,
    //                              CefRefPtr<CefV8Context> context) override;
 
 private:
