@@ -310,7 +310,7 @@ TFitResultPtr HFit::Fit(FitObject * h1, TF1 *f1 , Foption_t & fitOption , const
    fitConfig.SetMinimizerOptions(minOption);
 
    // specific  print level options
-   if (fitOption.Verbose) fitConfig.MinimizerOptions().SetPrintLevel(3);
+   if (fitOption.Verbose)  fitConfig.MinimizerOptions().SetPrintLevel(fitOption.Verbose + 1);
    if (fitOption.Quiet)    fitConfig.MinimizerOptions().SetPrintLevel(0);
 
    // specific minimizer options depending on minimizer
@@ -760,14 +760,15 @@ void ROOT::Fit::FitOptionsMake(EFitObjectType type, const char *option, Foption_
       //for robust fitting, see if # of good points is defined
       // decode parameters for robust fitting
       Double_t h=0;
+      constexpr auto length = std::char_traits<char>::length;
       if (opt.Contains("H=0.")) {
          int start = opt.Index("H=0.");
-         int numpos = start + strlen("H=0.");
+         int numpos = start + length("H=0.");
          int numlen = 0;
          int len = opt.Length();
          while( (numpos+numlen<len) && isdigit(opt[numpos+numlen]) ) numlen++;
          TString num = opt(numpos,numlen);
-         opt.Remove(start+strlen("H"),strlen("=0.")+numlen);
+         opt.Remove(start+length("H"),length("=0.")+numlen);
          h = atof(num.Data());
          h*=TMath::Power(10, -numlen);
       }
@@ -786,8 +787,12 @@ void ROOT::Fit::FitOptionsMake(EFitObjectType type, const char *option, Foption_
          fitOption.User = 0;
       }
    }
-   if (opt.Contains("Q")) fitOption.Quiet   = 1;
-   if (opt.Contains("V")) {fitOption.Verbose = 1; fitOption.Quiet   = 0;}
+
+   // in case of Q and V options V has precedence
+   if (opt.Contains("VVV") || opt.Contains("DEBUG")) { fitOption.Verbose = 3; }
+   else if (opt.Contains("VV")) {fitOption.Verbose = 2; }
+   else if (opt.Contains("V")) {fitOption.Verbose = 1; }
+   else if (opt.Contains("Q")) {fitOption.Quiet   = 1; }
 
 
    if (opt.Contains("E")) fitOption.Errors  = 1;
@@ -894,7 +899,7 @@ TFitResultPtr ROOT::Fit::UnBinFit(ROOT::Fit::UnBinData * data, TF1 * fitfunc, Fo
 
    fitConfig.SetMinimizerOptions(minOption);
 
-   if (fitOption.Verbose)   fitConfig.MinimizerOptions().SetPrintLevel(3);
+   if (fitOption.Verbose)   fitConfig.MinimizerOptions().SetPrintLevel(fitOption.Verbose+1);
    if (fitOption.Quiet)     fitConfig.MinimizerOptions().SetPrintLevel(0);
 
    // more
