@@ -14,7 +14,7 @@
     \brief Advanced Spectra Processing
     \author Miroslav Morhac
 
- \legacy{TSpectrum, For modeling a spectrum fitting  and estimating the background one can use RooFit while for deconvolution and unfolding one can use TUnfold.}
+ \legacy{TSpectrum, For modeling a spectrum fitting and estimating the background one can use RooFit while for deconvolution and unfolding one can use TUnfold.}
 
  This class contains advanced spectra processing functions for:
 
@@ -29,16 +29,6 @@
  2.  M.Morhac et al.: Efficient one- and two-dimensional Gold deconvolution and its application to gamma-ray spectra decomposition. Nuclear Instruments and Methods in Physics Research A 401 (1997) 385-408.
  3.  M.Morhac et al.: Identification of peaks in multidimensional coincidence gamma-ray spectra. Nuclear Instruments and Methods in Research Physics A 443(2000), 108-125.
 
- These NIM papers are also available as doc or ps files from:
-
- - [Spectrum.doc](https://root.cern.ch/download/Spectrum.doc)
- - [SpectrumDec.ps.gz](https://root.cern.ch/download/SpectrumDec.ps.gz)
- - [SpectrumSrc.ps.gz](https://root.cern.ch/download/SpectrumSrc.ps.gz)
- - [SpectrumBck.ps.gz](https://root.cern.ch/download/SpectrumBck.ps.gz)
-
- See also the
- [online documentation](https://root.cern/root/htmldoc/guides/spectrum/Spectrum.html) and
- [tutorials](https://root.cern.ch/doc/master/group__tutorial__spectrum.html).
 */
 
 Int_t TSpectrum::fgIterations    = 3;
@@ -419,7 +409,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// Original spectrum is shown in black color, estimated background in red color.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_incr.C
+/// ../../../tutorials/legacy/spectrum/Background_incr.C
 /// End_Macro
 ///
 /// ### Example 2 script Background_decr.C:
@@ -434,7 +424,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// color, estimated background in red color.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_decr.C
+/// ../../../tutorials/legacy/spectrum/Background_decr.C
 /// End_Macro
 ///
 /// ### Example 3 script Background_width.C:
@@ -451,7 +441,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// 2*numberIterations+1 was greater than the widths of preserved objects (peaks).
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_width.C
+/// ../../../tutorials/legacy/spectrum/Background_width.C
 /// End_Macro
 ///
 /// ### Example 4 script Background_width2.C:
@@ -463,7 +453,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// 40 (magenta line) using decreasing clipping window algorithm.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_width2.C
+/// ../../../tutorials/legacy/spectrum/Background_width2.C
 /// End_Macro
 ///
 /// ### Example 5 script Background_order.C:
@@ -478,7 +468,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// clipping window algorithm.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_order.C
+/// ../../../tutorials/legacy/spectrum/Background_order.C
 /// End_Macro
 ///
 /// ### Example 6 script Background_smooth.C:
@@ -492,7 +482,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// \image html TSpectrum_Background_smooth1.jpg Principle of background estimation algorithm with simultaneous smoothing.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_smooth.C
+/// ../../../tutorials/legacy/spectrum/Background_smooth.C
 /// End_Macro
 ///
 /// ### Example 8 script Background_compton.C:
@@ -509,7 +499,7 @@ void TSpectrum::SetResolution(Double_t resolution)
 /// window algorithm and smoothing (smoothingWindow=5).
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Background_compton.C
+/// ../../../tutorials/legacy/spectrum/Background_compton.C
 /// End_Macro
 
 const char *TSpectrum::Background(Double_t *spectrum, Int_t ssize,
@@ -1192,7 +1182,7 @@ const char *TSpectrum::Background(Double_t *spectrum, Int_t ssize,
 /// ### Example 14 - script Smoothing.C
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Smoothing.C
+/// ../../../tutorials/legacy/spectrum/Smoothing.C
 /// End_Macro
 
 const char* TSpectrum::SmoothMarkov(Double_t *source, int ssize, int averWindow)
@@ -1383,7 +1373,7 @@ const char* TSpectrum::SmoothMarkov(Double_t *source, int ssize, int averWindow)
 /// \image html TSpectrum_Deconvolution2.jpg Principle how the response matrix is composed inside of the Deconvolution function.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Deconvolution.C
+/// ../../../tutorials/legacy/spectrum/Deconvolution.C
 /// End_Macro
 ///
 /// ### Examples of Gold deconvolution method:
@@ -1439,7 +1429,7 @@ const char* TSpectrum::SmoothMarkov(Double_t *source, int ssize, int averWindow)
 /// (10000 iterations) with red color.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Deconvolution_wide.C
+/// ../../../tutorials/legacy/spectrum/Deconvolution_wide.C
 /// End_Macro
 ///
 /// ### Example 10 - script Deconvolution_wide_boost.C :
@@ -1456,7 +1446,7 @@ const char* TSpectrum::SmoothMarkov(Double_t *source, int ssize, int averWindow)
 /// the estimation of the position of small right hand peak.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/Deconvolution_wide_boost.C
+/// ../../../tutorials/legacy/spectrum/Deconvolution_wide_boost.C
 /// End_Macro
 
 const char *TSpectrum::Deconvolution(Double_t *source, const Double_t *response,
@@ -1647,7 +1637,7 @@ const char *TSpectrum::Deconvolution(Double_t *source, const Double_t *response,
 /// the deconvolution (10000 iterations) with red color.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/DeconvolutionRL_wide.C
+/// ../../../tutorials/legacy/spectrum/DeconvolutionRL_wide.C
 /// End_Macro
 ///
 /// ### Example 12 - script DeconvolutionRL_wide_boost.C :
@@ -1662,7 +1652,7 @@ const char *TSpectrum::Deconvolution(Double_t *source, const Double_t *response,
 /// to the results achieved by Gold deconvolution.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/DeconvolutionRL_wide_boost.C
+/// ../../../tutorials/legacy/spectrum/DeconvolutionRL_wide_boost.C
 /// End_Macro
 
 const char *TSpectrum::DeconvolutionRL(Double_t *source, const Double_t *response,
@@ -2114,7 +2104,7 @@ const char *TSpectrum::Unfolding(Double_t *source,
 /// #### Script:
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/SearchHR1.C
+/// ../../../tutorials/legacy/spectrum/SearchHR1.C
 /// End_Macro
 ///
 /// ### Example 16 - script SearchHR3.C:
@@ -2123,7 +2113,7 @@ const char *TSpectrum::Unfolding(Double_t *source,
 /// sigma=8, smoothing width=3.
 ///
 /// Begin_Macro(source)
-/// ../../../tutorials/spectrum/SearchHR3.C
+/// ../../../tutorials/legacy/spectrum/SearchHR3.C
 /// End_Macro
 
 Int_t TSpectrum::SearchHighRes(Double_t *source,Double_t *destVector, int ssize,
