@@ -19,7 +19,6 @@
 #include <memory>
 
 namespace clang {
-  class ASTDeserializationListener;
   class Decl;
   class DeclContext;
   class DeclarationName;
@@ -37,7 +36,6 @@ namespace clang {
 namespace cling {
   class Interpreter;
   class InterpreterCallbacks;
-  class InterpreterDeserializationListener;
   class InterpreterExternalSemaSource;
   class InterpreterPPCallbacks;
   class Transaction;
@@ -57,12 +55,6 @@ namespace cling {
     ///
     InterpreterExternalSemaSource* m_ExternalSemaSource;
 
-    ///\brief Our custom ASTDeserializationListener, translating interesting
-    /// events into callbacks.
-    ///
-    std::unique_ptr
-    <InterpreterDeserializationListener> m_DeserializationListener;
-
     ///\brief Our custom PPCallbacks, translating interesting
     /// events into interpreter callbacks.
     ///
@@ -83,15 +75,11 @@ namespace cling {
     ///\param[in] interp - an interpreter.
     ///\param[in] enableExternalSemaSourceCallbacks  - creates a default
     ///           InterpreterExternalSemaSource and attaches it to Sema.
-    ///\param[in] enableDeserializationListenerCallbacks - creates a default
-    ///           InterpreterDeserializationListener and attaches it to the
-    ///           ModuleManager if it is set.
     ///\param[in] enablePPCallbacks  - creates a default InterpreterPPCallbacks
     ///           and attaches it to the Preprocessor.
     ///
     InterpreterCallbacks(Interpreter* interp,
                          bool enableExternalSemaSourceCallbacks = false,
-                         bool enableDeserializationListenerCallbacks = false,
                          bool enablePPCallbacks = false);
 
     virtual ~InterpreterCallbacks();
@@ -99,9 +87,6 @@ namespace cling {
     cling::Interpreter* getInterpreter() const { return m_Interpreter; }
     clang::ExternalSemaSource* getInterpreterExternalSemaSource() const;
 
-    clang::ASTDeserializationListener*
-    getInterpreterDeserializationListener() const;
-
    virtual void InclusionDirective(clang::SourceLocation /*HashLoc*/,
                                    const clang::Token& /*IncludeTok*/,
                                    llvm::StringRef /*FileName*/,
@@ -174,16 +159,6 @@ namespace cling {
     ///\param[in] - The declaration that has been shadowed.
     virtual void DefinitionShadowed(const clang::NamedDecl*) {}
 
-    /// \brief Used to inform client about a new decl read by the ASTReader.
-    ///
-    ///\param[in] - The Decl read by the ASTReader.
-    virtual void DeclDeserialized(const clang::Decl*) {}
-
-    /// \brief Used to inform client about a new type read by the ASTReader.
-    ///
-    ///\param[in] - The Type read by the ASTReader.
-    virtual void TypeDeserialized(const clang::Type*) {}
-
     virtual void LibraryLoaded(const void*, llvm::StringRef) {}
     virtual void LibraryUnloaded(const void*, llvm::StringRef) {}
 
