@@ -210,8 +210,12 @@ namespace cling {
     }
 
     // Create a new body.
-    auto newCS = CompoundStmt::Create(*m_Context, Stmts, CS->getLBracLoc(),
-                                      CS->getRBracLoc());
+    FPOptionsOverride FPFeatures;
+    if (CS->hasStoredFPFeatures()) {
+      FPFeatures = CS->getStoredFPFeatures();
+    }
+    auto newCS = CompoundStmt::Create(*m_Context, Stmts, FPFeatures,
+                                      CS->getLBracLoc(), CS->getRBracLoc());
     FD->setBody(newCS);
 
     if (hasNoErrors && !TouchedDecls.empty()) {
@@ -268,7 +272,7 @@ namespace cling {
 
     // Wrap Stmts into a function body.
     llvm::ArrayRef<Stmt*> StmtsRef(Stmts.data(), Stmts.size());
-    CompoundStmt* CS = CompoundStmt::Create(*m_Context, StmtsRef, Loc, Loc);
+    CompoundStmt* CS = CompoundStmt::Create(*m_Context, StmtsRef, {}, Loc, Loc);
     FD->setBody(CS);
     Emit(FD);
 
@@ -354,7 +358,7 @@ namespace cling {
            && "Cannot handle that yet!");
     bool isExplicitSpecialization = false;
 
-    if (Kind == TTK_Enum) {
+    if (Kind == TagTypeKind::Enum) {
       EnumDecl* ED = cast<EnumDecl>(NewTD);
       bool ScopedEnum = ED->isScoped();
       const QualType QT = ED->getIntegerType();
@@ -545,8 +549,9 @@ namespace cling {
           if (!m_Sema->isAcceptableTagRedeclaration(PrevTagDecl, Kind,
                                           NewTD->isThisDeclarationADefinition(),
                                                     KWLoc, Name)) {
-            bool SafeToContinue
-              = (PrevTagDecl->getTagKind() != TTK_Enum && Kind != TTK_Enum);
+            bool SafeToContinue =
+                (PrevTagDecl->getTagKind() != TagTypeKind::Enum &&
+                 Kind != TagTypeKind::Enum);
 
             if (SafeToContinue)
               m_Sema->Diag(KWLoc, diag::err_use_with_wrong_tag)
@@ -567,7 +572,8 @@ namespace cling {
             }
           }
 
-          if (Kind == TTK_Enum && PrevTagDecl->getTagKind() == TTK_Enum) {
+          if (Kind == TagTypeKind::Enum &&
+              PrevTagDecl->getTagKind() == TagTypeKind::Enum) {
             const EnumDecl *NewEnum = cast<EnumDecl>(NewTD);
             const EnumDecl *PrevEnum = cast<EnumDecl>(PrevTagDecl);
 
