@@ -21,6 +21,8 @@ namespace {
 ///\brief A Lexer that exposes preprocessor directives.
 class MinimalPPLexer: public Lexer {
 
+  const LangOptions &LangOpts;
+
   ///\brief Jump to the next token after a scope chain A::B::C::D
   ///
   bool SkipScopes(Token& Tok) {
@@ -31,7 +33,7 @@ class MinimalPPLexer: public Lexer {
   bool SkipScopes(Token& Tok, Token& LastTok) {
     LastTok = Tok;
 
-    if (getLangOpts().CPlusPlus) {
+    if (LangOpts.CPlusPlus) {
       while (Tok.is(tok::coloncolon)) {
         if (!LexClean(LastTok) || Identifier(LastTok).empty())
           return false;
@@ -59,7 +61,7 @@ class MinimalPPLexer: public Lexer {
   llvm::StringRef Identifier(Token& Tok) const {
     if (Tok.is(tok::raw_identifier)) {
       StringRef Id(Tok.getRawIdentifier());
-      if (Lexer::isIdentifierBodyChar(Id.front(), getLangOpts()))
+      if (Lexer::isAsciiIdentifierContinueChar(Id.front(), LangOpts))
         return Id;
     }
     return llvm::StringRef();
@@ -89,7 +91,7 @@ class MinimalPPLexer: public Lexer {
     if (Ident.empty())
       return false;
 
-    if (Ident.equals("operator")) {
+    if (Ident == "operator") {
       // Tok is the operator, e.g. <=, ==, +...
       // however, for operator() and [], Tok only contains the
       // left side so we need to parse the closing right side
@@ -114,7 +116,8 @@ public:
   ///\brief Construct a Lexer from LangOpts and source.
   MinimalPPLexer(const LangOptions &LOpts, llvm::StringRef source):
     Lexer(SourceLocation(), LOpts,
-          source.begin(), source.begin(), source.end()) {}
+          source.begin(), source.begin(), source.end()),
+    LangOpts(LOpts) {}
 
   bool inPPDirective() const { return ParsingPreprocessorDirective; }
 
@@ -196,7 +199,7 @@ public:
                                    bool& HasBody) {
     HasBody = true;
     /// ###TODO: Allow preprocessor expansion
-    if (!Lexer::isIdentifierBodyChar(First.front(), getLangOpts()))
+    if (!Lexer::isAsciiIdentifierContinueChar(First.front(), LangOpts))
       return kNONE;
 
     // Early out calling a function/macro Ident()
@@ -206,7 +209,7 @@ public:
     bool Ctor = false;
     bool Dtor = false;
 
-    if (getLangOpts().CPlusPlus && Tok.is(tok::coloncolon)) {
+    if (LangOpts.CPlusPlus && Tok.is(tok::coloncolon)) {
       // CLASS::CLASS() or CLASS::~CLASS()
       // CLASS::NESTED::NESTED()
       // CLASS::type func()
@@ -248,7 +251,7 @@ public:
         Ctor = true;
 
       // Constructor and Destructor identifiers must match
-      if (!First.equals(Ident)) {
+      if (First != Ident) {
         if (!SkipPointerRefs(Tok))
           return kNONE;
 
@@ -264,13 +267,19 @@ public:
         Dtor = false;
       }
     } else {
-      bool SeenSignedness = false;
-      if (First.equals("struct") || First.equals("class")) {
+      bool SeenModifier = false;
+      auto AnalyzeModifier = [&SeenModifier](llvm::StringRef Modifier) {
+        if (Modifier == "signed" || Modifier == "unsigned" ||
+            Modifier == "short" || Modifier == "long") {
+          SeenModifier = true;
+        }
+      };
+      if (First == "struct" || First == "class") {
         do {
           // Identifier(Tok).empty() is redundant 1st time, but simplifies code
           if (Identifier(Tok).empty() || !LexClean(Tok))
             return kNONE;
-        } while (getLangOpts().CPlusPlus && Tok.is(tok::coloncolon) &&
+        } while (LangOpts.CPlusPlus && Tok.is(tok::coloncolon) &&
                  LexClean(Tok));
 
         // 'class T {' 'struct T {' 'class T :'
@@ -279,26 +288,25 @@ public:
         if (Tok.is(tok::colon))
           return !AdvanceTo(Tok, tok::l_brace) ? kClass : kNONE;
 
-      } else if (First.equals("static") || First.equals("constexpr") ||
-                 First.equals("inline") || First.equals("const")) {
-        // First check if the current keyword is "unsigned".
+      } else if (First == "static" || First == "constexpr" ||
+                 First == "inline" || First == "const") {
+        // First check if the current keyword is a modifier.
         llvm::StringRef Modifier = Identifier(Tok);
-        if (Modifier.equals("signed") || Modifier.equals("unsigned"))
-          SeenSignedness = true;
+        AnalyzeModifier(Modifier);
 
         // Advance past keyword for below
         if (!LexClean(Tok))
           return kNONE;
-      } else if (First.equals("signed") || First.equals("unsigned")) {
-        SeenSignedness = true;
+      } else {
+        AnalyzeModifier(First);
       }
 
       if (!SkipIdentifier(Tok))
         return kNONE;
 
-      // If we have not yet reached the argument list and seen a signedness
-      // modifier keyword, try to skip this once.
-      if (SeenSignedness && Tok.isNot(tok::l_paren) && !SkipIdentifier(Tok))
+      // If we have not yet reached the argument list and seen a modifier
+      // keyword, try to skip this once.
+      if (SeenModifier && Tok.isNot(tok::l_paren) && !SkipIdentifier(Tok))
         return kNONE;
     }
 
@@ -331,7 +339,26 @@ public:
     if (Tok.is(tok::l_brace))
       return kFunction;
 
-    if (getLangOpts().CPlusPlus) {
+    // Handle trailing return type: `int func() ->`
+    if (LangOpts.CPlusPlus && Tok.is(tok::arrow)) {
+      if (!LexClean(Tok))
+        return kNONE;
+
+      // Parse the return type
+      // eg, `int` or `std::vector<int>` or `int*` or `int&`
+      while (Tok.is(tok::raw_identifier) || Tok.is(tok::coloncolon) ||
+             Tok.is(tok::less) || Tok.is(tok::greater) || Tok.is(tok::star) ||
+             Tok.is(tok::amp)) {
+        if (!LexClean(Tok))
+          return kNONE;
+      }
+
+      // `int func() -> int {`
+      if (Tok.is(tok::l_brace))
+        return kFunction;
+    }
+
+    if (LangOpts.CPlusPlus) {
       // constructor initialization 'CLASS::CLASS() :'
       if (Ctor && Tok.is(tok::colon))
         return !AdvanceTo(Tok, tok::l_brace) ? kFunction : kNONE;
@@ -350,7 +377,7 @@ public:
       }
 
       // class const method 'CLASS::method() const {'
-      if (!Ctor && Identifier(Tok).equals("const")) {
+      if (!Ctor && Identifier(Tok) == "const") {
         if (LexClean(Tok) && Tok.is(tok::l_brace))
           return kFunction;
       }
@@ -385,7 +412,7 @@ cling::utils::isUnnamedMacro(llvm::StringRef source,
       if (AfterHash) {
         if (Tok.is(tok::raw_identifier)) {
           StringRef keyword(Tok.getRawIdentifier());
-          if (keyword.startswith("if")) {
+          if (keyword.starts_with("if")) {
             // This could well be
             //   #if FOO
             //   {
@@ -438,7 +465,7 @@ size_t cling::utils::getWrapPoint(std::string& source,
       continue; // Skip PP directives; they just move the wrap point.
     }
 
-    if (Tok.is(tok::eof)) {
+    if (Tok.is(tok::annot_repl_input_end)) {
       // Reached EOF before seeing a non-preproc token.
       // Nothing to wrap.
       return std::string::npos;
@@ -451,8 +478,8 @@ size_t cling::utils::getWrapPoint(std::string& source,
       do {
         if (Tok.getKind() == tok::raw_identifier) {
           StringRef keyword(Tok.getRawIdentifier());
-          if (keyword.equals("__global__") || keyword.equals("__device__") ||
-              keyword.equals("__host__"))
+          if (keyword == "__global__" || keyword == "__device__" ||
+              keyword == "__host__")
             // if attribute was found, skip the token and use the function
             // detection later
             Lex.Lex(Tok);
@@ -492,7 +519,7 @@ size_t cling::utils::getWrapPoint(std::string& source,
 
     if (Tok.getKind() == tok::raw_identifier && !Tok.needsCleaning()) {
       StringRef keyword(Tok.getRawIdentifier());
-      if (keyword.equals("using")) {
+      if (keyword == "using") {
         // FIXME: Using definitions and declarations should be decl extracted.
         // Until we have that, don't wrap them if they are the only input.
         if (Lex.AdvanceTo(Tok, tok::semi)) {
@@ -506,11 +533,11 @@ size_t cling::utils::getWrapPoint(std::string& source,
         // non-wrapped statement.
         return getFileOffset(Tok) + 1;
       }
-      if (keyword.equals("extern"))
+      if (keyword == "extern")
         return std::string::npos;
-      if (keyword.equals("namespace"))
+      if (keyword == "namespace")
         return std::string::npos;
-      if (keyword.equals("template"))
+      if (keyword == "template")
         return std::string::npos;
 
       auto HasBody{false};
