@@ -28,6 +28,14 @@ class TIOFeatures;
 }  // namespace ROOT
 
 class TFileMerger : public TObject {
+public:
+   enum class EErrorBehavior {
+      /// The merging process will stop and yield failure when encountering invalid objects
+      kFailOnError,
+      /// The merging process will skip invalid objects and continue
+      kSkipOnError
+   };
+
 private:
    using TIOFeatures = ROOT::TIOFeatures;
 
@@ -47,6 +55,7 @@ protected:
    TString        fMergeOptions;              ///< Options (in string format) to be passed down to the Merge functions
    TIOFeatures   *fIOFeatures{nullptr};       ///< IO features to use in the output file.
    TString        fMsgPrefix{"TFileMerger"};  ///< Prefix to be used when printing informational message (default TFileMerger)
+   EErrorBehavior fErrBehavior = EErrorBehavior::kFailOnError; ///< What to do in case of errors during merging
 
    Int_t          fMaxOpenedFiles;            ///< Maximum number of files opened at the same time by the TFileMerger
    Bool_t         fLocal;                     ///< Makes local copies of merging files if True (default is kTRUE)
@@ -126,8 +135,12 @@ public:
            Bool_t GetNotrees() const { return fNoTrees; }
    virtual void   SetNotrees(Bool_t notrees=kFALSE) {fNoTrees = notrees;}
            void   RecursiveRemove(TObject *obj) override;
+           /// Determines how the merging process should behave when encontering invalid objects.
+           /// By default the merging will be aborted.
+           /// \sa EErrorBehavior
+           void SetErrorBehavior(EErrorBehavior errBehavior) { fErrBehavior = errBehavior; }
 
-   ClassDefOverride(TFileMerger, 6)  // File copying and merging services
+           ClassDefOverride(TFileMerger, 6) // File copying and merging services
 };
 
 #endif
