@@ -39,8 +39,6 @@ public:
    }
 
    std::uint64_t GetSizeImpl() final { return fContent.size(); }
-
-   int GetFeatures() const final { return kFeatureHasSize; }
 };
 
 } // anonymous namespace
@@ -51,7 +49,6 @@ TEST(RRawFile, Empty)
    FileRaii emptyGuard("test_rrawfile_empty", "");
    auto f = RRawFile::Create(emptyGuard.GetPath());
    EXPECT_FALSE(f->IsOpen());
-   EXPECT_TRUE(f->GetFeatures() & RRawFile::kFeatureHasSize);
    EXPECT_EQ(0u, f->GetSize());
    EXPECT_EQ(0u, f->GetFilePos());
    EXPECT_EQ(0u, f->Read(nullptr, 0));
@@ -59,6 +56,12 @@ TEST(RRawFile, Empty)
    std::string line;
    EXPECT_FALSE(f->Readln(line));
    EXPECT_TRUE(f->IsOpen());
+
+   RRawFile::ROptions options;
+   options.fBlockSize = 0;
+   f = RRawFile::Create(emptyGuard.GetPath(), options);
+   EXPECT_EQ(0u, f->Read(nullptr, 0));
+   EXPECT_EQ(0u, f->ReadAt(nullptr, 0, 1));
 }
 
 
@@ -214,26 +217,37 @@ TEST(RRawFile, ReadBuffered)
    EXPECT_EQ(1u, f->fNumReadAt); f->fNumReadAt = 0;
 }
 
-
-TEST(RRawFile, Mmap)
+TEST(RRawFile, SetBuffering)
 {
-   std::uint64_t mapdOffset;
-   std::unique_ptr<RRawFileMock> m(new RRawFileMock("", RRawFile::ROptions()));
-   EXPECT_FALSE(m->GetFeatures() & RRawFile::kFeatureHasMmap);
-   EXPECT_THROW(m->Map(1, 0, mapdOffset), std::runtime_error);
-   EXPECT_THROW(m->Unmap(this, 1), std::runtime_error);
+   char buffer[3];
+   RRawFile::ROptions options;
+   options.fBlockSize = 2;
+   std::unique_ptr<RRawFileMock> f(new RRawFileMock("abcd", options));
 
-   void *region;
-   FileRaii mmapGuard("test_rawfile_mmap", "foo");
-   auto f = RRawFile::Create(mmapGuard.GetPath());
-   if (!(f->GetFeatures() & RRawFile::kFeatureHasMmap))
-      return;
-   region = f->Map(2, 1, mapdOffset);
-   auto innerOffset = 1 - mapdOffset;
-   ASSERT_NE(region, nullptr);
-   EXPECT_EQ("oo", std::string(reinterpret_cast<char *>(region) + innerOffset, 2));
-   auto mapdLength = 2 + innerOffset;
-   f->Unmap(region, mapdLength);
+   buffer[2] = '\0';
+   EXPECT_EQ(1u, f->ReadAt(buffer, 1, 0));
+   EXPECT_EQ(1u, f->ReadAt(buffer + 1, 1, 1));
+   EXPECT_STREQ("ab", buffer);
+   EXPECT_EQ(1u, f->fNumReadAt);
+   f->fNumReadAt = 0;
+
+   f->SetBuffering(false);
+   // idempotent
+   f->SetBuffering(false);
+   EXPECT_EQ(1u, f->ReadAt(buffer, 1, 0));
+   EXPECT_EQ(1u, f->ReadAt(buffer + 1, 1, 1));
+   EXPECT_STREQ("ab", buffer);
+   EXPECT_EQ(2u, f->fNumReadAt);
+   f->fNumReadAt = 0;
+
+   f->SetBuffering(true);
+   // idempotent
+   f->SetBuffering(true);
+   EXPECT_EQ(1u, f->ReadAt(buffer, 1, 2));
+   EXPECT_EQ(1u, f->ReadAt(buffer + 1, 1, 3));
+   EXPECT_STREQ("cd", buffer);
+   EXPECT_EQ(1u, f->fNumReadAt);
+   f->fNumReadAt = 0;
 }
 
 TEST(RRawFileTFile, TFile)
