@@ -4,19 +4,6 @@
 
 #include "gtest/gtest.h"
 
-// Backward compatibility for gtest version < 1.10.0
-#ifndef TYPED_TEST_SUITE_P
-#define TYPED_TEST_SUITE_P TYPED_TEST_CASE_P
-#endif
-// Backward compatibility for gtest version < 1.10.0
-#ifndef REGISTER_TYPED_TEST_SUITE_P
-#define REGISTER_TYPED_TEST_SUITE_P REGISTER_TYPED_TEST_CASE_P
-#endif
-// Backward compatibility for gtest version < 1.10.0
-#ifndef INSTANTIATE_TYPED_TEST_SUITE_P
-#define INSTANTIATE_TYPED_TEST_SUITE_P INSTANTIATE_TYPED_TEST_CASE_P
-#endif
-
 #include "StatFunction.h"
 #include "TestHelper.h"
 #include "VectorTest.h"
