@@ -72,11 +72,7 @@ struct GoFTStress {
 
       printf("*****************************************************************************************\n");
       gBenchmark->Print("GoFTestStress");
-#ifdef __CINT__
-      Double_t reftime = 0.02 ; // slc4rabacal interpreted (CPU time taken to run complete tests with ACLiC)
-#else
       Double_t reftime = 0.04; // slc4rabacal compiled (CPU time taken to run complete tests)
-#endif
 
       Double_t rootmarks = 800. * reftime / gBenchmark->GetCpuTime("GoFTestStress");
 
@@ -103,7 +99,7 @@ struct GoFTStress {
 
       ROOT::Math::GoFTest* goft = new ROOT::Math::GoFTest( smpSize1, smp1, smpSize2, smp2 );
 
-      Double_t A2 = goft->AndersonDarling2SamplesTest("t"); // standartized A2_akN
+      Double_t A2 = goft->AndersonDarling2SamplesTest("t"); // standardized A2_akN
    //     Double_t pvalueAD = goft->AndersonDarling2SamplesTest();
       Double_t pvalueAD = (*goft)(ROOT::Math::GoFTest::kAD2s);
 
@@ -115,7 +111,7 @@ struct GoFTStress {
 
       Int_t result = PrintResultAD2Samples(nsmps, A2, expectedA2_akN, sigmaN, zScore, pvalueAD);
 
-   //     Double_t Dn = goft->KolmogorovSmirnov2SamplesTest("t"); // standartized A2_akN
+   //     Double_t Dn = goft->KolmogorovSmirnov2SamplesTest("t"); // standardized A2_akN
       Double_t Dn = (*goft)(ROOT::Math::GoFTest::kKS2s, "t");
       Double_t pvalueKS = goft->KolmogorovSmirnov2SamplesTest();
 
@@ -141,7 +137,7 @@ struct GoFTStress {
 
       ROOT::Math::GoFTest* goft = new ROOT::Math::GoFTest( smpSize, smp1, smpSize, smp2 );
 
-   //     Double_t A2 = goft->AndersonDarling2SamplesTest("t"); // standartized A2_akN
+   //     Double_t A2 = goft->AndersonDarling2SamplesTest("t"); // standardized A2_akN
       Double_t A2 = (*goft)(ROOT::Math::GoFTest::kAD2s, "t");
       Double_t pvalueAD = goft->AndersonDarling2SamplesTest();
 
@@ -153,7 +149,7 @@ struct GoFTStress {
 
       Int_t result = PrintResultAD2Samples(nsmps, A2, expectedA2_akN, sigmaN, zScore, pvalueAD);
 
-      Double_t Dn = goft->KolmogorovSmirnov2SamplesTest("t"); // standartized A2_akN
+      Double_t Dn = goft->KolmogorovSmirnov2SamplesTest("t"); // standardized A2_akN
    //     Double_t pvalueKS = goft->KolmogorovSmirnov2SamplesTest();
       Double_t pvalueKS = (*goft)(ROOT::Math::GoFTest::kKS2s);
 
@@ -551,11 +547,11 @@ Int_t RunTests(Int_t argc, Char_t* argv[]) {
    return result;
 }
 
-Int_t stressGoFTest(Int_t argc = 1 , Char_t* argv[] = 0) {
+Int_t stressGoFTest(Int_t argc = 1 , Char_t* argv[] = nullptr) {
    return RunTests(argc, argv);
 }
 
-#if !defined(__CINT__) && !defined(__MAKECINT__)
+#if !defined(__CLING__)
 Int_t main(Int_t argc, Char_t* argv[]) {
    return RunTests(argc, argv);
 }
