@@ -51,19 +51,18 @@ struct BasisFunction {
    const Func * fFunc;
 };
 
-
-//______________________________________________________________________________
-//
-//  TLinearMinimizer, simple class implementing the ROOT::Math::Minimizer interface using
-//  TLinearFitter.
-//  This class uses TLinearFitter to find directly (by solving a system of linear equations)
-//  the minimum of a
-//  least-square function which has a linear dependence in the fit parameters.
-//  This class is not used directly, but via the ROOT::Fitter class, when calling the
-//  LinearFit method. It is instantiates using the plug-in manager (plug-in name is "Linear")
-//
-//__________________________________________________________________________________________
-
+////////////////////////////////////////////////////////////////////////////////
+/// \class TLinearMinimizer
+/// \note See ROOT::Minuit2 for a newer version of this class.
+///
+/// TLinearMinimizer, simple class implementing the ROOT::Math::Minimizer
+/// interface usingTLinearFitter. This class uses TLinearFitter to find directly
+/// (by solving a system of linear equations) the minimum of a least-square
+/// function which has a linear dependence in the fit parameters. This class is
+/// not used directly, but via the ROOT::Fitter class, when calling the
+/// LinearFit method. It is instantiates using the plug-in manager
+/// (plug-in name is "Linear").
+////////////////////////////////////////////////////////////////////////////////
 
 ClassImp(TLinearMinimizer);
 
@@ -104,20 +103,6 @@ TLinearMinimizer::~TLinearMinimizer()
    if (fFitter) delete fFitter;
 }
 
-TLinearMinimizer::TLinearMinimizer(const TLinearMinimizer &) :
-   Minimizer()
-{
-   // Implementation of copy constructor.
-}
-
-TLinearMinimizer & TLinearMinimizer::operator = (const TLinearMinimizer &rhs)
-{
-   // Implementation of assignment operator.
-   if (this == &rhs) return *this;  // time saving self-test
-   return *this;
-}
-
-
 void TLinearMinimizer::SetFunction(const  ROOT::Math::IMultiGenFunction & objfunc) {
    // Set the function to be minimized. The function must be a Chi2 gradient function
    // When performing a linear fit we need the basis functions, which are the partial derivatives with respect to the parameters of the model function.
