@@ -54,7 +54,6 @@ RooPoison(N,mu) and treating the function as a PDF in mu.
 
 #include <cmath>
 
-ClassImp(RooGamma);
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -87,11 +86,10 @@ double RooGamma::evaluate() const
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Compute multiple values of Gamma PDF.
-void RooGamma::computeBatch(cudaStream_t* stream, double* output, size_t nEvents, RooFit::Detail::DataMap const& dataMap) const
+void RooGamma::doEval(RooFit::EvalContext &ctx) const
 {
-  auto dispatch = stream ? RooBatchCompute::dispatchCUDA : RooBatchCompute::dispatchCPU;
-  dispatch->compute(stream, RooBatchCompute::Gamma, output, nEvents,
-          {dataMap.at(x), dataMap.at(gamma), dataMap.at(beta), dataMap.at(mu)});
+   RooBatchCompute::compute(ctx.config(this), RooBatchCompute::Gamma, ctx.output(),
+                            {ctx.at(x), ctx.at(gamma), ctx.at(beta), ctx.at(mu)});
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -104,13 +102,11 @@ Int_t RooGamma::getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVars, c
 
 ////////////////////////////////////////////////////////////////////////////////
 
-double RooGamma::analyticalIntegral(Int_t code, const char* rangeName) const
+double RooGamma::analyticalIntegral(Int_t /*code*/, const char *rangeName) const
 {
-  R__ASSERT(code==1) ;
-
- //integral of the Gamma distribution via ROOT::Math
-  double integral = ROOT::Math::gamma_cdf(x.max(rangeName), gamma, beta, mu) - ROOT::Math::gamma_cdf(x.min(rangeName), gamma, beta, mu);
-  return integral ;
+   // integral of the Gamma distribution via ROOT::Math
+   return ROOT::Math::gamma_cdf(x.max(rangeName), gamma, beta, mu) -
+          ROOT::Math::gamma_cdf(x.min(rangeName), gamma, beta, mu);
 }
 
 namespace {
@@ -120,7 +116,7 @@ inline double randomGamma(double gamma, double beta, double mu, double xmin, dou
    while (true) {
 
       double d = gamma - 1. / 3.;
-      double c = 1. / TMath::Sqrt(9. * d);
+      double c = 1. / std::sqrt(9. * d);
       double xgen = 0;
       double v = 0;
 
@@ -136,7 +132,7 @@ inline double randomGamma(double gamma, double beta, double mu, double xmin, dou
             return x;
          }
       }
-      if (TMath::Log(u) < 0.5 * xgen * xgen + d * (1. - v + TMath::Log(v))) {
+      if (std::log(u) < 0.5 * xgen * xgen + d * (1. - v + TMath::Log(v))) {
          double x = ((d * v) * beta + mu);
          if ((x < xmax) && (x > xmin)) {
             return x;
