@@ -1,3 +1,5 @@
+#ifdef __ROOFIT_BANNER
+
 #include "RConfigure.h"
 #include "TEnv.h"
 
@@ -6,7 +8,6 @@
 /**
 \file Initialisation.cxx
 \ingroup Roofitcore
-
 Run static initialisers on first load of RooFitCore.
 **/
 
@@ -15,7 +16,6 @@ namespace {
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 /// Print RooFit banner.
 void doBanner() {
-#ifndef __ROOFIT_NOBANNER
   if (gEnv->GetValue("RooFit.Banner", 1) == 0)
     return;
 
@@ -27,7 +27,6 @@ void doBanner() {
       << "                Copyright (C) 2000-2013 NIKHEF, University of California & Stanford University" << '\n'
       << "                All rights reserved, please read http://roofit.sourceforge.net/license.txt" << '\n'
       << std::endl;
-#endif
 }
 
 
@@ -40,3 +39,5 @@ static struct RooFitInitialiser {
 } __rooFitInitialiser;
 
 }
+
+#endif
