@@ -21,8 +21,9 @@
 ///  - Every object it contains must have a unique name returned by GetName().
 ///
 ///  - Contained objects are not ordered, although the set can be traversed
-///    using an iterator returned by createIterator(). The iterator does not
-///    necessarily follow the object insertion order.
+///    just like standard library containers such as `std::vector`
+///    (in fact, the RooArgSet uses a `std::vector<RooAbsArg *>` under the hood).
+///    The iterator does not necessarily follow the object insertion order.
 ///
 ///  - Objects can be retrieved by name only, and not by index.
 ///
@@ -38,10 +39,17 @@
 /// as unowned elements.
 ///
 ///
+/// Uniquely identifying RooArgSet objects
+/// ---------------------------------------
+///
+/// \warning Before v6.28, it was ensured that no RooArgSet objects on the heap
+/// were located at an address that had already been used for a RooArgSet before.
+/// With v6.28, this is not guaranteed anymore. Hence, if your code uses pointer
+/// comparisons to uniquely identify RooArgSet instances, please consider using
+/// the new `RooArgSet::uniqueId()`.
 
 #include "RooArgSet.h"
 
-#include "TClass.h"
 #include "RooStreamParser.h"
 #include "RooFormula.h"
 #include "RooAbsRealLValue.h"
@@ -51,7 +59,7 @@
 #include "RooArgList.h"
 #include "RooSentinel.h"
 #include "RooMsgService.h"
-#include "ROOT/RMakeUnique.hxx"
+#include "RooConstVar.h"
 #include "strlcpy.h"
 
 #include <iostream>
@@ -59,94 +67,18 @@
 #include <iomanip>
 #include <stdexcept>
 
-using namespace std ;
-
-#if (__GNUC__==3&&__GNUC_MINOR__==2&&__GNUC_PATCHLEVEL__==3)
-char* operator+( streampos&, char* );
-#endif
-
-ClassImp(RooArgSet);
+using std::istream, std::ostream, std::ifstream, std::ofstream, std::endl;
 
 
-
-#ifndef USEMEMPOOLFORARGSET
 void RooArgSet::cleanup() { }
-#else
-
-#include "MemPoolForRooSets.h"
-
-RooArgSet::MemPool* RooArgSet::memPool() {
-  RooSentinel::activate();
-  static auto * memPool = new RooArgSet::MemPool();
-  return memPool;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-/// Clear memory pool on exit to avoid reported memory leaks
-
-void RooArgSet::cleanup()
-{
-  auto pool = memPool();
-  memPool()->teardown();
-
-  //Here, the pool might have to leak if RooArgSets are still alive.
-  if (pool->empty())
-    delete pool;
-}
-
-
-////////////////////////////////////////////////////////////////////////////////
-/// Overloaded new operator guarantees that all RooArgSets allocated with new
-/// have a unique address, a property that is exploited in several places
-/// in roofit to quickly index contents on normalization set pointers. 
-/// The memory pool only allocates space for the class itself. The elements
-/// stored in the set are stored outside the pool.
-
-void* RooArgSet::operator new (size_t bytes)
-{
-  //This will fail if a derived class uses this operator
-  assert(sizeof(RooArgSet) == bytes);
-
-  return memPool()->allocate(bytes);
-}
-
-
-////////////////////////////////////////////////////////////////////////////////
-/// Overloaded new operator with placement does not guarante that all
-/// RooArgSets allocated with new have a unique address, but uses the global
-/// operator.
-
-void* RooArgSet::operator new (size_t bytes, void* ptr) noexcept
-{
-   return ::operator new (bytes, ptr);
-}
-
-
-////////////////////////////////////////////////////////////////////////////////
-/// Memory is owned by pool, we need to do nothing to release it
-
-void RooArgSet::operator delete (void* ptr)
-{
-  // Decrease use count in pool that ptr is on
-  if (memPool()->deallocate(ptr))
-    return;
-
-  std::cerr << __func__ << " " << ptr << " is not in any of the pools." << std::endl;
-
-  // Not part of any pool; use global op delete:
-  ::operator delete(ptr);
-}
-
-#endif
 
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Default constructor
 
-RooArgSet::RooArgSet() :
-  RooAbsCollection()
+RooArgSet::RooArgSet()
 {
-  TRACE_CREATE
+  TRACE_CREATE;
 }
 
 
@@ -154,11 +86,11 @@ RooArgSet::RooArgSet() :
 /// Constructor from a RooArgList. If the list contains multiple
 /// objects with the same name, only the first is store in the set.
 /// Warning messages will be printed for dropped items.
-RooArgSet::RooArgSet(const RooArgList& list) :
-  RooAbsCollection(list.GetName())
+RooArgSet::RooArgSet(const RooAbsCollection& coll) :
+  RooAbsCollection(coll.GetName())
 {
-  add(list,kTRUE) ; // verbose to catch duplicate errors
-  TRACE_CREATE
+  add(coll,true) ; // verbose to catch duplicate errors
+  TRACE_CREATE;
 }
 
 
@@ -174,10 +106,10 @@ RooArgSet::RooArgSet(const RooAbsCollection& collection, const RooAbsArg* var1)
   RooAbsCollection(collection.GetName())
 {
   if (var1 && !collection.contains(*var1)) {
-    add(*var1,kTRUE) ;
+    add(*var1,true) ;
   }
-  add(collection,kTRUE) ; // verbose to catch duplicate errors
-  TRACE_CREATE
+  add(collection,true) ; // verbose to catch duplicate errors
+  TRACE_CREATE;
 }
 
 
@@ -186,7 +118,7 @@ RooArgSet::RooArgSet(const RooAbsCollection& collection, const RooAbsArg* var1)
 RooArgSet::RooArgSet(const char *name) :
   RooAbsCollection(name)
 {
-  TRACE_CREATE
+  TRACE_CREATE;
 }
 
 
@@ -197,7 +129,7 @@ RooArgSet::RooArgSet(const RooArgSet& set1, const RooArgSet& set2, const char *n
 {
   add(set1) ;
   add(set2) ;
-  TRACE_CREATE
+  TRACE_CREATE;
 }
 
 
@@ -209,18 +141,15 @@ RooArgSet::RooArgSet(const RooArgSet& set1, const RooArgSet& set2, const char *n
 RooArgSet::RooArgSet(const TCollection& tcoll, const char* name) :
   RooAbsCollection(name)
 {
-  TIterator* iter = tcoll.MakeIterator() ;
-  TObject* obj ;
-  while((obj=iter->Next())) {
+  for(TObject* obj : tcoll) {
     if (!dynamic_cast<RooAbsArg*>(obj)) {
-      coutW(InputArguments) << "RooArgSet::RooArgSet(TCollection) element " << obj->GetName() 
-			    << " is not a RooAbsArg, ignored" << endl ;
+      coutW(InputArguments) << "RooArgSet::RooArgSet(TCollection) element " << obj->GetName()
+             << " is not a RooAbsArg, ignored" << std::endl ;
       continue ;
     }
-    add(*(RooAbsArg*)obj) ;
+    add(*static_cast<RooAbsArg*>(obj)) ;
   }
-  delete iter ;
-  TRACE_CREATE
+  TRACE_CREATE;
 }
 
 
@@ -231,66 +160,20 @@ RooArgSet::RooArgSet(const TCollection& tcoll, const char* name) :
 RooArgSet::RooArgSet(const RooArgSet& other, const char *name)
   : RooAbsCollection(other,name)
 {
-  TRACE_CREATE
+  TRACE_CREATE;
 }
 
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Destructor
 
-RooArgSet::~RooArgSet() 
+RooArgSet::~RooArgSet()
 {
-  TRACE_DESTROY  
+  TRACE_DESTROY;
 }
 
 
 ////////////////////////////////////////////////////////////////////////////////
-/// Add contents of a RooArgList to the set.
-void RooArgSet::processArg(const RooArgList& list) {
-  add(list);
-  if (_name.Length() == 0)
-    _name = list.GetName();
-}
-
-////////////////////////////////////////////////////////////////////////////////
-/// Add element to non-owning set. The operation will fail if
-/// a similarly named object already exists in the set, or
-/// the set is specified to own its elements. Eventual error messages
-/// can be suppressed with the silent flag
-
-Bool_t RooArgSet::add(const RooAbsArg& var, Bool_t silent) 
-{
-  return checkForDup(var,silent)? kFALSE : RooAbsCollection::add(var,silent) ;
-}
-
-
-
-////////////////////////////////////////////////////////////////////////////////
-/// Add element to an owning set. The operation will fail if
-/// a similarly named object already exists in the set, or
-/// the set is not specified to own its elements. Eventual error messages
-/// can be suppressed with the silent flag
-
-Bool_t RooArgSet::addOwned(RooAbsArg& var, Bool_t silent)
-{
-  return checkForDup(var,silent)? kFALSE : RooAbsCollection::addOwned(var,silent) ;
-}
-
-
-
-////////////////////////////////////////////////////////////////////////////////
-/// Add clone of specified element to an owning set. If sucessful, the
-/// set will own the clone, not the original. The operation will fail if
-/// a similarly named object already exists in the set, or
-/// the set is not specified to own its elements. Eventual error messages
-/// can be suppressed with the silent flag
-
-RooAbsArg* RooArgSet::addClone(const RooAbsArg& var, Bool_t silent) 
-{
-  return checkForDup(var,silent)? 0 : RooAbsCollection::addClone(var,silent) ;
-}
-
-
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Get reference to an element using its name. Named element must exist in set.
@@ -303,13 +186,13 @@ RooAbsArg* RooArgSet::addClone(const RooAbsArg& var, Bool_t silent)
 /// ```
 /// will not replace the element "x", it just assigns the values of y.
 RooAbsArg& RooArgSet::operator[](const TString& name) const
-{     
+{
   RooAbsArg* arg = find(name) ;
   if (!arg) {
-    coutE(InputArguments) << "RooArgSet::operator[](" << GetName() << ") ERROR: no element named " << name << " in set" << endl ;
+    coutE(InputArguments) << "RooArgSet::operator[](" << GetName() << ") ERROR: no element named " << name << " in set" << std::endl ;
     throw std::invalid_argument((TString("No element named '") + name + "' in set " + GetName()).Data());
   }
-  return *arg ; 
+  return *arg ;
 }
 
 
@@ -317,21 +200,21 @@ RooAbsArg& RooArgSet::operator[](const TString& name) const
 ////////////////////////////////////////////////////////////////////////////////
 /// Check if element with var's name is already in set
 
-Bool_t RooArgSet::checkForDup(const RooAbsArg& var, Bool_t silent) const 
+bool RooArgSet::checkForDup(const RooAbsArg& var, bool silent) const
 {
   RooAbsArg *other = find(var);
   if (other) {
     if (other != &var) {
       if (!silent) {
-	// print a warning if this variable is not the same one we
-	// already have
-	coutE(InputArguments) << "RooArgSet::checkForDup: ERROR argument with name " << var.GetName() << " is already in this set" << endl;
+   // print a warning if this variable is not the same one we
+   // already have
+   coutE(InputArguments) << "RooArgSet::checkForDup: ERROR argument with name " << var.GetName() << " is already in this set" << std::endl;
       }
     }
     // don't add duplicates
-    return kTRUE;
+    return true;
   }
-  return kFALSE ;
+  return false ;
 }
 
 
@@ -348,10 +231,10 @@ void RooArgSet::writeToFile(const char* fileName) const
 {
   ofstream ofs(fileName) ;
   if (ofs.fail()) {
-    coutE(InputArguments) << "RooArgSet::writeToFile(" << GetName() << ") error opening file " << fileName << endl ;
+    coutE(InputArguments) << "RooArgSet::writeToFile(" << GetName() << ") error opening file " << fileName << std::endl ;
     return ;
   }
-  writeToStream(ofs,kFALSE) ;
+  writeToStream(ofs,false) ;
 }
 
 
@@ -360,14 +243,14 @@ void RooArgSet::writeToFile(const char* fileName) const
 /// Read contents of the argset from specified file.
 /// See readFromStream() for details
 
-Bool_t RooArgSet::readFromFile(const char* fileName, const char* flagReadAtt, const char* section, Bool_t verbose) 
+bool RooArgSet::readFromFile(const char* fileName, const char* flagReadAtt, const char* section, bool verbose)
 {
   ifstream ifs(fileName) ;
   if (ifs.fail()) {
-    coutE(InputArguments) << "RooArgSet::readFromFile(" << GetName() << ") error opening file " << fileName << endl ;
-    return kTRUE ;
+    coutE(InputArguments) << "RooArgSet::readFromFile(" << GetName() << ") error opening file " << fileName << std::endl ;
+    return true ;
   }
-  return readFromStream(ifs,kFALSE,flagReadAtt,section,verbose) ;
+  return readFromStream(ifs,false,flagReadAtt,section,verbose) ;
 }
 
 
@@ -375,10 +258,10 @@ Bool_t RooArgSet::readFromFile(const char* fileName, const char* flagReadAtt, co
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Write the contents of the argset in ASCII form to given stream.
-/// 
+///
 /// A line is written for each element contained in the form
 /// `<argName> = <argValue>`
-/// 
+///
 /// The `<argValue>` part of each element is written by the arguments'
 /// writeToStream() function.
 /// \param os The stream to write to.
@@ -386,7 +269,7 @@ Bool_t RooArgSet::readFromFile(const char* fileName, const char* flagReadAtt, co
 /// \note In compact mode, the stream cannot be read back into a RooArgSet,
 /// but only into a RooArgList, because the variable names are lost.
 /// \param section If non-null, add a section header like `[<section>]`.
-void RooArgSet::writeToStream(ostream& os, Bool_t compact, const char* section) const
+void RooArgSet::writeToStream(ostream& os, bool compact, const char* section) const
 {
   if (section && section[0] != '\0')
     os << '[' << section << ']' << '\n';
@@ -396,12 +279,12 @@ void RooArgSet::writeToStream(ostream& os, Bool_t compact, const char* section)
       next->writeToStream(os, true);
       os << " ";
     }
-    os << endl;
+    os << std::endl;
   } else {
     for (const auto next : _list) {
       os << next->GetName() << " = " ;
-      next->writeToStream(os,kFALSE) ;
-      os << endl ;
+      next->writeToStream(os,false) ;
+      os << std::endl ;
     }
   }
 }
@@ -411,15 +294,15 @@ void RooArgSet::writeToStream(ostream& os, Bool_t compact, const char* section)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Read the contents of the argset in ASCII form from given stream.
-/// 
+///
 /// The stream is read to end-of-file and each line is assumed to be
 /// of the form
 /// \code
 ///   <argName> = <argValue>
 /// \endcode
 /// Lines starting with argNames not matching any element in the list
-/// will be ignored with a warning message. In addition limited C++ style 
-/// preprocessing and flow control is provided. The following constructions 
+/// will be ignored with a warning message. In addition limited C++ style
+/// preprocessing and flow control is provided. The following constructions
 /// are recognized:
 /// \code
 ///   include "include.file"
@@ -437,7 +320,7 @@ void RooArgSet::writeToStream(ostream& os, Bool_t compact, const char* section)
 /// \endcode
 ///
 /// All expressions are evaluated by RooFormula, and may involve any of
-/// the sets variables. 
+/// the sets variables.
 /// \code
 ///   echo <Message>
 /// \endcode
@@ -445,39 +328,39 @@ void RooArgSet::writeToStream(ostream& os, Bool_t compact, const char* section)
 /// \code
 ///   abort
 /// \endcode
-/// Force termination of read sequence with error status 
+/// Force termination of read sequence with error status
 ///
 /// The value of each argument is read by the arguments readFromStream
 /// function.
 
-Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagReadAtt, const char* section, Bool_t verbose) 
+bool RooArgSet::readFromStream(istream& is, bool compact, const char* flagReadAtt, const char* section, bool verbose)
 {
   if (compact) {
-    coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << ") compact mode not supported" << endl ;
-    return kTRUE ;
+    coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << ") compact mode not supported" << std::endl ;
+    return true ;
   }
 
   RooStreamParser parser(is) ;
   parser.setPunctuation("=") ;
   TString token ;
-  Bool_t retVal(kFALSE) ;
+  bool retVal(false) ;
 
   // Conditional stack and related state variables
   // coverity[UNINIT]
-  Bool_t anyCondTrue[100] ;
-  Bool_t condStack[100] ;
-  Bool_t lastLineWasElse=kFALSE ;
+  bool anyCondTrue[100] ;
+  bool condStack[100] ;
+  bool lastLineWasElse=false ;
   Int_t condStackLevel=0 ;
-  condStack[0]=kTRUE ;
+  condStack[0]=true ;
 
   // Prepare section processing
   TString sectionHdr("[") ;
   if (section) sectionHdr.Append(section) ;
   sectionHdr.Append("]") ;
-  Bool_t inSection(section?kFALSE:kTRUE) ;
+  bool inSection(section?false:true) ;
 
-  Bool_t reprocessToken = kFALSE ;
-  while (1) {
+  bool reprocessToken = false ;
+  while (true) {
 
     if (is.eof() || is.fail() || parser.atEOF()) {
       break ;
@@ -487,9 +370,9 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
     if (!reprocessToken) {
       token = parser.readToken() ;
     }
-    reprocessToken = kFALSE ;
+    reprocessToken = false ;
 
-    // Skip empty lines 
+    // Skip empty lines
     if (token.IsNull()) {
       continue ;
     }
@@ -498,18 +381,18 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
     if (!token.CompareTo("include")) {
       if (parser.atEOL()) {
         coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName()
-			          << "): no filename found after include statement" << endl ;
-        return kTRUE ;
+                   << "): no filename found after include statement" << std::endl ;
+        return true ;
       }
       TString filename = parser.readLine() ;
       ifstream incfs(filename) ;
       if (!incfs.good()) {
-        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): cannot open include file " << filename << endl ;
-        return kTRUE ;
+        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): cannot open include file " << filename << std::endl ;
+        return true ;
       }
-      coutI(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): processing include file " 
-          << filename << endl ;
-      if (readFromStream(incfs,compact,flagReadAtt,inSection?0:section,verbose)) return kTRUE ;
+      coutI(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): processing include file "
+          << filename << std::endl ;
+      if (readFromStream(incfs,compact,flagReadAtt,inSection?nullptr:section,verbose)) return true ;
       continue ;
     }
 
@@ -531,7 +414,7 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
 
     // If section is specified, ignore all data outside specified section
     if (!inSection) {
-      parser.zapToEnd(kTRUE) ;
+      parser.zapToEnd(true) ;
       continue ;
     }
 
@@ -541,69 +424,70 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
       // Extract conditional expressions and check validity
       TString expr = parser.readLine() ;
       RooFormula form(expr,expr,*this) ;
-      if (!form.ok()) return kTRUE ;
+      if (!form.ok()) return true ;
 
       // Evaluate expression
-      Bool_t status = form.eval()?kTRUE:kFALSE ;
+      bool status = form.eval()?true:false ;
       if (lastLineWasElse) {
         anyCondTrue[condStackLevel] |= status ;
-        lastLineWasElse=kFALSE ;
+        lastLineWasElse=false ;
       } else {
         condStackLevel++ ;
         anyCondTrue[condStackLevel] = status ;
       }
       condStack[condStackLevel] = status ;
 
-      if (verbose) cxcoutD(Eval) << "RooArgSet::readFromStream(" << GetName() 
-				     << "): conditional expression " << expr << " = "
-				     << (condStack[condStackLevel]?"true":"false") << endl ;
+      if (verbose) {
+        cxcoutD(Eval) << "RooArgSet::readFromStream(" << GetName() << "): conditional expression " << expr << " = "
+                      << (condStack[condStackLevel] ? "true" : "false") << std::endl;
+      }
       continue ; // go to next line
     }
 
     if (!token.CompareTo("else")) {
       // Must have seen an if statement before
       if (condStackLevel==0) {
-        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): unmatched 'else'" << endl ;
+        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): unmatched 'else'" << std::endl ;
       }
 
       if (parser.atEOL()) {
         // simple else: process if nothing else was true
         condStack[condStackLevel] = !anyCondTrue[condStackLevel] ;
-        parser.zapToEnd(kFALSE) ;
+        parser.zapToEnd(false) ;
         continue ;
       } else {
         // if anything follows it should be 'if'
         token = parser.readToken() ;
         if (token.CompareTo("if")) {
-          coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): syntax error: 'else " << token << "'" << endl ;
-          return kTRUE ;
+          coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): syntax error: 'else " << token << "'" << std::endl ;
+          return true ;
         } else {
           if (anyCondTrue[condStackLevel]) {
             // No need for further checking, true conditional already processed
-            condStack[condStackLevel] = kFALSE ;
-            parser.zapToEnd(kFALSE) ;
+            condStack[condStackLevel] = false ;
+            parser.zapToEnd(false) ;
             continue ;
           } else {
             // Process as normal 'if' no true conditional was encountered
-            reprocessToken = kTRUE ;
-            lastLineWasElse=kTRUE ;
+            reprocessToken = true ;
+            lastLineWasElse=true ;
             continue ;
           }
         }
-      }	
+      }
     }
 
     if (!token.CompareTo("endif")) {
       // Must have seen an if statement before
       if (condStackLevel==0) {
-        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): unmatched 'endif'" << endl ;
-        return kTRUE ;
+        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): unmatched 'endif'" << std::endl ;
+        return true ;
       }
 
       // Decrease stack by one
       condStackLevel-- ;
       continue ;
-    } 
+    }
 
     // If current conditional is true
     if (condStack[condStackLevel]) {
@@ -611,37 +495,37 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
       // Process echo statements
       if (!token.CompareTo("echo")) {
         TString message = parser.readLine() ;
-        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): >> " << message << endl ;
+        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): >> " << message << std::endl ;
         continue ;
-      } 
+      }
 
       // Process abort statements
       if (!token.CompareTo("abort")) {
         TString message = parser.readLine() ;
-        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): USER ABORT" << endl ;
-        return kTRUE ;
-      } 
+        coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): USER ABORT" << std::endl ;
+        return true ;
+      }
 
-      // Interpret the rest as <arg> = <value_expr> 
+      // Interpret the rest as <arg> = <value_expr>
       RooAbsArg *arg ;
 
       if ((arg = find(token)) && !arg->getAttribute("Dynamic")) {
-        if (parser.expectToken("=",kTRUE)) {
-          parser.zapToEnd(kTRUE) ;
-          retVal=kTRUE ;
+        if (parser.expectToken("=",true)) {
+          parser.zapToEnd(true) ;
+          retVal=true ;
           coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName()
-				    << "): missing '=' sign: " << arg << endl ;
+                << "): missing '=' sign: " << arg << std::endl ;
           continue ;
         }
-        Bool_t argRet = arg->readFromStream(is,kFALSE,verbose) ;
-        if (!argRet && flagReadAtt) arg->setAttribute(flagReadAtt,kTRUE) ;
+        bool argRet = arg->readFromStream(is,false,verbose) ;
+        if (!argRet && flagReadAtt) arg->setAttribute(flagReadAtt,true) ;
         retVal |= argRet ;
       } else {
         if (verbose) {
           coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): argument "
-              << token << " not in list, ignored" << endl ;
+              << token << " not in list, ignored" << std::endl ;
         }
-        parser.zapToEnd(kTRUE) ;
+        parser.zapToEnd(true) ;
       }
     } else {
       parser.readLine() ;
@@ -650,45 +534,41 @@ Bool_t RooArgSet::readFromStream(istream& is, Bool_t compact, const char* flagRe
 
   // Did we fully unwind the conditional stack?
   if (condStackLevel!=0) {
-    coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): missing 'endif'" << endl ;
-    return kTRUE ;
+    coutE(InputArguments) << "RooArgSet::readFromStream(" << GetName() << "): missing 'endif'" << std::endl ;
+    return true ;
   }
 
   return retVal ;
 }
 
 
-Bool_t RooArgSet::isInRange(const char* rangeSpec) 
+bool RooArgSet::isInRange(const char* rangeSpec)
 {
   char buf[1024] ;
   strlcpy(buf,rangeSpec,1024) ;
   char* token = strtok(buf,",") ;
-  
-  TIterator* iter = createIterator() ;
 
   while(token) {
 
-    Bool_t accept=kTRUE ;
-    iter->Reset() ;
-    RooAbsArg* arg ;
-    while((arg=(RooAbsArg*)iter->Next())) {
-      RooAbsRealLValue* lvarg = dynamic_cast<RooAbsRealLValue*>(arg) ;
+    bool accept=true ;
+    for (auto * lvarg : dynamic_range_cast<RooAbsRealLValue*>(*this)) {
       if (lvarg) {
-	if (!lvarg->inRange(token)) {
-	  accept=kFALSE ;
-	  break ;
-	}
+   if (!lvarg->inRange(token)) {
+     accept=false ;
+     break ;
+   }
       }
       // WVE MUST HANDLE RooAbsCategoryLValue ranges as well
     }
     if (accept) {
-      delete iter ;
-      return kTRUE ;
+      return true ;
     }
 
-    token = strtok(0,",") ;
+    token = strtok(nullptr,",") ;
   }
 
-  delete iter ;
-  return kFALSE ;
+  return false ;
 }
+
+
+void RooArgSet::processArg(double value) { processArg(RooFit::RooConst(value)); }
