@@ -38,24 +38,15 @@ store the interval.
 
 #include <TMath.h>
 
-ClassImp(RooStats::ConfidenceBelt); ;
 
 using namespace RooStats;
-using namespace std;
-
-////////////////////////////////////////////////////////////////////////////////
-/// Default constructor
-
-ConfidenceBelt::ConfidenceBelt() :
-   TNamed(), fParameterPoints(nullptr)
-{
-}
+using std::vector;
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Alternate constructor
 
 ConfidenceBelt::ConfidenceBelt(const char* name) :
-  TNamed(name,name), fParameterPoints(nullptr)
+  TNamed(name,name)
 {
 }
 
@@ -63,7 +54,7 @@ ConfidenceBelt::ConfidenceBelt(const char* name) :
 /// Alternate constructor
 
 ConfidenceBelt::ConfidenceBelt(const char* name, const char* title) :
-   TNamed(name,title), fParameterPoints(nullptr)
+   TNamed(name,title)
 {
 }
 
@@ -71,7 +62,7 @@ ConfidenceBelt::ConfidenceBelt(const char* name, const char* title) :
 /// Alternate constructor
 
 ConfidenceBelt::ConfidenceBelt(const char* name, RooAbsData& data) :
-  TNamed(name,name), fParameterPoints((RooAbsData*)data.Clone("PointsToTestForBelt"))
+  TNamed(name,name), fParameterPoints(static_cast<RooAbsData*>(data.Clone("PointsToTestForBelt")))
 {
 }
 
@@ -79,21 +70,14 @@ ConfidenceBelt::ConfidenceBelt(const char* name, RooAbsData& data) :
 /// Alternate constructor
 
 ConfidenceBelt::ConfidenceBelt(const char* name, const char* title, RooAbsData& data) :
-   TNamed(name,title), fParameterPoints((RooAbsData*)data.Clone("PointsToTestForBelt"))
-{
-}
-
-////////////////////////////////////////////////////////////////////////////////
-/// Destructor
-
-ConfidenceBelt::~ConfidenceBelt()
+   TNamed(name,title), fParameterPoints(static_cast<RooAbsData*>(data.Clone("PointsToTestForBelt")))
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 
 double ConfidenceBelt::GetAcceptanceRegionMin(RooArgSet& parameterPoint, double cl, double leftside) {
-  if(cl>0 || leftside > 0) cout <<"using default cl, leftside for now" <<endl;
+  if(cl>0 || leftside > 0) std::cout <<"using default cl, leftside for now" << std::endl;
   AcceptanceRegion * region = GetAcceptanceRegion(parameterPoint, cl,leftside);
   return (region) ? region->GetLowerLimit() : TMath::QuietNaN();
 }
@@ -101,7 +85,7 @@ double ConfidenceBelt::GetAcceptanceRegionMin(RooArgSet& parameterPoint, double
 ////////////////////////////////////////////////////////////////////////////////
 
 double ConfidenceBelt::GetAcceptanceRegionMax(RooArgSet& parameterPoint, double cl, double leftside) {
-  if(cl>0 || leftside > 0) cout <<"using default cl, leftside for now" <<endl;
+  if(cl>0 || leftside > 0) std::cout <<"using default cl, leftside for now" << std::endl;
   AcceptanceRegion * region = GetAcceptanceRegion(parameterPoint, cl,leftside);
   return (region) ? region->GetUpperLimit() : TMath::QuietNaN();
 }
@@ -118,22 +102,22 @@ vector<double> ConfidenceBelt::ConfidenceLevels() const {
 void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, Int_t dsIndex,
                 double lower, double upper,
                 double cl, double leftside){
-  if(cl>0 || leftside > 0) cout <<"using default cl, leftside for now" <<endl;
+  if(cl>0 || leftside > 0) std::cout <<"using default cl, leftside for now" << std::endl;
 
-  RooDataSet*  tree = dynamic_cast<RooDataSet*>(  fParameterPoints );
-  RooDataHist* hist = dynamic_cast<RooDataHist*>( fParameterPoints );
+  RooDataSet*  tree = dynamic_cast<RooDataSet*>( fParameterPoints );
+  RooDataHist* hist = dynamic_cast<RooDataHist*>(fParameterPoints );
 
-  //  cout << "add: " << tree << " " << hist << endl;
+  //  std::cout << "add: " << tree << " " << hist << std::endl;
 
   if( !this->CheckParameters(parameterPoint) )
     std::cout << "problem with parameters" << std::endl;
 
   Int_t luIndex = fSamplingSummaryLookup.GetLookupIndex(cl, leftside);
-  //  cout << "lookup index = " << luIndex << endl;
+  //  std::cout << "lookup index = " << luIndex << std::endl;
   if(luIndex <0 ) {
     fSamplingSummaryLookup.Add(cl,leftside);
     luIndex = fSamplingSummaryLookup.GetLookupIndex(cl, leftside);
-    cout << "lookup index = " << luIndex << endl;
+    std::cout << "lookup index = " << luIndex << std::endl;
   }
   AcceptanceRegion* thisRegion = new AcceptanceRegion(luIndex, lower, upper);
 
@@ -144,7 +128,7 @@ void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, Int_t dsInde
     //    RooStats::SetParameters(&parameterPoint, const_cast<RooArgSet*>(hist->get()));
     //    int index = hist->calcTreeIndex(); // get index
     int index = hist->getIndex(parameterPoint); // get index
-    //    cout << "hist index = " << index << endl;
+    //    std::cout << "hist index = " << index << std::endl;
 
     // allocate memory if necessary.  numEntries is overkill?
     if((Int_t)fSamplingSummaries.size() <= index) {
@@ -158,7 +142,7 @@ void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, Int_t dsInde
   else if( tree ){
     //    int index = tree->getIndex(parameterPoint);
     int index = dsIndex;
-    //    cout << "tree index = " << index << endl;
+    //    std::cout << "tree index = " << index << std::endl;
 
     // allocate memory if necessary.  numEntries is overkill?
     if((Int_t)fSamplingSummaries.size() <= index){
@@ -175,10 +159,10 @@ void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, Int_t dsInde
 
 void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, AcceptanceRegion region,
                 double cl, double leftside){
-  if(cl>0 || leftside > 0) cout <<"using default cl, leftside for now" <<endl;
+  if(cl>0 || leftside > 0) std::cout <<"using default cl, leftside for now" << std::endl;
 
-  RooDataSet*  tree = dynamic_cast<RooDataSet*>(  fParameterPoints );
-  RooDataHist* hist = dynamic_cast<RooDataHist*>( fParameterPoints );
+  RooDataSet*  tree = dynamic_cast<RooDataSet*>( fParameterPoints );
+  RooDataHist* hist = dynamic_cast<RooDataHist*>(fParameterPoints );
 
   if( !this->CheckParameters(parameterPoint) )
     std::cout << "problem with parameters" << std::endl;
@@ -214,10 +198,10 @@ void ConfidenceBelt::AddAcceptanceRegion(RooArgSet& parameterPoint, AcceptanceRe
 
 AcceptanceRegion* ConfidenceBelt::GetAcceptanceRegion(RooArgSet &parameterPoint, double cl, double leftside)
 {
-  if(cl>0 || leftside > 0) cout <<"using default cl, leftside for now" <<endl;
+  if(cl>0 || leftside > 0) std::cout <<"using default cl, leftside for now" << std::endl;
 
-  RooDataSet*  tree = dynamic_cast<RooDataSet*>(  fParameterPoints );
-  RooDataHist* hist = dynamic_cast<RooDataHist*>( fParameterPoints );
+  RooDataSet*  tree = dynamic_cast<RooDataSet*>( fParameterPoints );
+  RooDataHist* hist = dynamic_cast<RooDataHist*>(fParameterPoints );
 
   if( !this->CheckParameters(parameterPoint) ){
     std::cout << "problem with parameters" << std::endl;
@@ -279,7 +263,7 @@ RooArgSet* ConfidenceBelt::GetParameters() const
 
 bool ConfidenceBelt::CheckParameters(RooArgSet &parameterPoint) const
 {
-   if (parameterPoint.getSize() != fParameterPoints->get()->getSize() ) {
+   if (parameterPoint.size() != fParameterPoints->get()->size() ) {
       std::cout << "size is wrong, parameters don't match" << std::endl;
       return false;
    }
