@@ -53,11 +53,10 @@ conditional MLE (eg. profiled values).
 
 */
 
-ClassImp(RooStats::FeldmanCousins); ;
 
 using namespace RooFit;
 using namespace RooStats;
-using namespace std;
+using std::endl;
 
 ////////////////////////////////////////////////////////////////////////////////
 /// standard constructor
@@ -66,9 +65,9 @@ FeldmanCousins::FeldmanCousins(RooAbsData& data, ModelConfig& model) :
   fSize(0.05),
   fModel(model),
   fData(data),
-  fTestStatSampler(0),
-  fPointsToTest(0),
-  fPOIToTest(0),
+  fTestStatSampler(nullptr),
+  fPointsToTest(nullptr),
+  fPOIToTest(nullptr),
   fConfBelt(nullptr),
   fAdaptiveSampling(false),
   fAdditionalNToysFactor(1.),
@@ -119,14 +118,14 @@ void FeldmanCousins::CreateTestStatSampler() const{
   fTestStatSampler->SetPdf(*fModel.GetPdf());
 
   if(!fAdaptiveSampling){
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: ntoys per point = " << (int) (fAdditionalNToysFactor*50./fSize) << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: ntoys per point = " << (int) (fAdditionalNToysFactor*50./fSize) << std::endl;
   } else{
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: ntoys per point: adaptive" << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: ntoys per point: adaptive" << std::endl;
   }
   if(fFluctuateData){
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: nEvents per toy will fluctuate about  expectation" << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: nEvents per toy will fluctuate about  expectation" << std::endl;
   } else{
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: nEvents per toy will not fluctuate, will always be " << fData.numEntries() << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: nEvents per toy will not fluctuate, will always be " << fData.numEntries() << std::endl;
     fTestStatSampler->SetNEventsPerToy(fData.numEntries());
   }
 }
@@ -139,7 +138,7 @@ void FeldmanCousins::CreateParameterPoints() const{
   // get ingredients
   RooAbsPdf* pdf   = fModel.GetPdf();
   if (!pdf ){
-    ooccoutE(&fModel,Generation) << "FeldmanCousins: ModelConfig has no PDF" << endl;
+    ooccoutE(&fModel,Generation) << "FeldmanCousins: ModelConfig has no PDF" << std::endl;
     return;
   }
 
@@ -151,7 +150,7 @@ void FeldmanCousins::CreateParameterPoints() const{
 
   if( fModel.GetNuisanceParameters() && ! fModel.GetParametersOfInterest()->equals(*parameters) && fDoProfileConstruction) {
     // if parameters include nuisance parameters, do profile construction
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: Model has nuisance parameters, will do profile construction" << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: Model has nuisance parameters, will do profile construction" << std::endl;
 
     // set nbins for the POI
     for (auto *myarg2 : static_range_cast<RooRealVar *>(*fModel.GetParametersOfInterest())){
@@ -161,13 +160,13 @@ void FeldmanCousins::CreateParameterPoints() const{
     // get dataset for POI scan
     //     RooDataHist* parameterScan = nullptr;
     RooAbsData* parameterScan = nullptr;
-    if(fPOIToTest)
+    if (fPOIToTest) {
       parameterScan = fPOIToTest;
-    else
+    } else {
       parameterScan = new RooDataHist("parameterScan", "", *fModel.GetParametersOfInterest());
+    }
 
-
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: # points to test = " << parameterScan->numEntries() << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: # points to test = " << parameterScan->numEntries() << std::endl;
     // make profile construction
     RooFit::MsgLevel previous  = RooMsgService::instance().globalKillBelow();
     RooMsgService::instance().setGlobalKillBelow(RooFit::FATAL) ;
@@ -193,14 +192,14 @@ void FeldmanCousins::CreateParameterPoints() const{
 
   } else{
     // Do full construction
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: Model has no nuisance parameters" << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: Model has no nuisance parameters" << std::endl;
 
     for (auto *myarg : static_range_cast<RooRealVar *>(*parameters)){
       myarg->setBins(fNbins);
     }
 
     RooDataHist* parameterScan = new RooDataHist("parameterScan", "", *parameters);
-    ooccoutP(&fModel,Generation) << "FeldmanCousins: # points to test = " << parameterScan->numEntries() << endl;
+    ooccoutP(&fModel,Generation) << "FeldmanCousins: # points to test = " << parameterScan->numEntries() << std::endl;
 
     fPointsToTest = parameterScan;
   }
@@ -218,7 +217,7 @@ PointSetInterval* FeldmanCousins::GetInterval() const {
   //  RooAbsData* data = fData; //fWS->data(fDataName);
 
   // fill in implied variables given data
-  fModel.GuessObsAndNuisance(fData);
+  fModel.GuessObsAndNuisance(*fData.get());
 
   // create the test statistic sampler (private data member fTestStatSampler)
   if(!fTestStatSampler)
