@@ -639,7 +639,13 @@ Int_t TMySQLServer::Reload()
 {
    CheckConnect("Reload", -1);
 
-   Int_t res = mysql_reload(fMySQL);
+   Int_t res;
+   
+   #if MYSQL_VERSION_ID >= 80000
+   res = mysql_query(fMySQL, "FLUSH PRIVILEGES");
+   #else
+   res = mysql_reload(fMySQL);
+   #endif
 
    CheckErrNo("Reload", kFALSE, res);
 
@@ -656,7 +662,9 @@ Int_t TMySQLServer::Shutdown()
 
    Int_t res;
 
-#if MYSQL_VERSION_ID >= 50001 || \
+#if MYSQL_VERSION_ID >= 80000
+   res = mysql_query(fMySQL, "SHUTDOWN");
+#elif MYSQL_VERSION_ID >= 50001 || \
     (MYSQL_VERSION_ID < 50000 && MYSQL_VERSION_ID >= 40103)
    res = mysql_shutdown(fMySQL, SHUTDOWN_DEFAULT);
 #else
