@@ -359,6 +359,7 @@ void stress2()
    //Long64_t lastgood = 12383; //9428;
    //Long64_t lastgood = 9789;  // changes for new TFormula
    //Long64_t lastgood = 9797;  // changes for TH1 v8 ROOT-9173 on 32-bits
+   //Long64_t lastgood = 10034;  // changes in TFormula (v12)
 #ifdef R__HAS_DEFAULT_LZ4
       Long64_t lastgood = 10733;
       if (last < lastgood - 200 || last > lastgood + 200 || comp < 1.5 || comp > 2.1)
@@ -367,7 +368,7 @@ void stress2()
 #ifdef R__HAS_CLOUDFLARE_ZLIB
       Long64_t lastgood = 9813;
 #else
-      Long64_t lastgood = 10034;  // changes in TFormula (v12)
+      Long64_t lastgood = 10100;  // changes in TFormula (v13)
 #endif
       if (last < lastgood - 200 || last > lastgood + 200 || comp < 2.0 || comp > 2.4)
          OK = kFALSE;
@@ -402,11 +403,11 @@ void stress3()
    Float_t comp = f.GetCompressionFactor();
    Bool_t OK = kTRUE;
 #ifdef R__HAS_CLOUDFLARE_ZLIB
-   constexpr Long64_t lastgood = 52290;
+   constexpr Long64_t lastgood = 52264;
 #else
-   constexpr Long64_t lastgood = 52116;
+   constexpr Long64_t lastgood = 52090;
 #endif
-   constexpr Long64_t tolerance = 150;
+   constexpr Long64_t tolerance = 300;
 #ifdef R__HAS_DEFAULT_LZ4
       constexpr Long64_t difflastgoodlz4 = 5500;
       if (last < lastgood - tolerance || last > lastgood + difflastgoodlz4 + tolerance || comp < 1.5 || comp > 2.1)
@@ -1247,7 +1248,7 @@ void stress10()
       snprintf(filename,20,"Event_%d.root",file);
       chfile[file] = new TFile(filename,"recreate");
       if (file>=5) {
-         chfile[file]->SetCompressionAlgorithm(ROOT::kLZMA);
+         chfile[file]->SetCompressionAlgorithm(ROOT::RCompressionSetting::EAlgorithm::kLZMA);
       }
       chTree[file] = (TTree*)tree->CloneTree(0);
    }
@@ -1501,7 +1502,7 @@ void stress16()
    const float a[4]  = { 0.25, 0.04, 0.25, 0 };       // acceptance/trigger (last always 0)
 
    int   i, il, istep, itim[192], itrig[192], it, im, ipass;
-   float dead, sum[10];
+   float sum[10];
 
    // create histogram and array of profile histograms
    TCanvas *c = new TCanvas("laten","latency simulation",700,600);
@@ -1522,7 +1523,6 @@ void stress16()
       hp[i]->SetLineColor(2);
    }
 
-   dead   = 0;
    sum[0] = nbuf;
    for (i = 1; i <= nlev; i++) sum[i] = 0;
    for (i = 0; i < nbuf; i++) { itrig[i] = 0; itim[i] = 0; }
@@ -1564,9 +1564,7 @@ void stress16()
             ipass++;
          }
       }
-      if (ipass == 0) dead++;
    }
-//   Float_t deadTime = 100.*dead/nstep;
 
    // View results in the canvas and make the Postscript file
 
