@@ -7,7 +7,7 @@
  * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
  * Package: TMVA                                                                  *
  * Class  : DataLoader                                                            *
- *                                             *
+ *                                                                                *
  *                                                                                *
  * Description:                                                                   *
  *      This is a class to load datasets into every booked method                 *
@@ -23,7 +23,7 @@
  *                                                                                *
  * Redistribution and use in source and binary forms, with or without             *
  * modification, are permitted according to the terms listed in LICENSE           *
- * (see tmva/doc/LICENSE)                                          *
+ * (see tmva/doc/LICENSE)                                                         *
  **********************************************************************************/
 
 
@@ -298,6 +298,14 @@ void TMVA::DataLoader::AddEvent( const TString& className, Types::ETreeType tt,
 
    fATreeType   = clIndex;
    fATreeWeight = weight;
+   if (event.size() > fATreeEvent.size()) {
+      Error("AddEvent",
+       "Number of variables defined through DataLoader::AddVariable (%zu) is inconsistent"
+       " with number of variables given to DataLoader::Add*Event (%zu)."
+       " Please check your variable definitions and statement ordering."
+       " This event will not be added.", fATreeEvent.size(), event.size());
+      return;
+   }
    for (UInt_t ivar=0; ivar<event.size(); ivar++) fATreeEvent[ivar] = event[ivar];
 
    if(tt==Types::kTraining) fTrainAssignTree[clIndex]->Fill();
