@@ -2,6 +2,7 @@
 #include "ROOT/RDataFrame.hxx"
 #include "ROOT/RTrivialDS.hxx"
 #include "ROOT/TSeq.hxx"
+#include "Compression.h"
 #include "TFile.h"
 #include "TROOT.h"
 #include "TSystem.h"
@@ -10,10 +11,16 @@
 #include "gtest/gtest.h"
 #include <memory>
 #include <thread>
-using namespace ROOT;         // RDataFrame
-using namespace ROOT::RDF;    // RInterface
-using namespace ROOT::VecOps; // RVec
-using namespace ROOT::Detail::RDF;          // RLoopManager
+
+#include <TTreeReader.h>
+#include <TTreeReaderArray.h>
+
+#include "DummyHeader.hxx"
+
+using namespace ROOT;              // RDataFrame
+using namespace ROOT::RDF;         // RInterface
+using namespace ROOT::VecOps;      // RVec
+using namespace ROOT::Detail::RDF; // RLoopManager
 
 /********* FIXTURES *********/
 // fixture that provides a RDF with no data-source and a single integer column "ans" with value 42
@@ -60,6 +67,187 @@ protected:
 };
 #endif // R__USE_IMT
 
+// Test for custom basket size in Snapshot
+class SnapshotCustomBasketRAII {
+private:
+   std::string fInputFile;
+   std::string fOutputFileCustom;
+   std::string fOutputFileCollection;
+
+public:
+   SnapshotCustomBasketRAII()
+      : fInputFile("input_file.root"),
+        fOutputFileCustom("output_file_custom_basket.root"),
+        fOutputFileCollection("output_file_collection_basket.root")
+   {
+
+      // Create file and tree inside the constructor body
+      TFile fFile(fInputFile.c_str(), "RECREATE");
+      TTree fTree("tree", "Test Tree");
+
+      // Create scalar branch
+      float value = 0;
+      fTree.Branch("branch_x", &value);
+
+      // Create vector branch
+      std::vector<float> vec_values;
+      fTree.Branch("branch_vec", &vec_values);
+
+      // Fill the tree with some data
+      for (int i = 0; i < 1000; ++i) {
+         value = i;
+         vec_values.clear();
+         // Add some random number of elements to the vector
+         int vec_size = i % 10 + 1; // 1 to 10 elements
+         for (int j = 0; j < vec_size; ++j) {
+            vec_values.push_back(i + j * 0.1f);
+         }
+         fTree.Fill();
+      }
+      fFile.Write();
+   }
+
+   ~SnapshotCustomBasketRAII()
+   {
+      gSystem->Unlink(fInputFile.c_str());
+      gSystem->Unlink(fOutputFileCustom.c_str());
+      gSystem->Unlink(fOutputFileCollection.c_str());
+   }
+
+   const std::string &GetInputFile() const { return fInputFile; }
+   const std::string &GetOutputFileCustom() const { return fOutputFileCustom; }
+   const std::string &GetOutputFileCollection() const { return fOutputFileCollection; }
+};
+
+void TestCustomBasketSize()
+{
+   SnapshotCustomBasketRAII raii;
+
+   ROOT::RDataFrame df("tree", raii.GetInputFile());
+
+   auto df_with_new_columns = df.Define("branch_x_new", [](float x) { return x * 2; }, {"branch_x"})
+                                 .Define("branch_vec_new",
+                                         [](const std::vector<float> &vec) {
+                                            std::vector<float> result;
+                                            result.reserve(vec.size());
+                                            for (auto v : vec)
+                                               result.push_back(v * 2);
+                                            return result;
+                                         },
+                                         {"branch_vec"});
+
+   ROOT::RDF::RSnapshotOptions options;
+   options.fBasketSize = 2048;
+
+   df_with_new_columns.Snapshot<float, float>("tree", raii.GetOutputFileCustom(), {"branch_x", "branch_x_new"},
+                                              options);
+
+   df_with_new_columns.Snapshot<std::vector<float>, std::vector<float>>("tree", raii.GetOutputFileCollection(),
+                                                                        {"branch_vec", "branch_vec_new"}, options);
+
+   TFile output_file_custom(raii.GetOutputFileCustom().c_str());
+   auto output_tree_custom = output_file_custom.Get<TTree>("tree");
+
+   for (auto b : TRangeDynCast<TBranch>(*output_tree_custom->GetListOfBranches())) {
+      ASSERT_TRUE(b != nullptr);
+      EXPECT_EQ(b->GetBasketSize(), 2048) << "Incorrect basket size for scalar branch " << b->GetName();
+   }
+
+   TFile output_file_collection(raii.GetOutputFileCollection().c_str());
+   auto output_tree_collection = output_file_collection.Get<TTree>("tree");
+
+   for (auto b : TRangeDynCast<TBranch>(*output_tree_collection->GetListOfBranches())) {
+      ASSERT_TRUE(b != nullptr);
+      EXPECT_EQ(b->GetBasketSize(), 2048) << "Incorrect basket size for vector branch " << b->GetName();
+   }
+}
+
+void TestDefaultBasketSize()
+{
+   SnapshotCustomBasketRAII helper;
+   const Int_t defaultBasketSize = 32000;
+
+   ROOT::RDataFrame df("tree", helper.GetInputFile());
+
+   df.Snapshot("tree", helper.GetOutputFileCustom());
+
+   std::unique_ptr<TFile> f(TFile::Open(helper.GetOutputFileCustom().c_str()));
+   ASSERT_TRUE(f != nullptr);
+
+   auto tree = f->Get<TTree>("tree");
+   ASSERT_TRUE(tree != nullptr);
+
+   auto branchX = tree->GetBranch("branch_x");
+   ASSERT_TRUE(branchX != nullptr);
+   EXPECT_EQ(branchX->GetBasketSize(), defaultBasketSize) << "Scalar branch doesn't have default basket size";
+
+   auto branchVec = tree->GetBranch("branch_vec");
+   ASSERT_TRUE(branchVec != nullptr);
+   EXPECT_EQ(branchVec->GetBasketSize(), defaultBasketSize) << "Vector branch doesn't have default basket size";
+}
+
+void TestBasketSizePreservation()
+{
+   SnapshotCustomBasketRAII helper;
+
+   // Define the columns we want to snapshot
+   const std::vector<std::string> columns = {"branch_x", "branch_vec"};
+
+   // First create a tree with custom basket size
+   {
+      ROOT::RDataFrame df("tree", helper.GetInputFile());
+      ROOT::RDF::RSnapshotOptions options;
+      options.fBasketSize = 64000; // 64KB
+      df.Snapshot<float, std::vector<float>>("tree", helper.GetOutputFileCustom(), columns, options);
+   }
+
+   // Now read that tree and create new snapshot without specifying basket size
+   {
+      ROOT::RDataFrame df("tree", helper.GetOutputFileCustom());
+      df.Snapshot<float, std::vector<float>>("tree", helper.GetOutputFileCollection(), columns);
+   }
+
+   // Open both files and compare basket sizes
+   std::unique_ptr<TFile> f1(TFile::Open(helper.GetOutputFileCustom().c_str()));
+   std::unique_ptr<TFile> f2(TFile::Open(helper.GetOutputFileCollection().c_str()));
+   ASSERT_TRUE(f1 != nullptr);
+   ASSERT_TRUE(f2 != nullptr);
+
+   auto tree1 = f1->Get<TTree>("tree");
+   auto tree2 = f2->Get<TTree>("tree");
+   ASSERT_TRUE(tree1 != nullptr);
+   ASSERT_TRUE(tree2 != nullptr);
+
+   // Check both branches
+   for (const auto &branchName : columns) {
+      auto branch1 = tree1->GetBranch(branchName.c_str());
+      auto branch2 = tree2->GetBranch(branchName.c_str());
+      ASSERT_TRUE(branch1 != nullptr);
+      ASSERT_TRUE(branch2 != nullptr);
+
+      EXPECT_EQ(branch2->GetBasketSize(), branch1->GetBasketSize())
+         << "Branch '" << branchName << "' basket size not preserved";
+   }
+}
+
+// Test for custom basket size
+TEST(RDFSnapshotMore, CustomBasketSize)
+{
+   TestCustomBasketSize();
+}
+
+// Test for default basket size
+TEST(RDFSnapshotMore, DefaultBasketSize)
+{
+   TestDefaultBasketSize();
+}
+
+// Test for basket size preservation
+TEST(RDFSnapshotMore, BasketSizePreservation)
+{
+   TestBasketSizePreservation();
+}
+
 // fixture that provides fixed and variable sized arrays as RDF columns
 class RDFSnapshotArrays : public ::testing::Test {
 protected:
@@ -139,7 +327,7 @@ TEST_F(RDFSnapshot, Snapshot_aliases)
    const auto alias0 = "myalias0";
    const auto alias1 = "myalias1";
    auto tdfa = tdf.Alias(alias0, "ans");
-   auto tdfb = tdfa.Define("vec", [] { return RVec<int>{1,2,3}; }).Alias(alias1, "vec");
+   auto tdfb = tdfa.Define("vec", [] { return RVec<int>{1, 2, 3}; }).Alias(alias1, "vec");
    testing::internal::CaptureStderr();
    auto snap = tdfb.Snapshot<int, RVec<int>>("mytree", "Snapshot_aliases.root", {alias0, alias1});
    std::string err = testing::internal::GetCapturedStderr();
@@ -159,9 +347,7 @@ TEST_F(RDFSnapshot, Snapshot_nocolumnmatch)
 {
    const auto fname = "snapshotnocolumnmatch.root";
    RDataFrame d(1);
-   auto op = [&](){
-      d.Snapshot("t", fname, "x");
-   };
+   auto op = [&]() { d.Snapshot("t", fname, "x"); };
    EXPECT_ANY_THROW(op());
    gSystem->Unlink(fname);
 }
@@ -181,8 +367,7 @@ void TestSnapshotUpdate(RInterface<RLoopManager> &tdf, const std::string &outfil
    RSnapshotOptions opts;
    opts.fMode = "UPDATE";
    opts.fOverwriteIfExists = overwriteIfExists;
-   auto s2 = ROOT::RDataFrame(50ull).Define("x", [] { return 10; })
-                                    .Snapshot<int>(tree2, outfile, {"x"}, opts);
+   auto s2 = ROOT::RDataFrame(50ull).Define("x", [] { return 10; }).Snapshot<int>(tree2, outfile, {"x"}, opts);
 
    auto c2 = s2->Count();
    auto mean2 = s2->Mean<int>("x");
@@ -234,7 +419,8 @@ void test_snapshot_options(RInterface<RLoopManager> &tdf)
    opts.fCompressionLevel = 6;
 
    const auto outfile = "snapshot_test_opts.root";
-   for (auto algorithm : {ROOT::kZLIB, ROOT::kLZMA, ROOT::kLZ4, ROOT::kZSTD}) {
+   using RCAlgo = ROOT::RCompressionSetting::EAlgorithm;
+   for (auto algorithm : {RCAlgo::kZLIB, RCAlgo::kLZMA, RCAlgo::kLZ4, RCAlgo::kZSTD}) {
       opts.fCompressionAlgorithm = algorithm;
 
       auto s = tdf.Snapshot<int>("t", outfile, {"ans"}, opts);
@@ -376,8 +562,8 @@ void WriteColsWithCustomTitles(const std::string &tname, const std::string &fnam
    t.Write();
 }
 
-void CheckColsWithCustomTitles(unsigned long long int entry, int i, const RVec<int> &arrint,
-                               const RVec<int> &vararrint, float f)
+void CheckColsWithCustomTitles(unsigned long long int entry, int i, const RVec<int> &arrint, const RVec<int> &vararrint,
+                               float f)
 {
    if (entry == 0) {
       EXPECT_EQ(i, 1);
@@ -441,7 +627,7 @@ TEST(RDFSnapshotMore, ReadWriteStdVec)
    t.Write();
    f.Close();
 
-   auto outputChecker = [&treename](const char* filename){
+   auto outputChecker = [&treename](const char *filename) {
       // check snapshot output
       TFile f2(filename);
       TTreeReader r(treename, &f2);
@@ -672,8 +858,11 @@ TEST(RDFSnapshotMore, Lazy)
    gSystem->Unlink(fname0);
    RDataFrame d(1);
    auto v = 0U;
-   auto genf = [&v](){++v;return 42;};
-   RSnapshotOptions opts = {"RECREATE", ROOT::kZLIB, 0, 0, 99, true};
+   auto genf = [&v]() {
+      ++v;
+      return 42;
+   };
+   RSnapshotOptions opts = {"RECREATE", ROOT::RCompressionSetting::EAlgorithm::kZLIB, 0, 0, 99, true};
    auto ds = d.Define("c0", genf).Snapshot<int>(treename, fname0, {"c0"}, opts);
    EXPECT_EQ(v, 0U);
    EXPECT_TRUE(gSystem->AccessPathName(fname0)); // This returns FALSE if the file IS there
@@ -695,7 +884,7 @@ TEST(RDFSnapshotMore, LazyJitted)
    // make sure the file is not here beforehand
    gSystem->Unlink(fname);
    RDataFrame d(1);
-   RSnapshotOptions opts = {"RECREATE", ROOT::kZLIB, 0, 0, 99, true};
+   RSnapshotOptions opts = {"RECREATE", ROOT::RCompressionSetting::EAlgorithm::kZLIB, 0, 0, 99, true};
    auto ds = d.Alias("c0", "rdfentry_").Snapshot(treename, fname, {"c0"}, opts);
    EXPECT_TRUE(gSystem->AccessPathName(fname)); // This returns FALSE if the file IS there
    *ds;
@@ -713,7 +902,11 @@ void BookLazySnapshot()
 
 TEST(RDFSnapshotMore, LazyNotTriggered)
 {
-   ROOT_EXPECT_WARNING(BookLazySnapshot(), "Snapshot", "A lazy Snapshot action was booked but never triggered.");
+   ROOT_EXPECT_WARNING(BookLazySnapshot(), "Snapshot",
+                       "A lazy Snapshot action was booked but never triggered. The tree 't' in output file "
+                       "'lazysnapshotnottriggered_shouldnotbecreated.root' was not created. "
+                       "In case it was desired instead, remember to trigger the Snapshot operation, by "
+                       "storing its result in a variable and for example calling the GetValue() method on it.");
 }
 
 RResultPtr<RInterface<RLoopManager, void>> ReturnLazySnapshot(const char *fname)
@@ -834,16 +1027,19 @@ TEST(RDFSnapshotMore, ForbiddenOutputFilename)
    // Compiled
    try {
       ROOT_EXPECT_SYSERROR(df.Snapshot<unsigned int>("t", out_fname, {"rdfslot_"}), "TFile::TFile",
-                        "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory")
+                           "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory")
    } catch (const std::runtime_error &e) {
       EXPECT_STREQ(e.what(), "Snapshot: could not create output file /definitely/not/a/valid/path/f.root");
    }
 
    // Jitted
    // If some other test case called EnableThreadSafety, the error printed here is of the form
-   // "SysError in <TFile::TFile>: file /definitely/not/a/valid/path/f.root can not be opened No such file or directory\nError in <TReentrantRWLock::WriteUnLock>: Write lock already released for 0x55f179989378\n"
-   // but the address printed changes every time
-   ROOT::TestSupport::CheckDiagsRAII diagRAII{kSysError, "TFile::TFile", "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory"};
+   // "SysError in <TFile::TFile>: file /definitely/not/a/valid/path/f.root can not be opened No such file or
+   // directory\nError in <TReentrantRWLock::WriteUnLock>: Write lock already released for 0x55f179989378\n" but the
+   // address printed changes every time
+   ROOT::TestSupport::CheckDiagsRAII diagRAII{
+      kSysError, "TFile::TFile",
+      "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory"};
    EXPECT_THROW(df.Snapshot("t", out_fname, {"rdfslot_"}), std::runtime_error);
 }
 
@@ -966,6 +1162,83 @@ TEST(RDFSnapshotMore, OutOfOrderSizeBranch)
    gSystem->Unlink(outFile);
 }
 
+TEST(RDFSnapshotMore, PreserveStdVectorWithOptions)
+{
+   struct DatasetGuard {
+
+      const char *fFileName{"rdfsnapshotmore_preservestdvectorwithoptions.root"};
+      const char *fTreeName{"rdfsnapshotmore_preservestdvectorwithoptions"};
+      const char *fSnapFileDefault{"rdfsnapshotmore_preservestdvectorwithoptions_snap_default.root"};
+      const char *fSnapTreeDefault{"rdfsnapshotmore_preservestdvectorwithoptions_snap_default"};
+      const char *fSnapFileOpts{"rdfsnapshotmore_preservestdvectorwithoptions_snap_opts.root"};
+      const char *fSnapTreeOpts{"rdfsnapshotmore_preservestdvectorwithoptions_snap_opts"};
+
+      DatasetGuard()
+      {
+         std::unique_ptr<TFile> f{TFile::Open(fFileName, "RECREATE")};
+         auto t = std::make_unique<TTree>(fTreeName, fTreeName);
+         std::vector<int> a{11, 22, 33};
+         std::vector<float> b{44.f, 55.f, 66.f};
+         std::vector<double> c{77., 88., 99.};
+         t->Branch("a", &a);
+         t->Branch("b", &b);
+         t->Branch("c", &c);
+         t->Fill();
+         t->Write();
+      }
+
+      ~DatasetGuard()
+      {
+         std::remove(fFileName);
+         std::remove(fSnapFileDefault);
+         std::remove(fSnapFileOpts);
+      }
+   } dataset;
+
+   // Snapshot with default options: std::vector branches are converted to ROOT::RVec
+   {
+      ROOT::RDataFrame df{dataset.fTreeName, dataset.fFileName};
+      df.Snapshot(dataset.fSnapTreeDefault, dataset.fSnapFileDefault);
+   }
+
+   {
+      std::unique_ptr<TFile> f{TFile::Open(dataset.fSnapFileDefault)};
+      std::unique_ptr<TTree> t{f->Get<TTree>(dataset.fSnapTreeDefault)};
+      std::vector<std::string> expected_typenames_default{"ROOT::VecOps::RVec<int>", "ROOT::VecOps::RVec<float>",
+                                                          "ROOT::VecOps::RVec<double>"};
+      std::vector<std::string> typenames_default;
+      for (const auto *leaf : ROOT::Detail::TRangeStaticCast<TLeaf>(t->GetListOfLeaves())) {
+         typenames_default.push_back(leaf->GetTypeName());
+      }
+      EXPECT_EQ(expected_typenames_default.size(), typenames_default.size());
+      for (std::size_t i = 0; i < expected_typenames_default.size(); i++) {
+         EXPECT_EQ(expected_typenames_default[i], typenames_default[i]);
+      }
+   }
+
+   // Pass option to Snapshot to avoid the type conversion
+   {
+      ROOT::RDF::RSnapshotOptions opts;
+      opts.fVector2RVec = false;
+      ROOT::RDataFrame df{dataset.fTreeName, dataset.fFileName};
+      df.Snapshot(dataset.fSnapTreeOpts, dataset.fSnapFileOpts, df.GetColumnNames(), opts);
+   }
+
+   {
+      std::unique_ptr<TFile> f{TFile::Open(dataset.fSnapFileOpts)};
+      std::unique_ptr<TTree> t{f->Get<TTree>(dataset.fSnapTreeOpts)};
+      std::vector<std::string> expected_typenames_default{"vector<int>", "vector<float>", "vector<double>"};
+      std::vector<std::string> typenames_default;
+      for (const auto *leaf : ROOT::Detail::TRangeStaticCast<TLeaf>(t->GetListOfLeaves())) {
+         typenames_default.push_back(leaf->GetTypeName());
+      }
+      EXPECT_EQ(expected_typenames_default.size(), typenames_default.size());
+      for (std::size_t i = 0; i < expected_typenames_default.size(); i++) {
+         EXPECT_EQ(expected_typenames_default[i], typenames_default[i]);
+      }
+   }
+}
+
 /********* MULTI THREAD TESTS ***********/
 #ifdef R__USE_IMT
 TEST_F(RDFSnapshotMT, Snapshot_update_diff_treename)
@@ -1011,9 +1284,10 @@ TEST_F(RDFSnapshotMT, Reshuffled_friends)
       TFile f(fname);
       TTree *t = f.Get<TTree>("t");
       TTree t2("t2", "t2");
-      const auto expected = "Tree 't' has the kEntriesReshuffled bit set, and cannot be used as "
-                            "friend nor can be added as a friend unless the main tree has a TTreeIndex on the friend "
-                            "tree 't'. You can also unset the bit manually if you know what you are doing.";
+      const auto expected =
+         "Tree 't' has the kEntriesReshuffled bit set and cannot have friends nor can be added as a friend unless the "
+         "main tree has a TTreeIndex on the friend tree 't'. You can also unset the bit manually if you know what you "
+         "are doing; note that you risk associating wrong TTree entries of the friend with those of the main TTree!";
       ROOT_EXPECT_ERROR(t2.AddFriend(t), "AddFriend", expected);
    }
 
@@ -1022,9 +1296,10 @@ TEST_F(RDFSnapshotMT, Reshuffled_friends)
       TFile f(fname);
       TTree *t = f.Get<TTree>("t");
       TTree t2("t2", "t2");
-      const auto expected = "Tree 't' has the kEntriesReshuffled bit set, and cannot be used as "
-                            "friend nor can be added as a friend unless the main tree has a TTreeIndex on the friend "
-                            "tree 't2'. You can also unset the bit manually if you know what you are doing.";
+      const auto expected =
+         "Tree 't' has the kEntriesReshuffled bit set and cannot have friends nor can be added as a friend unless the "
+         "main tree has a TTreeIndex on the friend tree 't2'. You can also unset the bit manually if you know what you "
+         "are doing; note that you risk associating wrong TTree entries of the friend with those of the main TTree!";
       ROOT_EXPECT_ERROR(t->AddFriend(&t2);, "AddFriend", expected);
    }
 }
@@ -1047,7 +1322,7 @@ TEST(RDFSnapshotMore, ManyTasksPerThread)
 
    // test multi-thread Snapshotting from many tasks per worker thread
    const auto outputFile = "snapshot_manytasks_out.root";
-   ROOT::RDataFrame tdf("t", (inputFilePrefix + "*.root").c_str());
+   ROOT::RDataFrame tdf("t", inputFilePrefix + "*.root");
    tdf.Snapshot<int>("t", outputFile, {"x"});
 
    // check output contents
@@ -1199,23 +1474,41 @@ TEST(RDFSnapshotMore, JittedSnapshotAndAliasedColumns)
    gSystem->Unlink(fname2);
 }
 
-
 TEST(RDFSnapshotMore, LazyNotTriggeredMT)
 {
    ROOT::EnableImplicitMT(4);
-   ROOT_EXPECT_WARNING(BookLazySnapshot(), "Snapshot", "A lazy Snapshot action was booked but never triggered.");
+   ROOT_EXPECT_WARNING(BookLazySnapshot(), "Snapshot",
+                       "A lazy Snapshot action was booked but never triggered. The tree 't' in output file "
+                       "'lazysnapshotnottriggered_shouldnotbecreated.root' was not created. "
+                       "In case it was desired instead, remember to trigger the Snapshot operation, by "
+                       "storing its result in a variable and for example calling the GetValue() method on it.");
    ROOT::DisableImplicitMT();
 }
 
+TEST(RDFSnapshotMore, LazyTriggeredMT)
+{
+   TIMTEnabler _(4);
+   auto fname = "LazyTriggeredMT.root";
+   ROOT_EXPECT_NODIAG(*ReturnLazySnapshot(fname));
+   gSystem->Unlink(fname);
+}
+
 TEST(RDFSnapshotMore, EmptyBuffersMT)
 {
+   // Test that a tree gets created when only one worker yields events
    const auto fname = "emptybuffersmt.root";
    const auto treename = "t";
    const unsigned int nslots = std::min(4U, std::thread::hardware_concurrency());
    ROOT::EnableImplicitMT(nslots);
    ROOT::RDataFrame d(10);
-   auto dd = d.DefineSlot("x", [&](unsigned int s) { return s == nslots - 1 ? 0 : 1; })
-               .Filter([](int x) { return x == 0; }, {"x"}, "f");
+   std::atomic_bool firstWorker{true};
+   auto dd = d.DefineSlot("x", [&](unsigned int) {
+                 bool expected = true;
+                 if (firstWorker.compare_exchange_strong(expected, false)) {
+                    return 0;
+                 }
+                 return 1;
+              }).Filter([](int x) { return x == 0; }, {"x"}, "f");
    auto r = dd.Report();
    dd.Snapshot<int>(treename, fname, {"x"});
 
@@ -1263,11 +1556,14 @@ TEST(RDFSnapshotMore, ForbiddenOutputFilenameMT)
 
    // Jitted
    // the error printed here is
-   // "SysError in <TFile::TFile>: file /definitely/not/a/valid/path/f.root can not be opened No such file or directory\nError in <TReentrantRWLock::WriteUnLock>: Write lock already released for 0x55f179989378\n"
-   // but the address printed changes every time
+   // "SysError in <TFile::TFile>: file /definitely/not/a/valid/path/f.root can not be opened No such file or
+   // directory\nError in <TReentrantRWLock::WriteUnLock>: Write lock already released for 0x55f179989378\n" but the
+   // address printed changes every time
    ROOT::TestSupport::CheckDiagsRAII diagRAII;
-   diagRAII.requiredDiag(kSysError, "TFile::TFile", "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory");
-   diagRAII.optionalDiag(kSysError, "TReentrantRWLock::WriteUnLock", "Write lock already released for", /*wholeStringNeedsToMatch=*/false);
+   diagRAII.requiredDiag(kSysError, "TFile::TFile",
+                         "file /definitely/not/a/valid/path/f.root can not be opened No such file or directory");
+   diagRAII.optionalDiag(kSysError, "TReentrantRWLock::WriteUnLock", "Write lock already released for",
+                         /*wholeStringNeedsToMatch=*/false);
    EXPECT_THROW(df.Snapshot("t", out_fname, {"rdfslot_"}), std::runtime_error);
 }
 
@@ -1352,5 +1648,27 @@ TEST(RDFSnapshotMore, ZeroOutputEntriesMT)
    gSystem->Unlink(fname);
 }
 
-#endif // R__USE_IMT
+TEST(RDFSnapshotMore, CustomBasketSizeMT)
+{
+   ROOT::EnableImplicitMT();
+   TestCustomBasketSize();
+   ROOT::DisableImplicitMT();
+}
 
+// Test for default basket size
+TEST(RDFSnapshotMore, DefaultBasketSizeMT)
+{
+   ROOT::EnableImplicitMT();
+   TestDefaultBasketSize();
+   ROOT::DisableImplicitMT();
+}
+
+// Test for basket size preservation
+TEST(RDFSnapshotMore, BasketSizePreservationMT)
+{
+   ROOT::EnableImplicitMT();
+   TestBasketSizePreservation();
+   ROOT::DisableImplicitMT();
+}
+
+#endif // R__USE_IMT
