@@ -9,14 +9,14 @@
 #include "CustomStructUtil.hxx"
 #include "ntupleutil_test.hxx"
 
+using ROOT::ENTupleColumnType;
+using ROOT::RField;
+using ROOT::RFieldBase;
 using ROOT::RNTuple;
-using ROOT::Experimental::EColumnType;
-using ROOT::Experimental::RField;
-using ROOT::Experimental::RFieldBase;
+using ROOT::RNTupleModel;
+using ROOT::RNTupleWriteOptions;
+using ROOT::RNTupleWriter;
 using ROOT::Experimental::RNTupleInspector;
-using ROOT::Experimental::RNTupleModel;
-using ROOT::Experimental::RNTupleWriteOptions;
-using ROOT::Experimental::RNTupleWriter;
 
 TEST(RNTupleInspector, CreateFromPointer)
 {
@@ -29,7 +29,7 @@ TEST(RNTupleInspector, CreateFromPointer)
    std::unique_ptr<TFile> file(TFile::Open(fileGuard.GetPath().c_str()));
    auto ntuple = std::unique_ptr<RNTuple>(file->Get<RNTuple>("ntuple"));
    auto inspector = RNTupleInspector::Create(*ntuple);
-   EXPECT_EQ(inspector->GetDescriptor()->GetName(), "ntuple");
+   EXPECT_EQ(inspector->GetDescriptor().GetName(), "ntuple");
 }
 
 TEST(RNTupleInspector, CreateFromString)
@@ -40,9 +40,9 @@ TEST(RNTupleInspector, CreateFromString)
    }
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
-   EXPECT_EQ(inspector->GetDescriptor()->GetName(), "ntuple");
+   EXPECT_EQ(inspector->GetDescriptor().GetName(), "ntuple");
 
-   EXPECT_THROW(RNTupleInspector::Create("nonexistent", fileGuard.GetPath()), ROOT::Experimental::RException);
+   EXPECT_THROW(RNTupleInspector::Create("nonexistent", fileGuard.GetPath()), ROOT::RException);
 }
 
 TEST(RNTupleInspector, CompressionSettings)
@@ -62,7 +62,7 @@ TEST(RNTupleInspector, CompressionSettings)
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
 
-   EXPECT_EQ(207, inspector->GetCompressionSettings());
+   EXPECT_EQ(207, *inspector->GetCompressionSettings());
    EXPECT_EQ("LZMA (level 7)", inspector->GetCompressionSettingsAsString());
 }
 
@@ -75,7 +75,7 @@ TEST(RNTupleInspector, UnknownCompression)
    {
       auto model = RNTupleModel::Create();
 
-      auto vecFld = model->MakeField<std::vector<float>>("vecFld", refVec);
+      *model->MakeField<std::vector<float>>("vecFld") = refVec;
 
       RNTupleWriteOptions opts;
       opts.SetCompression(505);
@@ -87,14 +87,26 @@ TEST(RNTupleInspector, UnknownCompression)
       auto modelUpdater = ntuple->CreateModelUpdater();
 
       modelUpdater->BeginUpdate();
-      auto extVecField = modelUpdater->MakeField<std::vector<float>>("extVecFld", refVec);
+      *modelUpdater->MakeField<std::vector<float>>("extVecFld") = refVec;
       modelUpdater->CommitUpdate();
 
       ntuple->Fill();
    }
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
-   EXPECT_EQ(505, inspector->GetCompressionSettings());
+   EXPECT_EQ(505, *inspector->GetCompressionSettings());
+}
+
+TEST(RNTupleInspector, Empty)
+{
+   FileRaii fileGuard("test_ntuple_inspector_empty.root");
+   {
+      auto writer = RNTupleWriter::Recreate(RNTupleModel::Create(), "ntuple", fileGuard.GetPath());
+   }
+
+   auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
+   EXPECT_FALSE(inspector->GetCompressionSettings());
+   EXPECT_EQ("unknown", inspector->GetCompressionSettingsAsString());
 }
 
 TEST(RNTupleInspector, SizeUncompressedSimple)
@@ -141,8 +153,8 @@ TEST(RNTupleInspector, SizeUncompressedComplex)
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
 
-   int nIndexCols = inspector->GetColumnCountByType(EColumnType::kIndex64);
-   int nEntries = inspector->GetDescriptor()->GetNEntries();
+   int nIndexCols = inspector->GetColumnCountByType(ENTupleColumnType::kIndex64);
+   int nEntries = inspector->GetDescriptor().GetNEntries();
 
    EXPECT_EQ(2, nIndexCols);
    EXPECT_EQ(3, nEntries);
@@ -276,7 +288,7 @@ TEST(RNTupleInspector, ColumnInfoCompressed)
 
    std::uint64_t totalOnDiskSize = 0;
 
-   for (std::size_t i = 0; i < inspector->GetDescriptor()->GetNLogicalColumns(); ++i) {
+   for (std::size_t i = 0; i < inspector->GetDescriptor().GetNLogicalColumns(); ++i) {
       auto colInfo = inspector->GetColumnInspector(i);
       totalOnDiskSize += colInfo.GetCompressedSize();
 
@@ -287,7 +299,7 @@ TEST(RNTupleInspector, ColumnInfoCompressed)
 
    EXPECT_EQ(totalOnDiskSize, inspector->GetCompressedSize());
 
-   EXPECT_THROW(inspector->GetColumnInspector(42), ROOT::Experimental::RException);
+   EXPECT_THROW(inspector->GetColumnInspector(42), ROOT::RException);
 }
 
 TEST(RNTupleInspector, ColumnInfoUncompressed)
@@ -297,11 +309,11 @@ TEST(RNTupleInspector, ColumnInfoUncompressed)
       auto model = RNTupleModel::Create();
 
       auto int32fld = std::make_unique<RField<std::int32_t>>("int32");
-      int32fld->SetColumnRepresentatives({{EColumnType::kInt32}});
+      int32fld->SetColumnRepresentatives({{ENTupleColumnType::kInt32}});
       model->AddField(std::move(int32fld));
 
       auto splitReal64fld = std::make_unique<RField<double>>("splitReal64");
-      splitReal64fld->SetColumnRepresentatives({{EColumnType::kSplitReal64}});
+      splitReal64fld->SetColumnRepresentatives({{ENTupleColumnType::kSplitReal64}});
       model->AddField(std::move(splitReal64fld));
 
       auto writeOptions = RNTupleWriteOptions();
@@ -320,7 +332,7 @@ TEST(RNTupleInspector, ColumnInfoUncompressed)
 
    std::uint64_t colTypeSizes[] = {sizeof(std::int32_t), sizeof(double)};
 
-   for (std::size_t i = 0; i < inspector->GetDescriptor()->GetNLogicalColumns(); ++i) {
+   for (std::size_t i = 0; i < inspector->GetDescriptor().GetNLogicalColumns(); ++i) {
       auto colInfo = inspector->GetColumnInspector(i);
       EXPECT_EQ(colInfo.GetCompressedSize(), colInfo.GetUncompressedSize());
       EXPECT_EQ(colInfo.GetCompressedSize(), colTypeSizes[i] * 5);
@@ -341,9 +353,9 @@ TEST(RNTupleInspector, ColumnTypeCount)
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
 
-   EXPECT_EQ(2, inspector->GetColumnCountByType(EColumnType::kSplitIndex64));
-   EXPECT_EQ(4, inspector->GetColumnCountByType(EColumnType::kSplitReal32));
-   EXPECT_EQ(3, inspector->GetColumnCountByType(EColumnType::kSplitInt32));
+   EXPECT_EQ(2, inspector->GetColumnCountByType(ENTupleColumnType::kSplitIndex64));
+   EXPECT_EQ(4, inspector->GetColumnCountByType(ENTupleColumnType::kSplitReal32));
+   EXPECT_EQ(3, inspector->GetColumnCountByType(ENTupleColumnType::kSplitInt32));
 }
 
 TEST(RNTupleInspector, ColumnsByType)
@@ -363,23 +375,23 @@ TEST(RNTupleInspector, ColumnsByType)
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
 
-   EXPECT_EQ(2U, inspector->GetColumnsByType(EColumnType::kSplitInt64).size());
-   for (const auto colId : inspector->GetColumnsByType(EColumnType::kSplitInt64)) {
-      EXPECT_EQ(EColumnType::kSplitInt64, inspector->GetColumnInspector(colId).GetType());
+   EXPECT_EQ(2U, inspector->GetColumnsByType(ENTupleColumnType::kSplitInt64).size());
+   for (const auto colId : inspector->GetColumnsByType(ENTupleColumnType::kSplitInt64)) {
+      EXPECT_EQ(ENTupleColumnType::kSplitInt64, inspector->GetColumnInspector(colId).GetType());
    }
 
-   EXPECT_EQ(2U, inspector->GetColumnsByType(EColumnType::kSplitReal32).size());
-   for (const auto colId : inspector->GetColumnsByType(EColumnType::kSplitReal32)) {
-      EXPECT_EQ(EColumnType::kSplitReal32, inspector->GetColumnInspector(colId).GetType());
+   EXPECT_EQ(2U, inspector->GetColumnsByType(ENTupleColumnType::kSplitReal32).size());
+   for (const auto colId : inspector->GetColumnsByType(ENTupleColumnType::kSplitReal32)) {
+      EXPECT_EQ(ENTupleColumnType::kSplitReal32, inspector->GetColumnInspector(colId).GetType());
    }
 
-   EXPECT_EQ(1U, inspector->GetColumnsByType(EColumnType::kSplitIndex64).size());
-   EXPECT_EQ(1U, inspector->GetColumnsByType(EColumnType::kSplitIndex64).size());
-   for (const auto colId : inspector->GetColumnsByType(EColumnType::kSplitIndex64)) {
-      EXPECT_EQ(EColumnType::kSplitIndex64, inspector->GetColumnInspector(colId).GetType());
+   EXPECT_EQ(1U, inspector->GetColumnsByType(ENTupleColumnType::kSplitIndex64).size());
+   EXPECT_EQ(1U, inspector->GetColumnsByType(ENTupleColumnType::kSplitIndex64).size());
+   for (const auto colId : inspector->GetColumnsByType(ENTupleColumnType::kSplitIndex64)) {
+      EXPECT_EQ(ENTupleColumnType::kSplitIndex64, inspector->GetColumnInspector(colId).GetType());
    }
 
-   EXPECT_EQ(0U, inspector->GetColumnsByType(EColumnType::kSplitReal64).size());
+   EXPECT_EQ(0U, inspector->GetColumnsByType(ENTupleColumnType::kSplitReal64).size());
 }
 
 TEST(RNTupleInspector, ColumnTypes)
@@ -399,8 +411,8 @@ TEST(RNTupleInspector, ColumnTypes)
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
    auto types = inspector->GetColumnTypes();
-   EXPECT_THAT(types, testing::UnorderedElementsAre(EColumnType::kSplitInt64, EColumnType::kSplitReal32,
-                                                    EColumnType::kSplitIndex64));
+   EXPECT_THAT(types, testing::UnorderedElementsAre(ENTupleColumnType::kSplitInt64, ENTupleColumnType::kSplitReal32,
+                                                    ENTupleColumnType::kSplitIndex64));
 }
 
 TEST(RNTupleInspector, PrintColumnTypeInfo)
@@ -433,7 +445,7 @@ TEST(RNTupleInspector, PrintColumnTypeInfo)
 
    std::string line;
    std::getline(csvOutput, line);
-   EXPECT_EQ("columnType,count,nElements,compressedSize,uncompressedSize", line);
+   EXPECT_EQ("columnType,count,nElements,compressedSize,uncompressedSize,compressionFactor,nPages", line);
 
    size_t nLines = 0;
    std::string colTypeStr;
@@ -450,10 +462,14 @@ TEST(RNTupleInspector, PrintColumnTypeInfo)
    inspector->PrintColumnTypeInfo(ROOT::Experimental::ENTupleInspectorPrintFormat::kTable, tableOutput);
 
    std::getline(tableOutput, line);
-   EXPECT_EQ(" column type    | count   | # elements      | compressed bytes  | uncompressed bytes", line);
+   EXPECT_EQ(
+      " column type    | count   | # elements  | compressed bytes | uncompressed bytes | compression ratio | # pages ",
+      line);
 
    std::getline(tableOutput, line);
-   EXPECT_EQ("----------------|---------|-----------------|-------------------|--------------------", line);
+   EXPECT_EQ(
+      "----------------|---------|-------------|------------------|--------------------|-------------------|-------",
+      line);
 
    nLines = 0;
    while (std::getline(tableOutput, line)) {
@@ -496,15 +512,15 @@ TEST(RNTupleInspector, ColumnTypeInfoHist)
    EXPECT_STREQ("colTypeCountHist", countHist->GetName());
    EXPECT_STREQ("Column count by type", countHist->GetTitle());
    EXPECT_EQ(4U, countHist->GetNbinsX());
-   EXPECT_EQ(inspector->GetDescriptor()->GetNPhysicalColumns(), countHist->Integral());
+   EXPECT_EQ(inspector->GetDescriptor().GetNPhysicalColumns(), countHist->Integral());
 
    auto nElemsHist = inspector->GetColumnTypeInfoAsHist(ROOT::Experimental::ENTupleInspectorHist::kNElems, "elemsHist");
    EXPECT_STREQ("elemsHist", nElemsHist->GetName());
    EXPECT_STREQ("Number of elements by column type", nElemsHist->GetTitle());
    EXPECT_EQ(4U, nElemsHist->GetNbinsX());
    std::uint64_t nTotalElems = 0;
-   for (const auto &col : inspector->GetDescriptor()->GetColumnIterable()) {
-      nTotalElems += inspector->GetDescriptor()->GetNElements(col.GetPhysicalId());
+   for (const auto &col : inspector->GetDescriptor().GetColumnIterable()) {
+      nTotalElems += inspector->GetDescriptor().GetNElements(col.GetPhysicalId());
    }
    EXPECT_EQ(nTotalElems, nElemsHist->Integral());
 
@@ -531,10 +547,11 @@ TEST(RNTupleInspector, PageSizeDistribution)
       auto nFldInt = model->MakeField<std::int64_t>("int");
       auto nFldFloat = model->MakeField<float>("float");
       auto nFldFloatVec = model->MakeField<std::vector<float>>("floatVec");
+      auto nFldDoubleVec = model->MakeField<std::vector<double>>("doubleVec");
 
       auto writeOptions = RNTupleWriteOptions();
       writeOptions.SetCompression(505);
-      writeOptions.SetInitialNElementsPerPage(1);
+      writeOptions.SetInitialUnzippedPageSize(8);
       writeOptions.SetMaxUnzippedPageSize(64);
       auto ntuple = RNTupleWriter::Recreate(std::move(model), "ntuple", fileGuard.GetPath(), writeOptions);
 
@@ -542,13 +559,14 @@ TEST(RNTupleInspector, PageSizeDistribution)
          *nFldInt = static_cast<std::int64_t>(i);
          *nFldFloat = static_cast<float>(i) * .1f;
          *nFldFloatVec = {static_cast<float>(i), 3.14f, static_cast<float>(i) * *nFldFloat};
+         *nFldDoubleVec = {};
          ntuple->Fill();
       }
    }
 
    auto inspector = RNTupleInspector::Create("ntuple", fileGuard.GetPath());
 
-   int intColId = inspector->GetColumnsByType(EColumnType::kSplitInt64)[0];
+   int intColId = inspector->GetColumnsByType(ENTupleColumnType::kSplitInt64)[0];
    auto intPageSizeHisto = inspector->GetPageSizeDistribution(intColId);
    EXPECT_STREQ("pageSizeHist", intPageSizeHisto->GetName());
    EXPECT_STREQ(Form("Page size distribution for column with ID %d", intColId), intPageSizeHisto->GetTitle());
@@ -559,7 +577,7 @@ TEST(RNTupleInspector, PageSizeDistribution)
    int nIntPages = inspector->GetColumnInspector(intColId).GetNPages();
    EXPECT_EQ(nIntPages, intPageSizeHisto->Integral());
 
-   auto floatPageSizeHisto = inspector->GetPageSizeDistribution(EColumnType::kSplitReal32, "floatPageSize",
+   auto floatPageSizeHisto = inspector->GetPageSizeDistribution(ENTupleColumnType::kSplitReal32, "floatPageSize",
                                                                 "Float page size distribution", 100);
    EXPECT_STREQ("floatPageSize", floatPageSizeHisto->GetName());
    EXPECT_STREQ("Float page size distribution", floatPageSizeHisto->GetTitle());
@@ -568,7 +586,7 @@ TEST(RNTupleInspector, PageSizeDistribution)
    EXPECT_EQ(100, floatPageSizeHisto->GetNbinsX());
    // Make sure that all page sizes are included in the histogram
    int nFloatPages = 0;
-   for (const auto colId : inspector->GetColumnsByType(EColumnType::kSplitReal32)) {
+   for (const auto colId : inspector->GetColumnsByType(ENTupleColumnType::kSplitReal32)) {
       nFloatPages += inspector->GetColumnInspector(colId).GetNPages();
    }
    EXPECT_EQ(nFloatPages, floatPageSizeHisto->Integral());
@@ -580,8 +598,8 @@ TEST(RNTupleInspector, PageSizeDistribution)
                 inspector->GetColumnInspector(2).GetNPages();
    EXPECT_EQ(nPages, multipleColsSizeHisto->Integral());
 
-   auto intFloatPageSizeHisto =
-      inspector->GetPageSizeDistribution({EColumnType::kSplitInt64, EColumnType::kSplitReal32}, "intFloatPageSize");
+   auto intFloatPageSizeHisto = inspector->GetPageSizeDistribution(
+      {ENTupleColumnType::kSplitInt64, ENTupleColumnType::kSplitReal32}, "intFloatPageSize");
    EXPECT_STREQ("intFloatPageSize", intFloatPageSizeHisto->GetName());
    EXPECT_STREQ("Per-column type page size distribution", intFloatPageSizeHisto->GetTitle());
    EXPECT_EQ(2, intFloatPageSizeHisto->GetNhists());
@@ -594,7 +612,7 @@ TEST(RNTupleInspector, PageSizeDistribution)
 
    auto allColsSizeHisto = inspector->GetPageSizeDistribution();
    nPages = 0;
-   for (const auto &col : inspector->GetDescriptor()->GetColumnIterable()) {
+   for (const auto &col : inspector->GetDescriptor().GetColumnIterable()) {
       nPages += inspector->GetColumnInspector(col.GetPhysicalId()).GetNPages();
    }
    int allColsIntegral = 0;
@@ -604,12 +622,22 @@ TEST(RNTupleInspector, PageSizeDistribution)
    EXPECT_EQ(nPages, allColsIntegral);
 
    // Requesting a histogram for a column with a physical ID not present in the given RNTuple should throw
-   EXPECT_THROW(inspector->GetPageSizeDistribution(inspector->GetDescriptor()->GetNPhysicalColumns() + 1),
-                ROOT::Experimental::RException);
+   EXPECT_THROW(inspector->GetPageSizeDistribution(inspector->GetDescriptor().GetNPhysicalColumns() + 1),
+                ROOT::RException);
 
    // Requesting a histogram for a column type not present in the given RNTuple should give an empty histogram
-   auto nonExistingTypeHisto = inspector->GetPageSizeDistribution(EColumnType::kReal32);
+   auto nonExistingTypeHisto = inspector->GetPageSizeDistribution(ENTupleColumnType::kReal32);
    EXPECT_EQ(0, nonExistingTypeHisto->Integral());
+
+   // Requesting a histogram for a column type without pages in the given RNTuple should give an empty histogram
+   auto emptyTypeHisto = inspector->GetPageSizeDistribution(ENTupleColumnType::kSplitReal64);
+   EXPECT_EQ(0, emptyTypeHisto->Integral());
+
+   // Requesting a histogram for a column  without pages in the given RNTuple should give an empty histogram
+   auto doubleColumns = inspector->GetColumnsByType(ENTupleColumnType::kSplitReal64);
+   ASSERT_EQ(1, doubleColumns.size());
+   auto emptyColumnHisto = inspector->GetPageSizeDistribution({doubleColumns[0]});
+   EXPECT_EQ(0, emptyColumnHisto->Integral());
 }
 
 TEST(RNTupleInspector, FieldInfoCompressed)
@@ -644,7 +672,7 @@ TEST(RNTupleInspector, FieldInfoCompressed)
    std::uint64_t subFieldOnDiskSize = 0;
    std::uint64_t subFieldInMemorySize = 0;
 
-   for (const auto &subField : inspector->GetDescriptor()->GetFieldIterable(topFieldInfo.GetDescriptor().GetId())) {
+   for (const auto &subField : inspector->GetDescriptor().GetFieldIterable(topFieldInfo.GetDescriptor().GetId())) {
       auto subFieldInfo = inspector->GetFieldTreeInspector(subField.GetId());
       subFieldOnDiskSize += subFieldInfo.GetCompressedSize();
       subFieldInMemorySize += subFieldInfo.GetUncompressedSize();
@@ -653,9 +681,8 @@ TEST(RNTupleInspector, FieldInfoCompressed)
    EXPECT_EQ(topFieldInfo.GetCompressedSize(), subFieldOnDiskSize);
    EXPECT_EQ(topFieldInfo.GetUncompressedSize(), subFieldInMemorySize);
 
-   EXPECT_THROW(inspector->GetFieldTreeInspector("invalid_field"), ROOT::Experimental::RException);
-   EXPECT_THROW(inspector->GetFieldTreeInspector(inspector->GetDescriptor()->GetNFields()),
-                ROOT::Experimental::RException);
+   EXPECT_THROW(inspector->GetFieldTreeInspector("invalid_field"), ROOT::RException);
+   EXPECT_THROW(inspector->GetFieldTreeInspector(inspector->GetDescriptor().GetNFields()), ROOT::RException);
 }
 
 TEST(RNTupleInspector, FieldInfoUncompressed)
@@ -688,7 +715,7 @@ TEST(RNTupleInspector, FieldInfoUncompressed)
    std::uint64_t subFieldOnDiskSize = 0;
    std::uint64_t subFieldInMemorySize = 0;
 
-   for (const auto &subField : inspector->GetDescriptor()->GetFieldIterable(topFieldInfo.GetDescriptor().GetId())) {
+   for (const auto &subField : inspector->GetDescriptor().GetFieldIterable(topFieldInfo.GetDescriptor().GetId())) {
       auto subFieldInfo = inspector->GetFieldTreeInspector(subField.GetId());
       subFieldOnDiskSize += subFieldInfo.GetCompressedSize();
       subFieldInMemorySize += subFieldInfo.GetUncompressedSize();
@@ -768,12 +795,12 @@ TEST(RNTupleInspector, MultiColumnRepresentations)
    {
       auto model = RNTupleModel::Create();
       auto fldPx = RFieldBase::Create("px", "float").Unwrap();
-      fldPx->SetColumnRepresentatives({{EColumnType::kReal32}, {EColumnType::kReal16}});
+      fldPx->SetColumnRepresentatives({{ENTupleColumnType::kReal32}, {ENTupleColumnType::kReal16}});
       model->AddField(std::move(fldPx));
       auto writer = RNTupleWriter::Recreate(std::move(model), "ntpl", fileGuard.GetPath());
       writer->Fill();
       writer->CommitCluster();
-      ROOT::Experimental::Internal::RFieldRepresentationModifier::SetPrimaryColumnRepresentation(
+      ROOT::Internal::RFieldRepresentationModifier::SetPrimaryColumnRepresentation(
          const_cast<RFieldBase &>(writer->GetModel().GetConstField("px")), 1);
       writer->Fill();
    }
@@ -781,8 +808,8 @@ TEST(RNTupleInspector, MultiColumnRepresentations)
    auto inspector = RNTupleInspector::Create("ntpl", fileGuard.GetPath());
    auto px0Inspector = inspector->GetColumnInspector(0);
    auto px1Inspector = inspector->GetColumnInspector(1);
-   EXPECT_EQ(EColumnType::kReal32, px0Inspector.GetType());
+   EXPECT_EQ(ENTupleColumnType::kReal32, px0Inspector.GetType());
    EXPECT_EQ(1u, px0Inspector.GetNElements());
-   EXPECT_EQ(EColumnType::kReal16, px1Inspector.GetType());
+   EXPECT_EQ(ENTupleColumnType::kReal16, px1Inspector.GetType());
    EXPECT_EQ(1u, px1Inspector.GetNElements());
 }
