@@ -54,7 +54,7 @@ TBufferSQL::TBufferSQL(TBuffer::EMode mode, Int_t bufsiz, std::vector<Int_t> *vc
 
 TBufferSQL::TBufferSQL(TBuffer::EMode mode, Int_t bufsiz, std::vector<Int_t> *vc,
                        TString *insert_query, TSQLRow ** r,
-                       void *buf, Bool_t adopt) :
+                       void *buf, bool adopt) :
    TBufferFile(mode,bufsiz,buf,adopt),
    fColumnVec(vc), fInsertQuery(insert_query), fRowPtr(r)
 {
@@ -64,7 +64,7 @@ TBufferSQL::TBufferSQL(TBuffer::EMode mode, Int_t bufsiz, std::vector<Int_t> *vc
 ////////////////////////////////////////////////////////////////////////////////
 /// Constructor.
 
-TBufferSQL::TBufferSQL() : TBufferFile(), fColumnVec(0),fInsertQuery(0),fRowPtr(0)
+TBufferSQL::TBufferSQL() : TBufferFile(), fColumnVec(nullptr),fInsertQuery(nullptr),fRowPtr(nullptr)
 {
 }
 
@@ -79,9 +79,9 @@ TBufferSQL::~TBufferSQL()
 ////////////////////////////////////////////////////////////////////////////////
 /// Operator>>
 
-void TBufferSQL::ReadBool(Bool_t &b)
+void TBufferSQL::ReadBool(bool &b)
 {
-   b = (Bool_t)atoi((*fRowPtr)->GetField(*fIter));
+   b = (bool)atoi((*fRowPtr)->GetField(*fIter));
 
    if (fIter != fColumnVec->end()) ++fIter;
 }
@@ -149,7 +149,7 @@ void TBufferSQL::ReadDouble(Double_t &d)
 ////////////////////////////////////////////////////////////////////////////////
 /// Operator<<
 
-void TBufferSQL::WriteBool(Bool_t    b)
+void TBufferSQL::WriteBool(bool      b)
 {
    (*fInsertQuery) += b;
    (*fInsertQuery) += ",";
@@ -422,9 +422,17 @@ void TBufferSQL::WriteCharP(const Char_t *str)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const bool *b, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // 2 chars
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += b[i];
       (*fInsertQuery) += ",";
@@ -434,9 +442,17 @@ void TBufferSQL::WriteFastArray(const bool *b, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Char_t *c, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += (Short_t)c[i];
       (*fInsertQuery) += ",";
@@ -446,9 +462,17 @@ void TBufferSQL::WriteFastArray(const Char_t *c, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArrayString(const Char_t *c, Long64_t /* n */)
 {
+   constexpr Int_t dataWidth = 4; // 4 chars
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (maxElements < 1)
+   {
+      Fatal("WriteFastArrayString", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", 1LL, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    (*fInsertQuery) += "\"";
    (*fInsertQuery) += c;
    (*fInsertQuery) += "\",";
@@ -457,9 +481,17 @@ void TBufferSQL::WriteFastArrayString(const Char_t *c, Long64_t /* n */)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const UChar_t *uc, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += uc[i];
       (*fInsertQuery) += ",";
@@ -469,9 +501,17 @@ void TBufferSQL::WriteFastArray(const UChar_t *uc, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Short_t *h, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += h[i];
       (*fInsertQuery) += ",";
@@ -481,9 +521,18 @@ void TBufferSQL::WriteFastArray(const Short_t *h, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
+
 
 void TBufferSQL::WriteFastArray(const UShort_t *us, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += us[i];
       (*fInsertQuery) += ",";
@@ -493,9 +542,17 @@ void TBufferSQL::WriteFastArray(const UShort_t *us, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Int_t     *ii, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
     //   std::cerr << "Column: " <<*fIter << "   i:" << *ii << std::endl;
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += ii[i];
@@ -506,9 +563,17 @@ void TBufferSQL::WriteFastArray(const Int_t     *ii, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const UInt_t *ui, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += ui[i];
       (*fInsertQuery) += ",";
@@ -518,9 +583,17 @@ void TBufferSQL::WriteFastArray(const UInt_t *ui, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Long_t    *l, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery)+= l[i];
       (*fInsertQuery)+= ",";
@@ -530,9 +603,17 @@ void TBufferSQL::WriteFastArray(const Long_t    *l, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const ULong_t   *ul, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += ul[i];
       (*fInsertQuery) += ",";
@@ -542,9 +623,17 @@ void TBufferSQL::WriteFastArray(const ULong_t   *ul, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Long64_t  *l, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += l[i];
       (*fInsertQuery) += ",";
@@ -554,9 +643,17 @@ void TBufferSQL::WriteFastArray(const Long64_t  *l, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const ULong64_t *ul, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += ul[i];
       (*fInsertQuery) += ",";
@@ -566,9 +663,17 @@ void TBufferSQL::WriteFastArray(const ULong64_t *ul, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Float_t   *f, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += f[i];
       (*fInsertQuery) += ",";
@@ -578,9 +683,17 @@ void TBufferSQL::WriteFastArray(const Float_t   *f, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+/// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(const Double_t  *d, Long64_t n)
 {
+   constexpr Int_t dataWidth = 2; // at least 2 chars, but could be more.
+   const Int_t maxElements = (std::numeric_limits<Int_t>::max() - Length())/dataWidth;
+   if (n < 0 || n > maxElements)
+   {
+      Fatal("WriteFastArray", "Not enough space left in the buffer (1GB limit). %lld elements is greater than the max left of %d", n, maxElements);
+      return; // In case the user re-routes the error handler to not die when Fatal is called
+   }
    for(int i=0; i<n; ++i) {
       (*fInsertQuery) += d[i];
       (*fInsertQuery )+= ",";
@@ -590,6 +703,7 @@ void TBufferSQL::WriteFastArray(const Double_t  *d, Long64_t n)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 void TBufferSQL::WriteFastArray(void*, const TClass*, Long64_t, TMemberStreamer *)
 {
@@ -598,6 +712,7 @@ void TBufferSQL::WriteFastArray(void*, const TClass*, Long64_t, TMemberStreamer
 
 ////////////////////////////////////////////////////////////////////////////////
 /// WriteFastArray SQL implementation.
+// \note Due to the current limit of the buffer size, the function aborts execution of the program in case of underflow or overflow. See https://github.com/root-project/root/issues/6734 for more details.
 
 Int_t TBufferSQL::WriteFastArray(void **, const TClass*, Long64_t, bool, TMemberStreamer*)
 {
@@ -608,10 +723,10 @@ Int_t TBufferSQL::WriteFastArray(void **, const TClass*, Long64_t, bool, TMember
 ////////////////////////////////////////////////////////////////////////////////
 /// ReadFastArray SQL implementation.
 
-void TBufferSQL::ReadFastArray(Bool_t *b, Int_t n)
+void TBufferSQL::ReadFastArray(bool *b, Int_t n)
 {
    for(int i=0; i<n; ++i) {
-      b[i] = (Bool_t)atoi((*fRowPtr)->GetField(*fIter));
+      b[i] = (bool)atoi((*fRowPtr)->GetField(*fIter));
       ++fIter;
    }
 }
@@ -813,9 +928,9 @@ void     TBufferSQL::ReadFastArray(void  *, const TClass *, Int_t, TMemberStream
 ////////////////////////////////////////////////////////////////////////////////
 /// ReadFastArray SQL implementation.
 
-void     TBufferSQL::ReadFastArray(void **, const TClass *, Int_t, Bool_t, TMemberStreamer *, const TClass *)
+void     TBufferSQL::ReadFastArray(void **, const TClass *, Int_t, bool, TMemberStreamer *, const TClass *)
 {
-   Fatal("ReadFastArray(void **, const TClass *, Int_t, Bool_t, TMemberStreamer *, const TClass *)","Not implemented yet");
+   Fatal("ReadFastArray(void **, const TClass *, Int_t, bool, TMemberStreamer *, const TClass *)","Not implemented yet");
 }
 
 ////////////////////////////////////////////////////////////////////////////////
