@@ -58,11 +58,11 @@ TLeaf::TLeaf()
    , fLen(0)
    , fLenType(0)
    , fOffset(0)
-   , fIsRange(kFALSE)
-   , fIsUnsigned(kFALSE)
-   , fLeafCount(0)
-   , fBranch(0)
-   , fLeafCountValues(0)
+   , fIsRange(false)
+   , fIsUnsigned(false)
+   , fLeafCount(nullptr)
+   , fBranch(nullptr)
+   , fLeafCountValues(nullptr)
 {
 }
 
@@ -77,11 +77,11 @@ TLeaf::TLeaf(TBranch *parent, const char* name, const char *)
    , fLen(0)
    , fLenType(4)
    , fOffset(0)
-   , fIsRange(kFALSE)
-   , fIsUnsigned(kFALSE)
-   , fLeafCount(0)
+   , fIsRange(false)
+   , fIsUnsigned(false)
+   , fLeafCount(nullptr)
    , fBranch(parent)
-   , fLeafCountValues(0)
+   , fLeafCountValues(nullptr)
 {
    fLeafCount = GetLeafCounter(fLen);
 
@@ -141,13 +141,13 @@ TLeaf::~TLeaf()
 {
    if (fBranch) {
       TTree* tree = fBranch->GetTree();
-      fBranch = 0;
+      fBranch = nullptr;
       if (tree) {
          TObjArray *lst = tree->GetListOfLeaves();
          if (lst->GetLast()!=-1) lst->Remove(this);
       }
    }
-   fLeafCount = 0;
+   fLeafCount = nullptr;
    delete fLeafCountValues;
 }
 
@@ -252,7 +252,7 @@ TLeaf* TLeaf::GetLeafCounter(Int_t& countval) const
    const char* name = GetTitle();
    char* bleft = (char*) strchr(name, '[');
    if (!bleft) {
-      return 0;
+      return nullptr;
    }
    bleft++;
    Int_t nch = strlen(bleft);
@@ -261,29 +261,29 @@ TLeaf* TLeaf::GetLeafCounter(Int_t& countval) const
    char* bright = (char*) strchr(countname, ']');
    if (!bright) {
       delete[] countname;
-      countname = 0;
+      countname = nullptr;
       countval = -1;
-      return 0;
+      return nullptr;
    }
    char *bleft2 = (char*) strchr(countname, '[');
    *bright = 0;
    nch = strlen(countname);
 
    // Now search a branch name with a leaf name = countname
-   if (fBranch == 0) {
+   if (fBranch == nullptr) {
       Error("GetLeafCounter","TLeaf %s is not setup properly, fBranch is null.",GetName());
       delete[] countname;
-      return 0;
+      return nullptr;
    }
-   if (fBranch->GetTree() == 0) {
+   if (fBranch->GetTree() == nullptr) {
       Error("GetLeafCounter","For Leaf %s, the TBranch %s is not setup properly, fTree is null.",GetName(),fBranch->GetName());
       delete[] countname;
-      return 0;
+      return nullptr;
    }
    TTree* pTree = fBranch->GetTree();
 
    TLeaf* leaf = (TLeaf*) GetBranch()->GetListOfLeaves()->FindObject(countname);
-   if (leaf == 0) {
+   if (leaf == nullptr) {
       // Try outside the branch:
       leaf = (TLeaf*) pTree->GetListOfLeaves()->FindObject(countname);
    }
@@ -295,7 +295,7 @@ TLeaf* TLeaf::GetLeafCounter(Int_t& countval) const
       strcpy(lastdot, countname);
       leaf = (TLeaf*) pTree->GetListOfLeaves()->FindObject(withdot);
       delete[] withdot;
-      withdot = 0;
+      withdot = nullptr;
    }
    if (!leaf && strchr(countname,'.')) {
       // Not yet found and the countname has a dot in it, let's try
@@ -322,16 +322,16 @@ TLeaf* TLeaf::GetLeafCounter(Int_t& countval) const
          bleft2 = bleft;
       }
       delete[] countname;
-      countname = 0;
+      countname = nullptr;
       return leaf;
    }
    // not found in a branch/leaf. Is it a numerical value?
    for (i = 0; i < nch; i++) {
       if (!isdigit(countname[i])) {
          delete[] countname;
-         countname = 0;
+         countname = nullptr;
          countval = -1;
-         return 0;
+         return nullptr;
       }
    }
    sscanf(countname, "%d", &countval);
@@ -352,8 +352,8 @@ TLeaf* TLeaf::GetLeafCounter(Int_t& countval) const
    }
 
    delete[] countname;
-   countname = 0;
-   return 0;
+   countname = nullptr;
+   return nullptr;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -426,14 +426,14 @@ Int_t TLeaf::GetLen() const
 /// and a decision is made whether or not we own the
 /// new value buffer.
 
-Int_t TLeaf::ResetAddress(void* addr, Bool_t calledFromDestructor)
+Int_t TLeaf::ResetAddress(void* addr, bool calledFromDestructor)
 {
    // The kNewValue bit records whether or not we own
    // the current value buffer or not.  If we own it,
    // then we are responsible for deleting it.
-   Bool_t deleteValue = kFALSE;
+   bool deleteValue = false;
    if (TestBit(kNewValue)) {
-      deleteValue = kTRUE;
+      deleteValue = true;
    }
    // If we are not being called from a destructor,
    // recalculate the value buffer size and decide
